use std::ops::RangeInclusive;

use once_cell::sync::Lazy;

use super::hall_symbol_database::Number;

pub const NUM_MAGNETIC_SPACE_GROUP_TYPES: usize = 1651;

/// UNI Number for magnetic space groups (1 - 1651)
pub type UNINumber = i32;

#[derive(Debug, Clone, PartialEq, Eq)]
pub enum ConstructType {
    Type1,
    Type2,
    Type3,
    Type4,
}

#[derive(Debug, Clone)]
pub struct MagneticSpaceGroupType {
    pub uni_number: UNINumber,
    pub litvin_number: i32,
    pub bns_number: &'static str,
    pub og_number: &'static str,
    /// ITA number for reference space group in BNS setting
    pub number: Number,
    pub construct_type: ConstructType,
}

impl MagneticSpaceGroupType {
    const fn new(
        uni_number: UNINumber,
        litvin_number: i32,
        bns_number: &'static str,
        og_number: &'static str,
        number: Number,
        construct_type: ConstructType,
    ) -> Self {
        Self {
            uni_number,
            litvin_number,
            bns_number,
            og_number,
            number,
            construct_type,
        }
    }
}

/// Return inclusive range for UNI numbers associated with the given ITA number.
pub fn uni_number_range(number: Number) -> Option<RangeInclusive<UNINumber>> {
    ITA_NUMBER_TO_UNI_NUMBERS
        .get((number - 1) as usize)
        .cloned()
}

static ITA_NUMBER_TO_UNI_NUMBERS: Lazy<Vec<RangeInclusive<UNINumber>>> = Lazy::new(|| {
    let mut ret = vec![];
    let mut start = 1;
    for uni_number in 1..=NUM_MAGNETIC_SPACE_GROUP_TYPES {
        if (uni_number == NUM_MAGNETIC_SPACE_GROUP_TYPES)
            || (MAGNETIC_SPACE_GROUP_TYPES[uni_number - 1].number
                != MAGNETIC_SPACE_GROUP_TYPES[uni_number].number)
        {
            ret.push(start..=uni_number as UNINumber);
            start = uni_number as UNINumber + 1;
        }
    }
    assert_eq!(ret.len(), 230);
    ret
});

pub fn get_magnetic_space_group_type(uni_number: UNINumber) -> Option<MagneticSpaceGroupType> {
    MAGNETIC_SPACE_GROUP_TYPES
        .get((uni_number - 1) as usize)
        .cloned()
}

const MAGNETIC_SPACE_GROUP_TYPES: [MagneticSpaceGroupType; NUM_MAGNETIC_SPACE_GROUP_TYPES] = [
    MagneticSpaceGroupType::new(1, 1, "1.1", "1.1.1", 1, ConstructType::Type1),
    MagneticSpaceGroupType::new(2, 2, "1.2", "1.2.2", 1, ConstructType::Type2),
    MagneticSpaceGroupType::new(3, 3, "1.3", "1.3.3", 1, ConstructType::Type4),
    MagneticSpaceGroupType::new(4, 4, "2.4", "2.1.4", 2, ConstructType::Type1),
    MagneticSpaceGroupType::new(5, 5, "2.5", "2.2.5", 2, ConstructType::Type2),
    MagneticSpaceGroupType::new(6, 6, "2.6", "2.3.6", 2, ConstructType::Type3),
    MagneticSpaceGroupType::new(7, 7, "2.7", "2.4.7", 2, ConstructType::Type4),
    MagneticSpaceGroupType::new(8, 8, "3.1", "3.1.8", 3, ConstructType::Type1),
    MagneticSpaceGroupType::new(9, 9, "3.2", "3.2.9", 3, ConstructType::Type2),
    MagneticSpaceGroupType::new(10, 10, "3.3", "3.3.10", 3, ConstructType::Type3),
    MagneticSpaceGroupType::new(11, 11, "3.4", "3.4.11", 3, ConstructType::Type4),
    MagneticSpaceGroupType::new(12, 12, "3.5", "3.5.12", 3, ConstructType::Type4),
    MagneticSpaceGroupType::new(13, 23, "3.6", "5.5.23", 3, ConstructType::Type4),
    MagneticSpaceGroupType::new(14, 15, "4.7", "4.1.15", 4, ConstructType::Type1),
    MagneticSpaceGroupType::new(15, 16, "4.8", "4.2.16", 4, ConstructType::Type2),
    MagneticSpaceGroupType::new(16, 17, "4.9", "4.3.17", 4, ConstructType::Type3),
    MagneticSpaceGroupType::new(17, 18, "4.10", "4.4.18", 4, ConstructType::Type4),
    MagneticSpaceGroupType::new(18, 14, "4.11", "3.7.14", 4, ConstructType::Type4),
    MagneticSpaceGroupType::new(19, 24, "4.12", "5.6.24", 4, ConstructType::Type4),
    MagneticSpaceGroupType::new(20, 19, "5.13", "5.1.19", 5, ConstructType::Type1),
    MagneticSpaceGroupType::new(21, 20, "5.14", "5.2.20", 5, ConstructType::Type2),
    MagneticSpaceGroupType::new(22, 21, "5.15", "5.3.21", 5, ConstructType::Type3),
    MagneticSpaceGroupType::new(23, 22, "5.16", "5.4.22", 5, ConstructType::Type4),
    MagneticSpaceGroupType::new(24, 13, "5.17", "3.6.13", 5, ConstructType::Type4),
    MagneticSpaceGroupType::new(25, 25, "6.18", "6.1.25", 6, ConstructType::Type1),
    MagneticSpaceGroupType::new(26, 26, "6.19", "6.2.26", 6, ConstructType::Type2),
    MagneticSpaceGroupType::new(27, 27, "6.20", "6.3.27", 6, ConstructType::Type3),
    MagneticSpaceGroupType::new(28, 28, "6.21", "6.4.28", 6, ConstructType::Type4),
    MagneticSpaceGroupType::new(29, 29, "6.22", "6.5.29", 6, ConstructType::Type4),
    MagneticSpaceGroupType::new(30, 42, "6.23", "8.5.42", 6, ConstructType::Type4),
    MagneticSpaceGroupType::new(31, 32, "7.24", "7.1.32", 7, ConstructType::Type1),
    MagneticSpaceGroupType::new(32, 33, "7.25", "7.2.33", 7, ConstructType::Type2),
    MagneticSpaceGroupType::new(33, 34, "7.26", "7.3.34", 7, ConstructType::Type3),
    MagneticSpaceGroupType::new(34, 35, "7.27", "7.4.35", 7, ConstructType::Type4),
    MagneticSpaceGroupType::new(35, 31, "7.28", "6.7.31", 7, ConstructType::Type4),
    MagneticSpaceGroupType::new(36, 36, "7.29", "7.5.36", 7, ConstructType::Type4),
    MagneticSpaceGroupType::new(37, 48, "7.30", "9.4.48", 7, ConstructType::Type4),
    MagneticSpaceGroupType::new(38, 44, "7.31", "8.7.44", 7, ConstructType::Type4),
    MagneticSpaceGroupType::new(39, 38, "8.32", "8.1.38", 8, ConstructType::Type1),
    MagneticSpaceGroupType::new(40, 39, "8.33", "8.2.39", 8, ConstructType::Type2),
    MagneticSpaceGroupType::new(41, 40, "8.34", "8.3.40", 8, ConstructType::Type3),
    MagneticSpaceGroupType::new(42, 41, "8.35", "8.4.41", 8, ConstructType::Type4),
    MagneticSpaceGroupType::new(43, 30, "8.36", "6.6.30", 8, ConstructType::Type4),
    MagneticSpaceGroupType::new(44, 45, "9.37", "9.1.45", 9, ConstructType::Type1),
    MagneticSpaceGroupType::new(45, 46, "9.38", "9.2.46", 9, ConstructType::Type2),
    MagneticSpaceGroupType::new(46, 47, "9.39", "9.3.47", 9, ConstructType::Type3),
    MagneticSpaceGroupType::new(47, 43, "9.40", "8.6.43", 9, ConstructType::Type4),
    MagneticSpaceGroupType::new(48, 37, "9.41", "7.6.37", 9, ConstructType::Type4),
    MagneticSpaceGroupType::new(49, 49, "10.42", "10.1.49", 10, ConstructType::Type1),
    MagneticSpaceGroupType::new(50, 50, "10.43", "10.2.50", 10, ConstructType::Type2),
    MagneticSpaceGroupType::new(51, 51, "10.44", "10.3.51", 10, ConstructType::Type3),
    MagneticSpaceGroupType::new(52, 52, "10.45", "10.4.52", 10, ConstructType::Type3),
    MagneticSpaceGroupType::new(53, 53, "10.46", "10.5.53", 10, ConstructType::Type3),
    MagneticSpaceGroupType::new(54, 54, "10.47", "10.6.54", 10, ConstructType::Type4),
    MagneticSpaceGroupType::new(55, 55, "10.48", "10.7.55", 10, ConstructType::Type4),
    MagneticSpaceGroupType::new(56, 72, "10.49", "12.7.72", 10, ConstructType::Type4),
    MagneticSpaceGroupType::new(57, 59, "11.50", "11.1.59", 11, ConstructType::Type1),
    MagneticSpaceGroupType::new(58, 60, "11.51", "11.2.60", 11, ConstructType::Type2),
    MagneticSpaceGroupType::new(59, 61, "11.52", "11.3.61", 11, ConstructType::Type3),
    MagneticSpaceGroupType::new(60, 62, "11.53", "11.4.62", 11, ConstructType::Type3),
    MagneticSpaceGroupType::new(61, 63, "11.54", "11.5.63", 11, ConstructType::Type3),
    MagneticSpaceGroupType::new(62, 64, "11.55", "11.6.64", 11, ConstructType::Type4),
    MagneticSpaceGroupType::new(63, 57, "11.56", "10.9.57", 11, ConstructType::Type4),
    MagneticSpaceGroupType::new(64, 74, "11.57", "12.9.74", 11, ConstructType::Type4),
    MagneticSpaceGroupType::new(65, 66, "12.58", "12.1.66", 12, ConstructType::Type1),
    MagneticSpaceGroupType::new(66, 67, "12.59", "12.2.67", 12, ConstructType::Type2),
    MagneticSpaceGroupType::new(67, 68, "12.60", "12.3.68", 12, ConstructType::Type3),
    MagneticSpaceGroupType::new(68, 69, "12.61", "12.4.69", 12, ConstructType::Type3),
    MagneticSpaceGroupType::new(69, 70, "12.62", "12.5.70", 12, ConstructType::Type3),
    MagneticSpaceGroupType::new(70, 71, "12.63", "12.6.71", 12, ConstructType::Type4),
    MagneticSpaceGroupType::new(71, 56, "12.64", "10.8.56", 12, ConstructType::Type4),
    MagneticSpaceGroupType::new(72, 77, "13.65", "13.1.77", 13, ConstructType::Type1),
    MagneticSpaceGroupType::new(73, 78, "13.66", "13.2.78", 13, ConstructType::Type2),
    MagneticSpaceGroupType::new(74, 79, "13.67", "13.3.79", 13, ConstructType::Type3),
    MagneticSpaceGroupType::new(75, 80, "13.68", "13.4.80", 13, ConstructType::Type3),
    MagneticSpaceGroupType::new(76, 81, "13.69", "13.5.81", 13, ConstructType::Type3),
    MagneticSpaceGroupType::new(77, 82, "13.70", "13.6.82", 13, ConstructType::Type4),
    MagneticSpaceGroupType::new(78, 83, "13.71", "13.7.83", 13, ConstructType::Type4),
    MagneticSpaceGroupType::new(79, 58, "13.72", "10.10.58", 13, ConstructType::Type4),
    MagneticSpaceGroupType::new(80, 75, "13.73", "12.10.75", 13, ConstructType::Type4),
    MagneticSpaceGroupType::new(81, 97, "13.74", "15.6.97", 13, ConstructType::Type4),
    MagneticSpaceGroupType::new(82, 86, "14.75", "14.1.86", 14, ConstructType::Type1),
    MagneticSpaceGroupType::new(83, 87, "14.76", "14.2.87", 14, ConstructType::Type2),
    MagneticSpaceGroupType::new(84, 88, "14.77", "14.3.88", 14, ConstructType::Type3),
    MagneticSpaceGroupType::new(85, 89, "14.78", "14.4.89", 14, ConstructType::Type3),
    MagneticSpaceGroupType::new(86, 90, "14.79", "14.5.90", 14, ConstructType::Type3),
    MagneticSpaceGroupType::new(87, 91, "14.80", "14.6.91", 14, ConstructType::Type4),
    MagneticSpaceGroupType::new(88, 85, "14.81", "13.9.85", 14, ConstructType::Type4),
    MagneticSpaceGroupType::new(89, 65, "14.82", "11.7.65", 14, ConstructType::Type4),
    MagneticSpaceGroupType::new(90, 76, "14.83", "12.11.76", 14, ConstructType::Type4),
    MagneticSpaceGroupType::new(91, 98, "14.84", "15.7.98", 14, ConstructType::Type4),
    MagneticSpaceGroupType::new(92, 92, "15.85", "15.1.92", 15, ConstructType::Type1),
    MagneticSpaceGroupType::new(93, 93, "15.86", "15.2.93", 15, ConstructType::Type2),
    MagneticSpaceGroupType::new(94, 94, "15.87", "15.3.94", 15, ConstructType::Type3),
    MagneticSpaceGroupType::new(95, 95, "15.88", "15.4.95", 15, ConstructType::Type3),
    MagneticSpaceGroupType::new(96, 96, "15.89", "15.5.96", 15, ConstructType::Type3),
    MagneticSpaceGroupType::new(97, 73, "15.90", "12.8.73", 15, ConstructType::Type4),
    MagneticSpaceGroupType::new(98, 84, "15.91", "13.8.84", 15, ConstructType::Type4),
    MagneticSpaceGroupType::new(99, 99, "16.1", "16.1.99", 16, ConstructType::Type1),
    MagneticSpaceGroupType::new(100, 100, "16.2", "16.2.100", 16, ConstructType::Type2),
    MagneticSpaceGroupType::new(101, 101, "16.3", "16.3.101", 16, ConstructType::Type3),
    MagneticSpaceGroupType::new(102, 102, "16.4", "16.4.102", 16, ConstructType::Type4),
    MagneticSpaceGroupType::new(103, 134, "16.5", "21.6.134", 16, ConstructType::Type4),
    MagneticSpaceGroupType::new(104, 148, "16.6", "23.4.148", 16, ConstructType::Type4),
    MagneticSpaceGroupType::new(105, 106, "17.7", "17.1.106", 17, ConstructType::Type1),
    MagneticSpaceGroupType::new(106, 107, "17.8", "17.2.107", 17, ConstructType::Type2),
    MagneticSpaceGroupType::new(107, 108, "17.9", "17.3.108", 17, ConstructType::Type3),
    MagneticSpaceGroupType::new(108, 109, "17.10", "17.4.109", 17, ConstructType::Type3),
    MagneticSpaceGroupType::new(109, 110, "17.11", "17.5.110", 17, ConstructType::Type4),
    MagneticSpaceGroupType::new(110, 105, "17.12", "16.7.105", 17, ConstructType::Type4),
    MagneticSpaceGroupType::new(111, 138, "17.13", "21.10.138", 17, ConstructType::Type4),
    MagneticSpaceGroupType::new(112, 126, "17.14", "20.5.126", 17, ConstructType::Type4),
    MagneticSpaceGroupType::new(113, 154, "17.15", "24.5.154", 17, ConstructType::Type4),
    MagneticSpaceGroupType::new(114, 113, "18.16", "18.1.113", 18, ConstructType::Type1),
    MagneticSpaceGroupType::new(115, 114, "18.17", "18.2.114", 18, ConstructType::Type2),
    MagneticSpaceGroupType::new(116, 115, "18.18", "18.3.115", 18, ConstructType::Type3),
    MagneticSpaceGroupType::new(117, 116, "18.19", "18.4.116", 18, ConstructType::Type3),
    MagneticSpaceGroupType::new(118, 112, "18.20", "17.7.112", 18, ConstructType::Type4),
    MagneticSpaceGroupType::new(119, 117, "18.21", "18.5.117", 18, ConstructType::Type4),
    MagneticSpaceGroupType::new(120, 128, "18.22", "20.7.128", 18, ConstructType::Type4),
    MagneticSpaceGroupType::new(121, 137, "18.23", "21.9.137", 18, ConstructType::Type4),
    MagneticSpaceGroupType::new(122, 149, "18.24", "23.5.149", 18, ConstructType::Type4),
    MagneticSpaceGroupType::new(123, 119, "19.25", "19.1.119", 19, ConstructType::Type1),
    MagneticSpaceGroupType::new(124, 120, "19.26", "19.2.120", 19, ConstructType::Type2),
    MagneticSpaceGroupType::new(125, 121, "19.27", "19.3.121", 19, ConstructType::Type3),
    MagneticSpaceGroupType::new(126, 118, "19.28", "18.6.118", 19, ConstructType::Type4),
    MagneticSpaceGroupType::new(127, 127, "19.29", "20.6.127", 19, ConstructType::Type4),
    MagneticSpaceGroupType::new(128, 153, "19.30", "24.4.153", 19, ConstructType::Type4),
    MagneticSpaceGroupType::new(129, 122, "20.31", "20.1.122", 20, ConstructType::Type1),
    MagneticSpaceGroupType::new(130, 123, "20.32", "20.2.123", 20, ConstructType::Type2),
    MagneticSpaceGroupType::new(131, 124, "20.33", "20.3.124", 20, ConstructType::Type3),
    MagneticSpaceGroupType::new(132, 125, "20.34", "20.4.125", 20, ConstructType::Type3),
    MagneticSpaceGroupType::new(133, 136, "20.35", "21.8.136", 20, ConstructType::Type4),
    MagneticSpaceGroupType::new(134, 111, "20.36", "17.6.111", 20, ConstructType::Type4),
    MagneticSpaceGroupType::new(135, 144, "20.37", "22.5.144", 20, ConstructType::Type4),
    MagneticSpaceGroupType::new(136, 129, "21.38", "21.1.129", 21, ConstructType::Type1),
    MagneticSpaceGroupType::new(137, 130, "21.39", "21.2.130", 21, ConstructType::Type2),
    MagneticSpaceGroupType::new(138, 131, "21.40", "21.3.131", 21, ConstructType::Type3),
    MagneticSpaceGroupType::new(139, 132, "21.41", "21.4.132", 21, ConstructType::Type3),
    MagneticSpaceGroupType::new(140, 133, "21.42", "21.5.133", 21, ConstructType::Type4),
    MagneticSpaceGroupType::new(141, 103, "21.43", "16.5.103", 21, ConstructType::Type4),
    MagneticSpaceGroupType::new(142, 143, "21.44", "22.4.143", 21, ConstructType::Type4),
    MagneticSpaceGroupType::new(143, 140, "22.45", "22.1.140", 22, ConstructType::Type1),
    MagneticSpaceGroupType::new(144, 141, "22.46", "22.2.141", 22, ConstructType::Type2),
    MagneticSpaceGroupType::new(145, 142, "22.47", "22.3.142", 22, ConstructType::Type3),
    MagneticSpaceGroupType::new(146, 104, "22.48", "16.6.104", 22, ConstructType::Type4),
    MagneticSpaceGroupType::new(147, 145, "23.49", "23.1.145", 23, ConstructType::Type1),
    MagneticSpaceGroupType::new(148, 146, "23.50", "23.2.146", 23, ConstructType::Type2),
    MagneticSpaceGroupType::new(149, 147, "23.51", "23.3.147", 23, ConstructType::Type3),
    MagneticSpaceGroupType::new(150, 135, "23.52", "21.7.135", 23, ConstructType::Type4),
    MagneticSpaceGroupType::new(151, 150, "24.53", "24.1.150", 24, ConstructType::Type1),
    MagneticSpaceGroupType::new(152, 151, "24.54", "24.2.151", 24, ConstructType::Type2),
    MagneticSpaceGroupType::new(153, 152, "24.55", "24.3.152", 24, ConstructType::Type3),
    MagneticSpaceGroupType::new(154, 139, "24.56", "21.11.139", 24, ConstructType::Type4),
    MagneticSpaceGroupType::new(155, 155, "25.57", "25.1.155", 25, ConstructType::Type1),
    MagneticSpaceGroupType::new(156, 156, "25.58", "25.2.156", 25, ConstructType::Type2),
    MagneticSpaceGroupType::new(157, 157, "25.59", "25.3.157", 25, ConstructType::Type3),
    MagneticSpaceGroupType::new(158, 158, "25.60", "25.4.158", 25, ConstructType::Type3),
    MagneticSpaceGroupType::new(159, 159, "25.61", "25.5.159", 25, ConstructType::Type4),
    MagneticSpaceGroupType::new(160, 160, "25.62", "25.6.160", 25, ConstructType::Type4),
    MagneticSpaceGroupType::new(161, 241, "25.63", "35.6.241", 25, ConstructType::Type4),
    MagneticSpaceGroupType::new(162, 271, "25.64", "38.7.271", 25, ConstructType::Type4),
    MagneticSpaceGroupType::new(163, 328, "25.65", "44.5.328", 25, ConstructType::Type4),
    MagneticSpaceGroupType::new(164, 168, "26.66", "26.1.168", 26, ConstructType::Type1),
    MagneticSpaceGroupType::new(165, 169, "26.67", "26.2.169", 26, ConstructType::Type2),
    MagneticSpaceGroupType::new(166, 170, "26.68", "26.3.170", 26, ConstructType::Type3),
    MagneticSpaceGroupType::new(167, 171, "26.69", "26.4.171", 26, ConstructType::Type3),
    MagneticSpaceGroupType::new(168, 172, "26.70", "26.5.172", 26, ConstructType::Type3),
    MagneticSpaceGroupType::new(169, 173, "26.71", "26.6.173", 26, ConstructType::Type4),
    MagneticSpaceGroupType::new(170, 174, "26.72", "26.7.174", 26, ConstructType::Type4),
    MagneticSpaceGroupType::new(171, 164, "26.73", "25.10.164", 26, ConstructType::Type4),
    MagneticSpaceGroupType::new(172, 275, "26.74", "38.11.275", 26, ConstructType::Type4),
    MagneticSpaceGroupType::new(173, 287, "26.75", "39.10.287", 26, ConstructType::Type4),
    MagneticSpaceGroupType::new(174, 254, "26.76", "36.6.254", 26, ConstructType::Type4),
    MagneticSpaceGroupType::new(175, 345, "26.77", "46.8.345", 26, ConstructType::Type4),
    MagneticSpaceGroupType::new(176, 178, "27.78", "27.1.178", 27, ConstructType::Type1),
    MagneticSpaceGroupType::new(177, 179, "27.79", "27.2.179", 27, ConstructType::Type2),
    MagneticSpaceGroupType::new(178, 180, "27.80", "27.3.180", 27, ConstructType::Type3),
    MagneticSpaceGroupType::new(179, 181, "27.81", "27.4.181", 27, ConstructType::Type3),
    MagneticSpaceGroupType::new(180, 165, "27.82", "25.11.165", 27, ConstructType::Type4),
    MagneticSpaceGroupType::new(181, 182, "27.83", "27.5.182", 27, ConstructType::Type4),
    MagneticSpaceGroupType::new(182, 262, "27.84", "37.5.262", 27, ConstructType::Type4),
    MagneticSpaceGroupType::new(183, 289, "27.85", "39.12.289", 27, ConstructType::Type4),
    MagneticSpaceGroupType::new(184, 335, "27.86", "45.5.335", 27, ConstructType::Type4),
    MagneticSpaceGroupType::new(185, 185, "28.87", "28.1.185", 28, ConstructType::Type1),
    MagneticSpaceGroupType::new(186, 186, "28.88", "28.2.186", 28, ConstructType::Type2),
    MagneticSpaceGroupType::new(187, 187, "28.89", "28.3.187", 28, ConstructType::Type3),
    MagneticSpaceGroupType::new(188, 188, "28.90", "28.4.188", 28, ConstructType::Type3),
    MagneticSpaceGroupType::new(189, 189, "28.91", "28.5.189", 28, ConstructType::Type3),
    MagneticSpaceGroupType::new(190, 166, "28.92", "25.12.166", 28, ConstructType::Type4),
    MagneticSpaceGroupType::new(191, 190, "28.93", "28.6.190", 28, ConstructType::Type4),
    MagneticSpaceGroupType::new(192, 191, "28.94", "28.7.191", 28, ConstructType::Type4),
    MagneticSpaceGroupType::new(193, 296, "28.95", "40.6.296", 28, ConstructType::Type4),
    MagneticSpaceGroupType::new(194, 284, "28.96", "39.7.284", 28, ConstructType::Type4),
    MagneticSpaceGroupType::new(195, 245, "28.97", "35.10.245", 28, ConstructType::Type4),
    MagneticSpaceGroupType::new(196, 343, "28.98", "46.6.343", 28, ConstructType::Type4),
    MagneticSpaceGroupType::new(197, 198, "29.99", "29.1.198", 29, ConstructType::Type1),
    MagneticSpaceGroupType::new(198, 199, "29.100", "29.2.199", 29, ConstructType::Type2),
    MagneticSpaceGroupType::new(199, 200, "29.101", "29.3.200", 29, ConstructType::Type3),
    MagneticSpaceGroupType::new(200, 201, "29.102", "29.4.201", 29, ConstructType::Type3),
    MagneticSpaceGroupType::new(201, 202, "29.103", "29.5.202", 29, ConstructType::Type3),
    MagneticSpaceGroupType::new(202, 177, "29.104", "26.10.177", 29, ConstructType::Type4),
    MagneticSpaceGroupType::new(203, 203, "29.105", "29.6.203", 29, ConstructType::Type4),
    MagneticSpaceGroupType::new(204, 194, "29.106", "28.10.194", 29, ConstructType::Type4),
    MagneticSpaceGroupType::new(205, 306, "29.107", "41.7.306", 29, ConstructType::Type4),
    MagneticSpaceGroupType::new(206, 288, "29.108", "39.11.288", 29, ConstructType::Type4),
    MagneticSpaceGroupType::new(207, 255, "29.109", "36.7.255", 29, ConstructType::Type4),
    MagneticSpaceGroupType::new(208, 336, "29.110", "45.6.336", 29, ConstructType::Type4),
    MagneticSpaceGroupType::new(209, 205, "30.111", "30.1.205", 30, ConstructType::Type1),
    MagneticSpaceGroupType::new(210, 206, "30.112", "30.2.206", 30, ConstructType::Type2),
    MagneticSpaceGroupType::new(211, 207, "30.113", "30.3.207", 30, ConstructType::Type3),
    MagneticSpaceGroupType::new(212, 208, "30.114", "30.4.208", 30, ConstructType::Type3),
    MagneticSpaceGroupType::new(213, 209, "30.115", "30.5.209", 30, ConstructType::Type3),
    MagneticSpaceGroupType::new(214, 210, "30.116", "30.6.210", 30, ConstructType::Type4),
    MagneticSpaceGroupType::new(215, 184, "30.117", "27.7.184", 30, ConstructType::Type4),
    MagneticSpaceGroupType::new(216, 196, "30.118", "28.12.196", 30, ConstructType::Type4),
    MagneticSpaceGroupType::new(217, 276, "30.119", "38.12.276", 30, ConstructType::Type4),
    MagneticSpaceGroupType::new(218, 308, "30.120", "41.9.308", 30, ConstructType::Type4),
    MagneticSpaceGroupType::new(219, 263, "30.121", "37.6.263", 30, ConstructType::Type4),
    MagneticSpaceGroupType::new(220, 346, "30.122", "46.9.346", 30, ConstructType::Type4),
    MagneticSpaceGroupType::new(221, 212, "31.123", "31.1.212", 31, ConstructType::Type1),
    MagneticSpaceGroupType::new(222, 213, "31.124", "31.2.213", 31, ConstructType::Type2),
    MagneticSpaceGroupType::new(223, 214, "31.125", "31.3.214", 31, ConstructType::Type3),
    MagneticSpaceGroupType::new(224, 215, "31.126", "31.4.215", 31, ConstructType::Type3),
    MagneticSpaceGroupType::new(225, 216, "31.127", "31.5.216", 31, ConstructType::Type3),
    MagneticSpaceGroupType::new(226, 176, "31.128", "26.9.176", 31, ConstructType::Type4),
    MagneticSpaceGroupType::new(227, 217, "31.129", "31.6.217", 31, ConstructType::Type4),
    MagneticSpaceGroupType::new(228, 195, "31.130", "28.11.195", 31, ConstructType::Type4),
    MagneticSpaceGroupType::new(229, 298, "31.131", "40.8.298", 31, ConstructType::Type4),
    MagneticSpaceGroupType::new(230, 274, "31.132", "38.10.274", 31, ConstructType::Type4),
    MagneticSpaceGroupType::new(231, 256, "31.133", "36.8.256", 31, ConstructType::Type4),
    MagneticSpaceGroupType::new(232, 329, "31.134", "44.6.329", 31, ConstructType::Type4),
    MagneticSpaceGroupType::new(233, 219, "32.135", "32.1.219", 32, ConstructType::Type1),
    MagneticSpaceGroupType::new(234, 220, "32.136", "32.2.220", 32, ConstructType::Type2),
    MagneticSpaceGroupType::new(235, 221, "32.137", "32.3.221", 32, ConstructType::Type3),
    MagneticSpaceGroupType::new(236, 222, "32.138", "32.4.222", 32, ConstructType::Type3),
    MagneticSpaceGroupType::new(237, 223, "32.139", "32.5.223", 32, ConstructType::Type4),
    MagneticSpaceGroupType::new(238, 193, "32.140", "28.9.193", 32, ConstructType::Type4),
    MagneticSpaceGroupType::new(239, 246, "32.141", "35.11.246", 32, ConstructType::Type4),
    MagneticSpaceGroupType::new(240, 305, "32.142", "41.6.305", 32, ConstructType::Type4),
    MagneticSpaceGroupType::new(241, 337, "32.143", "45.7.337", 32, ConstructType::Type4),
    MagneticSpaceGroupType::new(242, 226, "33.144", "33.1.226", 33, ConstructType::Type1),
    MagneticSpaceGroupType::new(243, 227, "33.145", "33.2.227", 33, ConstructType::Type2),
    MagneticSpaceGroupType::new(244, 228, "33.146", "33.3.228", 33, ConstructType::Type3),
    MagneticSpaceGroupType::new(245, 229, "33.147", "33.4.229", 33, ConstructType::Type3),
    MagneticSpaceGroupType::new(246, 230, "33.148", "33.5.230", 33, ConstructType::Type3),
    MagneticSpaceGroupType::new(247, 218, "33.149", "31.7.218", 33, ConstructType::Type4),
    MagneticSpaceGroupType::new(248, 204, "33.150", "29.7.204", 33, ConstructType::Type4),
    MagneticSpaceGroupType::new(249, 224, "33.151", "32.6.224", 33, ConstructType::Type4),
    MagneticSpaceGroupType::new(250, 297, "33.152", "40.7.297", 33, ConstructType::Type4),
    MagneticSpaceGroupType::new(251, 307, "33.153", "41.8.307", 33, ConstructType::Type4),
    MagneticSpaceGroupType::new(252, 257, "33.154", "36.9.257", 33, ConstructType::Type4),
    MagneticSpaceGroupType::new(253, 344, "33.155", "46.7.344", 33, ConstructType::Type4),
    MagneticSpaceGroupType::new(254, 231, "34.156", "34.1.231", 34, ConstructType::Type1),
    MagneticSpaceGroupType::new(255, 232, "34.157", "34.2.232", 34, ConstructType::Type2),
    MagneticSpaceGroupType::new(256, 233, "34.158", "34.3.233", 34, ConstructType::Type3),
    MagneticSpaceGroupType::new(257, 234, "34.159", "34.4.234", 34, ConstructType::Type3),
    MagneticSpaceGroupType::new(258, 211, "34.160", "30.7.211", 34, ConstructType::Type4),
    MagneticSpaceGroupType::new(259, 225, "34.161", "32.7.225", 34, ConstructType::Type4),
    MagneticSpaceGroupType::new(260, 299, "34.162", "40.9.299", 34, ConstructType::Type4),
    MagneticSpaceGroupType::new(261, 264, "34.163", "37.7.264", 34, ConstructType::Type4),
    MagneticSpaceGroupType::new(262, 330, "34.164", "44.7.330", 34, ConstructType::Type4),
    MagneticSpaceGroupType::new(263, 236, "35.165", "35.1.236", 35, ConstructType::Type1),
    MagneticSpaceGroupType::new(264, 237, "35.166", "35.2.237", 35, ConstructType::Type2),
    MagneticSpaceGroupType::new(265, 238, "35.167", "35.3.238", 35, ConstructType::Type3),
    MagneticSpaceGroupType::new(266, 239, "35.168", "35.4.239", 35, ConstructType::Type3),
    MagneticSpaceGroupType::new(267, 240, "35.169", "35.5.240", 35, ConstructType::Type4),
    MagneticSpaceGroupType::new(268, 161, "35.170", "25.7.161", 35, ConstructType::Type4),
    MagneticSpaceGroupType::new(269, 313, "35.171", "42.5.313", 35, ConstructType::Type4),
    MagneticSpaceGroupType::new(270, 249, "36.172", "36.1.249", 36, ConstructType::Type1),
    MagneticSpaceGroupType::new(271, 250, "36.173", "36.2.250", 36, ConstructType::Type2),
    MagneticSpaceGroupType::new(272, 251, "36.174", "36.3.251", 36, ConstructType::Type3),
    MagneticSpaceGroupType::new(273, 252, "36.175", "36.4.252", 36, ConstructType::Type3),
    MagneticSpaceGroupType::new(274, 253, "36.176", "36.5.253", 36, ConstructType::Type3),
    MagneticSpaceGroupType::new(275, 243, "36.177", "35.8.243", 36, ConstructType::Type4),
    MagneticSpaceGroupType::new(276, 175, "36.178", "26.8.175", 36, ConstructType::Type4),
    MagneticSpaceGroupType::new(277, 315, "36.179", "42.7.315", 36, ConstructType::Type4),
    MagneticSpaceGroupType::new(278, 258, "37.180", "37.1.258", 37, ConstructType::Type1),
    MagneticSpaceGroupType::new(279, 259, "37.181", "37.2.259", 37, ConstructType::Type2),
    MagneticSpaceGroupType::new(280, 260, "37.182", "37.3.260", 37, ConstructType::Type3),
    MagneticSpaceGroupType::new(281, 261, "37.183", "37.4.261", 37, ConstructType::Type3),
    MagneticSpaceGroupType::new(282, 244, "37.184", "35.9.244", 37, ConstructType::Type4),
    MagneticSpaceGroupType::new(283, 183, "37.185", "27.6.183", 37, ConstructType::Type4),
    MagneticSpaceGroupType::new(284, 316, "37.186", "42.8.316", 37, ConstructType::Type4),
    MagneticSpaceGroupType::new(285, 265, "38.187", "38.1.265", 38, ConstructType::Type1),
    MagneticSpaceGroupType::new(286, 266, "38.188", "38.2.266", 38, ConstructType::Type2),
    MagneticSpaceGroupType::new(287, 267, "38.189", "38.3.267", 38, ConstructType::Type3),
    MagneticSpaceGroupType::new(288, 268, "38.190", "38.4.268", 38, ConstructType::Type3),
    MagneticSpaceGroupType::new(289, 269, "38.191", "38.5.269", 38, ConstructType::Type3),
    MagneticSpaceGroupType::new(290, 270, "38.192", "38.6.270", 38, ConstructType::Type4),
    MagneticSpaceGroupType::new(291, 162, "38.193", "25.8.162", 38, ConstructType::Type4),
    MagneticSpaceGroupType::new(292, 314, "38.194", "42.6.314", 38, ConstructType::Type4),
    MagneticSpaceGroupType::new(293, 278, "39.195", "39.1.278", 39, ConstructType::Type1),
    MagneticSpaceGroupType::new(294, 279, "39.196", "39.2.279", 39, ConstructType::Type2),
    MagneticSpaceGroupType::new(295, 280, "39.197", "39.3.280", 39, ConstructType::Type3),
    MagneticSpaceGroupType::new(296, 281, "39.198", "39.4.281", 39, ConstructType::Type3),
    MagneticSpaceGroupType::new(297, 282, "39.199", "39.5.282", 39, ConstructType::Type3),
    MagneticSpaceGroupType::new(298, 283, "39.200", "39.6.283", 39, ConstructType::Type4),
    MagneticSpaceGroupType::new(299, 167, "39.201", "25.13.167", 39, ConstructType::Type4),
    MagneticSpaceGroupType::new(300, 317, "39.202", "42.9.317", 39, ConstructType::Type4),
    MagneticSpaceGroupType::new(301, 291, "40.203", "40.1.291", 40, ConstructType::Type1),
    MagneticSpaceGroupType::new(302, 292, "40.204", "40.2.292", 40, ConstructType::Type2),
    MagneticSpaceGroupType::new(303, 293, "40.205", "40.3.293", 40, ConstructType::Type3),
    MagneticSpaceGroupType::new(304, 294, "40.206", "40.4.294", 40, ConstructType::Type3),
    MagneticSpaceGroupType::new(305, 295, "40.207", "40.5.295", 40, ConstructType::Type3),
    MagneticSpaceGroupType::new(306, 273, "40.208", "38.9.273", 40, ConstructType::Type4),
    MagneticSpaceGroupType::new(307, 192, "40.209", "28.8.192", 40, ConstructType::Type4),
    MagneticSpaceGroupType::new(308, 318, "40.210", "42.10.318", 40, ConstructType::Type4),
    MagneticSpaceGroupType::new(309, 300, "41.211", "41.1.300", 41, ConstructType::Type1),
    MagneticSpaceGroupType::new(310, 301, "41.212", "41.2.301", 41, ConstructType::Type2),
    MagneticSpaceGroupType::new(311, 302, "41.213", "41.3.302", 41, ConstructType::Type3),
    MagneticSpaceGroupType::new(312, 303, "41.214", "41.4.303", 41, ConstructType::Type3),
    MagneticSpaceGroupType::new(313, 304, "41.215", "41.5.304", 41, ConstructType::Type3),
    MagneticSpaceGroupType::new(314, 286, "41.216", "39.9.286", 41, ConstructType::Type4),
    MagneticSpaceGroupType::new(315, 197, "41.217", "28.13.197", 41, ConstructType::Type4),
    MagneticSpaceGroupType::new(316, 319, "41.218", "42.11.319", 41, ConstructType::Type4),
    MagneticSpaceGroupType::new(317, 309, "42.219", "42.1.309", 42, ConstructType::Type1),
    MagneticSpaceGroupType::new(318, 310, "42.220", "42.2.310", 42, ConstructType::Type2),
    MagneticSpaceGroupType::new(319, 311, "42.221", "42.3.311", 42, ConstructType::Type3),
    MagneticSpaceGroupType::new(320, 312, "42.222", "42.4.312", 42, ConstructType::Type3),
    MagneticSpaceGroupType::new(321, 163, "42.223", "25.9.163", 42, ConstructType::Type4),
    MagneticSpaceGroupType::new(322, 320, "43.224", "43.1.320", 43, ConstructType::Type1),
    MagneticSpaceGroupType::new(323, 321, "43.225", "43.2.321", 43, ConstructType::Type2),
    MagneticSpaceGroupType::new(324, 322, "43.226", "43.3.322", 43, ConstructType::Type3),
    MagneticSpaceGroupType::new(325, 323, "43.227", "43.4.323", 43, ConstructType::Type3),
    MagneticSpaceGroupType::new(326, 235, "43.228", "34.5.235", 43, ConstructType::Type4),
    MagneticSpaceGroupType::new(327, 324, "44.229", "44.1.324", 44, ConstructType::Type1),
    MagneticSpaceGroupType::new(328, 325, "44.230", "44.2.325", 44, ConstructType::Type2),
    MagneticSpaceGroupType::new(329, 326, "44.231", "44.3.326", 44, ConstructType::Type3),
    MagneticSpaceGroupType::new(330, 327, "44.232", "44.4.327", 44, ConstructType::Type3),
    MagneticSpaceGroupType::new(331, 242, "44.233", "35.7.242", 44, ConstructType::Type4),
    MagneticSpaceGroupType::new(332, 272, "44.234", "38.8.272", 44, ConstructType::Type4),
    MagneticSpaceGroupType::new(333, 331, "45.235", "45.1.331", 45, ConstructType::Type1),
    MagneticSpaceGroupType::new(334, 332, "45.236", "45.2.332", 45, ConstructType::Type2),
    MagneticSpaceGroupType::new(335, 333, "45.237", "45.3.333", 45, ConstructType::Type3),
    MagneticSpaceGroupType::new(336, 334, "45.238", "45.4.334", 45, ConstructType::Type3),
    MagneticSpaceGroupType::new(337, 248, "45.239", "35.13.248", 45, ConstructType::Type4),
    MagneticSpaceGroupType::new(338, 290, "45.240", "39.13.290", 45, ConstructType::Type4),
    MagneticSpaceGroupType::new(339, 338, "46.241", "46.1.338", 46, ConstructType::Type1),
    MagneticSpaceGroupType::new(340, 339, "46.242", "46.2.339", 46, ConstructType::Type2),
    MagneticSpaceGroupType::new(341, 340, "46.243", "46.3.340", 46, ConstructType::Type3),
    MagneticSpaceGroupType::new(342, 341, "46.244", "46.4.341", 46, ConstructType::Type3),
    MagneticSpaceGroupType::new(343, 342, "46.245", "46.5.342", 46, ConstructType::Type3),
    MagneticSpaceGroupType::new(344, 247, "46.246", "35.12.247", 46, ConstructType::Type4),
    MagneticSpaceGroupType::new(345, 277, "46.247", "38.13.277", 46, ConstructType::Type4),
    MagneticSpaceGroupType::new(346, 285, "46.248", "39.8.285", 46, ConstructType::Type4),
    MagneticSpaceGroupType::new(347, 347, "47.249", "47.1.347", 47, ConstructType::Type1),
    MagneticSpaceGroupType::new(348, 348, "47.250", "47.2.348", 47, ConstructType::Type2),
    MagneticSpaceGroupType::new(349, 349, "47.251", "47.3.349", 47, ConstructType::Type3),
    MagneticSpaceGroupType::new(350, 350, "47.252", "47.4.350", 47, ConstructType::Type3),
    MagneticSpaceGroupType::new(351, 351, "47.253", "47.5.351", 47, ConstructType::Type3),
    MagneticSpaceGroupType::new(352, 352, "47.254", "47.6.352", 47, ConstructType::Type4),
    MagneticSpaceGroupType::new(353, 553, "47.255", "65.9.553", 47, ConstructType::Type4),
    MagneticSpaceGroupType::new(354, 626, "47.256", "71.6.626", 47, ConstructType::Type4),
    MagneticSpaceGroupType::new(355, 358, "48.257", "48.1.358", 48, ConstructType::Type1),
    MagneticSpaceGroupType::new(356, 359, "48.258", "48.2.359", 48, ConstructType::Type2),
    MagneticSpaceGroupType::new(357, 360, "48.259", "48.3.360", 48, ConstructType::Type3),
    MagneticSpaceGroupType::new(358, 361, "48.260", "48.4.361", 48, ConstructType::Type3),
    MagneticSpaceGroupType::new(359, 362, "48.261", "48.5.362", 48, ConstructType::Type3),
    MagneticSpaceGroupType::new(360, 386, "48.262", "50.10.386", 48, ConstructType::Type4),
    MagneticSpaceGroupType::new(361, 576, "48.263", "66.13.576", 48, ConstructType::Type4),
    MagneticSpaceGroupType::new(362, 629, "48.264", "71.9.629", 48, ConstructType::Type4),
    MagneticSpaceGroupType::new(363, 364, "49.265", "49.1.364", 49, ConstructType::Type1),
    MagneticSpaceGroupType::new(364, 365, "49.266", "49.2.365", 49, ConstructType::Type2),
    MagneticSpaceGroupType::new(365, 366, "49.267", "49.3.366", 49, ConstructType::Type3),
    MagneticSpaceGroupType::new(366, 367, "49.268", "49.4.367", 49, ConstructType::Type3),
    MagneticSpaceGroupType::new(367, 368, "49.269", "49.5.368", 49, ConstructType::Type3),
    MagneticSpaceGroupType::new(368, 369, "49.270", "49.6.369", 49, ConstructType::Type3),
    MagneticSpaceGroupType::new(369, 370, "49.271", "49.7.370", 49, ConstructType::Type3),
    MagneticSpaceGroupType::new(370, 371, "49.272", "49.8.371", 49, ConstructType::Type4),
    MagneticSpaceGroupType::new(371, 356, "49.273", "47.10.356", 49, ConstructType::Type4),
    MagneticSpaceGroupType::new(372, 585, "49.274", "67.9.585", 49, ConstructType::Type4),
    MagneticSpaceGroupType::new(373, 571, "49.275", "66.8.571", 49, ConstructType::Type4),
    MagneticSpaceGroupType::new(374, 637, "49.276", "72.8.637", 49, ConstructType::Type4),
    MagneticSpaceGroupType::new(375, 377, "50.277", "50.1.377", 50, ConstructType::Type1),
    MagneticSpaceGroupType::new(376, 378, "50.278", "50.2.378", 50, ConstructType::Type2),
    MagneticSpaceGroupType::new(377, 379, "50.279", "50.3.379", 50, ConstructType::Type3),
    MagneticSpaceGroupType::new(378, 380, "50.280", "50.4.380", 50, ConstructType::Type3),
    MagneticSpaceGroupType::new(379, 381, "50.281", "50.5.381", 50, ConstructType::Type3),
    MagneticSpaceGroupType::new(380, 382, "50.282", "50.6.382", 50, ConstructType::Type3),
    MagneticSpaceGroupType::new(381, 383, "50.283", "50.7.383", 50, ConstructType::Type3),
    MagneticSpaceGroupType::new(382, 375, "50.284", "49.12.375", 50, ConstructType::Type4),
    MagneticSpaceGroupType::new(383, 384, "50.285", "50.8.384", 50, ConstructType::Type4),
    MagneticSpaceGroupType::new(384, 601, "50.286", "68.8.601", 50, ConstructType::Type4),
    MagneticSpaceGroupType::new(385, 561, "50.287", "65.17.561", 50, ConstructType::Type4),
    MagneticSpaceGroupType::new(386, 642, "50.288", "72.13.642", 50, ConstructType::Type4),
    MagneticSpaceGroupType::new(387, 387, "51.289", "51.1.387", 51, ConstructType::Type1),
    MagneticSpaceGroupType::new(388, 388, "51.290", "51.2.388", 51, ConstructType::Type2),
    MagneticSpaceGroupType::new(389, 389, "51.291", "51.3.389", 51, ConstructType::Type3),
    MagneticSpaceGroupType::new(390, 390, "51.292", "51.4.390", 51, ConstructType::Type3),
    MagneticSpaceGroupType::new(391, 391, "51.293", "51.5.391", 51, ConstructType::Type3),
    MagneticSpaceGroupType::new(392, 392, "51.294", "51.6.392", 51, ConstructType::Type3),
    MagneticSpaceGroupType::new(393, 393, "51.295", "51.7.393", 51, ConstructType::Type3),
    MagneticSpaceGroupType::new(394, 394, "51.296", "51.8.394", 51, ConstructType::Type3),
    MagneticSpaceGroupType::new(395, 395, "51.297", "51.9.395", 51, ConstructType::Type3),
    MagneticSpaceGroupType::new(396, 355, "51.298", "47.9.355", 51, ConstructType::Type4),
    MagneticSpaceGroupType::new(397, 396, "51.299", "51.10.396", 51, ConstructType::Type4),
    MagneticSpaceGroupType::new(398, 397, "51.300", "51.11.397", 51, ConstructType::Type4),
    MagneticSpaceGroupType::new(399, 520, "51.301", "63.10.520", 51, ConstructType::Type4),
    MagneticSpaceGroupType::new(400, 557, "51.302", "65.13.557", 51, ConstructType::Type4),
    MagneticSpaceGroupType::new(401, 590, "51.303", "67.14.590", 51, ConstructType::Type4),
    MagneticSpaceGroupType::new(402, 657, "51.304", "74.8.657", 51, ConstructType::Type4),
    MagneticSpaceGroupType::new(403, 406, "52.305", "52.1.406", 52, ConstructType::Type1),
    MagneticSpaceGroupType::new(404, 407, "52.306", "52.2.407", 52, ConstructType::Type2),
    MagneticSpaceGroupType::new(405, 408, "52.307", "52.3.408", 52, ConstructType::Type3),
    MagneticSpaceGroupType::new(406, 409, "52.308", "52.4.409", 52, ConstructType::Type3),
    MagneticSpaceGroupType::new(407, 410, "52.309", "52.5.410", 52, ConstructType::Type3),
    MagneticSpaceGroupType::new(408, 411, "52.310", "52.6.411", 52, ConstructType::Type3),
    MagneticSpaceGroupType::new(409, 412, "52.311", "52.7.412", 52, ConstructType::Type3),
    MagneticSpaceGroupType::new(410, 413, "52.312", "52.8.413", 52, ConstructType::Type3),
    MagneticSpaceGroupType::new(411, 414, "52.313", "52.9.414", 52, ConstructType::Type3),
    MagneticSpaceGroupType::new(412, 427, "52.314", "53.13.427", 52, ConstructType::Type4),
    MagneticSpaceGroupType::new(413, 385, "52.315", "50.9.385", 52, ConstructType::Type4),
    MagneticSpaceGroupType::new(414, 440, "52.316", "54.13.440", 52, ConstructType::Type4),
    MagneticSpaceGroupType::new(415, 575, "52.317", "66.12.575", 52, ConstructType::Type4),
    MagneticSpaceGroupType::new(416, 527, "52.318", "63.17.527", 52, ConstructType::Type4),
    MagneticSpaceGroupType::new(417, 604, "52.319", "68.11.604", 52, ConstructType::Type4),
    MagneticSpaceGroupType::new(418, 658, "52.320", "74.9.658", 52, ConstructType::Type4),
    MagneticSpaceGroupType::new(419, 415, "53.321", "53.1.415", 53, ConstructType::Type1),
    MagneticSpaceGroupType::new(420, 416, "53.322", "53.2.416", 53, ConstructType::Type2),
    MagneticSpaceGroupType::new(421, 417, "53.323", "53.3.417", 53, ConstructType::Type3),
    MagneticSpaceGroupType::new(422, 418, "53.324", "53.4.418", 53, ConstructType::Type3),
    MagneticSpaceGroupType::new(423, 419, "53.325", "53.5.419", 53, ConstructType::Type3),
    MagneticSpaceGroupType::new(424, 420, "53.326", "53.6.420", 53, ConstructType::Type3),
    MagneticSpaceGroupType::new(425, 421, "53.327", "53.7.421", 53, ConstructType::Type3),
    MagneticSpaceGroupType::new(426, 422, "53.328", "53.8.422", 53, ConstructType::Type3),
    MagneticSpaceGroupType::new(427, 423, "53.329", "53.9.423", 53, ConstructType::Type3),
    MagneticSpaceGroupType::new(428, 401, "53.330", "51.15.401", 53, ConstructType::Type4),
    MagneticSpaceGroupType::new(429, 424, "53.331", "53.10.424", 53, ConstructType::Type4),
    MagneticSpaceGroupType::new(430, 374, "53.332", "49.11.374", 53, ConstructType::Type4),
    MagneticSpaceGroupType::new(431, 572, "53.333", "66.9.572", 53, ConstructType::Type4),
    MagneticSpaceGroupType::new(432, 560, "53.334", "65.16.560", 53, ConstructType::Type4),
    MagneticSpaceGroupType::new(433, 542, "53.335", "64.15.542", 53, ConstructType::Type4),
    MagneticSpaceGroupType::new(434, 659, "53.336", "74.10.659", 53, ConstructType::Type4),
    MagneticSpaceGroupType::new(435, 428, "54.337", "54.1.428", 54, ConstructType::Type1),
    MagneticSpaceGroupType::new(436, 429, "54.338", "54.2.429", 54, ConstructType::Type2),
    MagneticSpaceGroupType::new(437, 430, "54.339", "54.3.430", 54, ConstructType::Type3),
    MagneticSpaceGroupType::new(438, 431, "54.340", "54.4.431", 54, ConstructType::Type3),
    MagneticSpaceGroupType::new(439, 432, "54.341", "54.5.432", 54, ConstructType::Type3),
    MagneticSpaceGroupType::new(440, 433, "54.342", "54.6.433", 54, ConstructType::Type3),
    MagneticSpaceGroupType::new(441, 434, "54.343", "54.7.434", 54, ConstructType::Type3),
    MagneticSpaceGroupType::new(442, 435, "54.344", "54.8.435", 54, ConstructType::Type3),
    MagneticSpaceGroupType::new(443, 436, "54.345", "54.9.436", 54, ConstructType::Type3),
    MagneticSpaceGroupType::new(444, 373, "54.346", "49.10.373", 54, ConstructType::Type4),
    MagneticSpaceGroupType::new(445, 437, "54.347", "54.10.437", 54, ConstructType::Type4),
    MagneticSpaceGroupType::new(446, 404, "54.348", "51.18.404", 54, ConstructType::Type4),
    MagneticSpaceGroupType::new(447, 538, "54.349", "64.11.538", 54, ConstructType::Type4),
    MagneticSpaceGroupType::new(448, 589, "54.350", "67.13.589", 54, ConstructType::Type4),
    MagneticSpaceGroupType::new(449, 602, "54.351", "68.9.602", 54, ConstructType::Type4),
    MagneticSpaceGroupType::new(450, 649, "54.352", "73.7.649", 54, ConstructType::Type4),
    MagneticSpaceGroupType::new(451, 441, "55.353", "55.1.441", 55, ConstructType::Type1),
    MagneticSpaceGroupType::new(452, 442, "55.354", "55.2.442", 55, ConstructType::Type2),
    MagneticSpaceGroupType::new(453, 443, "55.355", "55.3.443", 55, ConstructType::Type3),
    MagneticSpaceGroupType::new(454, 444, "55.356", "55.4.444", 55, ConstructType::Type3),
    MagneticSpaceGroupType::new(455, 445, "55.357", "55.5.445", 55, ConstructType::Type3),
    MagneticSpaceGroupType::new(456, 446, "55.358", "55.6.446", 55, ConstructType::Type3),
    MagneticSpaceGroupType::new(457, 447, "55.359", "55.7.447", 55, ConstructType::Type3),
    MagneticSpaceGroupType::new(458, 402, "55.360", "51.16.402", 55, ConstructType::Type4),
    MagneticSpaceGroupType::new(459, 448, "55.361", "55.8.448", 55, ConstructType::Type4),
    MagneticSpaceGroupType::new(460, 537, "55.362", "64.10.537", 55, ConstructType::Type4),
    MagneticSpaceGroupType::new(461, 559, "55.363", "65.15.559", 55, ConstructType::Type4),
    MagneticSpaceGroupType::new(462, 640, "55.364", "72.11.640", 55, ConstructType::Type4),
    MagneticSpaceGroupType::new(463, 451, "56.365", "56.1.451", 56, ConstructType::Type1),
    MagneticSpaceGroupType::new(464, 452, "56.366", "56.2.452", 56, ConstructType::Type2),
    MagneticSpaceGroupType::new(465, 453, "56.367", "56.3.453", 56, ConstructType::Type3),
    MagneticSpaceGroupType::new(466, 454, "56.368", "56.4.454", 56, ConstructType::Type3),
    MagneticSpaceGroupType::new(467, 455, "56.369", "56.5.455", 56, ConstructType::Type3),
    MagneticSpaceGroupType::new(468, 456, "56.370", "56.6.456", 56, ConstructType::Type3),
    MagneticSpaceGroupType::new(469, 457, "56.371", "56.7.457", 56, ConstructType::Type3),
    MagneticSpaceGroupType::new(470, 439, "56.372", "54.12.439", 56, ConstructType::Type4),
    MagneticSpaceGroupType::new(471, 487, "56.373", "59.10.487", 56, ConstructType::Type4),
    MagneticSpaceGroupType::new(472, 541, "56.374", "64.14.541", 56, ConstructType::Type4),
    MagneticSpaceGroupType::new(473, 573, "56.375", "66.10.573", 56, ConstructType::Type4),
    MagneticSpaceGroupType::new(474, 639, "56.376", "72.10.639", 56, ConstructType::Type4),
    MagneticSpaceGroupType::new(475, 458, "57.377", "57.1.458", 57, ConstructType::Type1),
    MagneticSpaceGroupType::new(476, 459, "57.378", "57.2.459", 57, ConstructType::Type2),
    MagneticSpaceGroupType::new(477, 460, "57.379", "57.3.460", 57, ConstructType::Type3),
    MagneticSpaceGroupType::new(478, 461, "57.380", "57.4.461", 57, ConstructType::Type3),
    MagneticSpaceGroupType::new(479, 462, "57.381", "57.5.462", 57, ConstructType::Type3),
    MagneticSpaceGroupType::new(480, 463, "57.382", "57.6.463", 57, ConstructType::Type3),
    MagneticSpaceGroupType::new(481, 464, "57.383", "57.7.464", 57, ConstructType::Type3),
    MagneticSpaceGroupType::new(482, 465, "57.384", "57.8.465", 57, ConstructType::Type3),
    MagneticSpaceGroupType::new(483, 466, "57.385", "57.9.466", 57, ConstructType::Type3),
    MagneticSpaceGroupType::new(484, 467, "57.386", "57.10.467", 57, ConstructType::Type4),
    MagneticSpaceGroupType::new(485, 403, "57.387", "51.17.403", 57, ConstructType::Type4),
    MagneticSpaceGroupType::new(486, 399, "57.388", "51.13.399", 57, ConstructType::Type4),
    MagneticSpaceGroupType::new(487, 591, "57.389", "67.15.591", 57, ConstructType::Type4),
    MagneticSpaceGroupType::new(488, 540, "57.390", "64.13.540", 57, ConstructType::Type4),
    MagneticSpaceGroupType::new(489, 521, "57.391", "63.11.521", 57, ConstructType::Type4),
    MagneticSpaceGroupType::new(490, 638, "57.392", "72.9.638", 57, ConstructType::Type4),
    MagneticSpaceGroupType::new(491, 471, "58.393", "58.1.471", 58, ConstructType::Type1),
    MagneticSpaceGroupType::new(492, 472, "58.394", "58.2.472", 58, ConstructType::Type2),
    MagneticSpaceGroupType::new(493, 473, "58.395", "58.3.473", 58, ConstructType::Type3),
    MagneticSpaceGroupType::new(494, 474, "58.396", "58.4.474", 58, ConstructType::Type3),
    MagneticSpaceGroupType::new(495, 475, "58.397", "58.5.475", 58, ConstructType::Type3),
    MagneticSpaceGroupType::new(496, 476, "58.398", "58.6.476", 58, ConstructType::Type3),
    MagneticSpaceGroupType::new(497, 477, "58.399", "58.7.477", 58, ConstructType::Type3),
    MagneticSpaceGroupType::new(498, 426, "58.400", "53.12.426", 58, ConstructType::Type4),
    MagneticSpaceGroupType::new(499, 450, "58.401", "55.10.450", 58, ConstructType::Type4),
    MagneticSpaceGroupType::new(500, 525, "58.402", "63.15.525", 58, ConstructType::Type4),
    MagneticSpaceGroupType::new(501, 574, "58.403", "66.11.574", 58, ConstructType::Type4),
    MagneticSpaceGroupType::new(502, 628, "58.404", "71.8.628", 58, ConstructType::Type4),
    MagneticSpaceGroupType::new(503, 478, "59.405", "59.1.478", 59, ConstructType::Type1),
    MagneticSpaceGroupType::new(504, 479, "59.406", "59.2.479", 59, ConstructType::Type2),
    MagneticSpaceGroupType::new(505, 480, "59.407", "59.3.480", 59, ConstructType::Type3),
    MagneticSpaceGroupType::new(506, 481, "59.408", "59.4.481", 59, ConstructType::Type3),
    MagneticSpaceGroupType::new(507, 482, "59.409", "59.5.482", 59, ConstructType::Type3),
    MagneticSpaceGroupType::new(508, 483, "59.410", "59.6.483", 59, ConstructType::Type3),
    MagneticSpaceGroupType::new(509, 484, "59.411", "59.7.484", 59, ConstructType::Type3),
    MagneticSpaceGroupType::new(510, 400, "59.412", "51.14.400", 59, ConstructType::Type4),
    MagneticSpaceGroupType::new(511, 485, "59.413", "59.8.485", 59, ConstructType::Type4),
    MagneticSpaceGroupType::new(512, 522, "59.414", "63.12.522", 59, ConstructType::Type4),
    MagneticSpaceGroupType::new(513, 558, "59.415", "65.14.558", 59, ConstructType::Type4),
    MagneticSpaceGroupType::new(514, 627, "59.416", "71.7.627", 59, ConstructType::Type4),
    MagneticSpaceGroupType::new(515, 488, "60.417", "60.1.488", 60, ConstructType::Type1),
    MagneticSpaceGroupType::new(516, 489, "60.418", "60.2.489", 60, ConstructType::Type2),
    MagneticSpaceGroupType::new(517, 490, "60.419", "60.3.490", 60, ConstructType::Type3),
    MagneticSpaceGroupType::new(518, 491, "60.420", "60.4.491", 60, ConstructType::Type3),
    MagneticSpaceGroupType::new(519, 492, "60.421", "60.5.492", 60, ConstructType::Type3),
    MagneticSpaceGroupType::new(520, 493, "60.422", "60.6.493", 60, ConstructType::Type3),
    MagneticSpaceGroupType::new(521, 494, "60.423", "60.7.494", 60, ConstructType::Type3),
    MagneticSpaceGroupType::new(522, 495, "60.424", "60.8.495", 60, ConstructType::Type3),
    MagneticSpaceGroupType::new(523, 496, "60.425", "60.9.496", 60, ConstructType::Type3),
    MagneticSpaceGroupType::new(524, 438, "60.426", "54.11.438", 60, ConstructType::Type4),
    MagneticSpaceGroupType::new(525, 470, "60.427", "57.13.470", 60, ConstructType::Type4),
    MagneticSpaceGroupType::new(526, 425, "60.428", "53.11.425", 60, ConstructType::Type4),
    MagneticSpaceGroupType::new(527, 544, "60.429", "64.17.544", 60, ConstructType::Type4),
    MagneticSpaceGroupType::new(528, 603, "60.430", "68.10.603", 60, ConstructType::Type4),
    MagneticSpaceGroupType::new(529, 526, "60.431", "63.16.526", 60, ConstructType::Type4),
    MagneticSpaceGroupType::new(530, 641, "60.432", "72.12.641", 60, ConstructType::Type4),
    MagneticSpaceGroupType::new(531, 497, "61.433", "61.1.497", 61, ConstructType::Type1),
    MagneticSpaceGroupType::new(532, 498, "61.434", "61.2.498", 61, ConstructType::Type2),
    MagneticSpaceGroupType::new(533, 499, "61.435", "61.3.499", 61, ConstructType::Type3),
    MagneticSpaceGroupType::new(534, 500, "61.436", "61.4.500", 61, ConstructType::Type3),
    MagneticSpaceGroupType::new(535, 501, "61.437", "61.5.501", 61, ConstructType::Type3),
    MagneticSpaceGroupType::new(536, 469, "61.438", "57.12.469", 61, ConstructType::Type4),
    MagneticSpaceGroupType::new(537, 543, "61.439", "64.16.543", 61, ConstructType::Type4),
    MagneticSpaceGroupType::new(538, 648, "61.440", "73.6.648", 61, ConstructType::Type4),
    MagneticSpaceGroupType::new(539, 502, "62.441", "62.1.502", 62, ConstructType::Type1),
    MagneticSpaceGroupType::new(540, 503, "62.442", "62.2.503", 62, ConstructType::Type2),
    MagneticSpaceGroupType::new(541, 504, "62.443", "62.3.504", 62, ConstructType::Type3),
    MagneticSpaceGroupType::new(542, 505, "62.444", "62.4.505", 62, ConstructType::Type3),
    MagneticSpaceGroupType::new(543, 506, "62.445", "62.5.506", 62, ConstructType::Type3),
    MagneticSpaceGroupType::new(544, 507, "62.446", "62.6.507", 62, ConstructType::Type3),
    MagneticSpaceGroupType::new(545, 508, "62.447", "62.7.508", 62, ConstructType::Type3),
    MagneticSpaceGroupType::new(546, 509, "62.448", "62.8.509", 62, ConstructType::Type3),
    MagneticSpaceGroupType::new(547, 510, "62.449", "62.9.510", 62, ConstructType::Type3),
    MagneticSpaceGroupType::new(548, 486, "62.450", "59.9.486", 62, ConstructType::Type4),
    MagneticSpaceGroupType::new(549, 449, "62.451", "55.9.449", 62, ConstructType::Type4),
    MagneticSpaceGroupType::new(550, 468, "62.452", "57.11.468", 62, ConstructType::Type4),
    MagneticSpaceGroupType::new(551, 523, "62.453", "63.13.523", 62, ConstructType::Type4),
    MagneticSpaceGroupType::new(552, 524, "62.454", "63.14.524", 62, ConstructType::Type4),
    MagneticSpaceGroupType::new(553, 539, "62.455", "64.12.539", 62, ConstructType::Type4),
    MagneticSpaceGroupType::new(554, 660, "62.456", "74.11.660", 62, ConstructType::Type4),
    MagneticSpaceGroupType::new(555, 511, "63.457", "63.1.511", 63, ConstructType::Type1),
    MagneticSpaceGroupType::new(556, 512, "63.458", "63.2.512", 63, ConstructType::Type2),
    MagneticSpaceGroupType::new(557, 513, "63.459", "63.3.513", 63, ConstructType::Type3),
    MagneticSpaceGroupType::new(558, 514, "63.460", "63.4.514", 63, ConstructType::Type3),
    MagneticSpaceGroupType::new(559, 515, "63.461", "63.5.515", 63, ConstructType::Type3),
    MagneticSpaceGroupType::new(560, 516, "63.462", "63.6.516", 63, ConstructType::Type3),
    MagneticSpaceGroupType::new(561, 517, "63.463", "63.7.517", 63, ConstructType::Type3),
    MagneticSpaceGroupType::new(562, 518, "63.464", "63.8.518", 63, ConstructType::Type3),
    MagneticSpaceGroupType::new(563, 519, "63.465", "63.9.519", 63, ConstructType::Type3),
    MagneticSpaceGroupType::new(564, 556, "63.466", "65.12.556", 63, ConstructType::Type4),
    MagneticSpaceGroupType::new(565, 398, "63.467", "51.12.398", 63, ConstructType::Type4),
    MagneticSpaceGroupType::new(566, 611, "63.468", "69.7.611", 63, ConstructType::Type4),
    MagneticSpaceGroupType::new(567, 528, "64.469", "64.1.528", 64, ConstructType::Type1),
    MagneticSpaceGroupType::new(568, 529, "64.470", "64.2.529", 64, ConstructType::Type2),
    MagneticSpaceGroupType::new(569, 530, "64.471", "64.3.530", 64, ConstructType::Type3),
    MagneticSpaceGroupType::new(570, 531, "64.472", "64.4.531", 64, ConstructType::Type3),
    MagneticSpaceGroupType::new(571, 532, "64.473", "64.5.532", 64, ConstructType::Type3),
    MagneticSpaceGroupType::new(572, 533, "64.474", "64.6.533", 64, ConstructType::Type3),
    MagneticSpaceGroupType::new(573, 534, "64.475", "64.7.534", 64, ConstructType::Type3),
    MagneticSpaceGroupType::new(574, 535, "64.476", "64.8.535", 64, ConstructType::Type3),
    MagneticSpaceGroupType::new(575, 536, "64.477", "64.9.536", 64, ConstructType::Type3),
    MagneticSpaceGroupType::new(576, 587, "64.478", "67.11.587", 64, ConstructType::Type4),
    MagneticSpaceGroupType::new(577, 405, "64.479", "51.19.405", 64, ConstructType::Type4),
    MagneticSpaceGroupType::new(578, 614, "64.480", "69.10.614", 64, ConstructType::Type4),
    MagneticSpaceGroupType::new(579, 545, "65.481", "65.1.545", 65, ConstructType::Type1),
    MagneticSpaceGroupType::new(580, 546, "65.482", "65.2.546", 65, ConstructType::Type2),
    MagneticSpaceGroupType::new(581, 547, "65.483", "65.3.547", 65, ConstructType::Type3),
    MagneticSpaceGroupType::new(582, 548, "65.484", "65.4.548", 65, ConstructType::Type3),
    MagneticSpaceGroupType::new(583, 549, "65.485", "65.5.549", 65, ConstructType::Type3),
    MagneticSpaceGroupType::new(584, 550, "65.486", "65.6.550", 65, ConstructType::Type3),
    MagneticSpaceGroupType::new(585, 551, "65.487", "65.7.551", 65, ConstructType::Type3),
    MagneticSpaceGroupType::new(586, 552, "65.488", "65.8.552", 65, ConstructType::Type4),
    MagneticSpaceGroupType::new(587, 353, "65.489", "47.7.353", 65, ConstructType::Type4),
    MagneticSpaceGroupType::new(588, 610, "65.490", "69.6.610", 65, ConstructType::Type4),
    MagneticSpaceGroupType::new(589, 564, "66.491", "66.1.564", 66, ConstructType::Type1),
    MagneticSpaceGroupType::new(590, 565, "66.492", "66.2.565", 66, ConstructType::Type2),
    MagneticSpaceGroupType::new(591, 566, "66.493", "66.3.566", 66, ConstructType::Type3),
    MagneticSpaceGroupType::new(592, 567, "66.494", "66.4.567", 66, ConstructType::Type3),
    MagneticSpaceGroupType::new(593, 568, "66.495", "66.5.568", 66, ConstructType::Type3),
    MagneticSpaceGroupType::new(594, 569, "66.496", "66.6.569", 66, ConstructType::Type3),
    MagneticSpaceGroupType::new(595, 570, "66.497", "66.7.570", 66, ConstructType::Type3),
    MagneticSpaceGroupType::new(596, 555, "66.498", "65.11.555", 66, ConstructType::Type4),
    MagneticSpaceGroupType::new(597, 372, "66.499", "49.9.372", 66, ConstructType::Type4),
    MagneticSpaceGroupType::new(598, 613, "66.500", "69.9.613", 66, ConstructType::Type4),
    MagneticSpaceGroupType::new(599, 577, "67.501", "67.1.577", 67, ConstructType::Type1),
    MagneticSpaceGroupType::new(600, 578, "67.502", "67.2.578", 67, ConstructType::Type2),
    MagneticSpaceGroupType::new(601, 579, "67.503", "67.3.579", 67, ConstructType::Type3),
    MagneticSpaceGroupType::new(602, 580, "67.504", "67.4.580", 67, ConstructType::Type3),
    MagneticSpaceGroupType::new(603, 581, "67.505", "67.5.581", 67, ConstructType::Type3),
    MagneticSpaceGroupType::new(604, 582, "67.506", "67.6.582", 67, ConstructType::Type3),
    MagneticSpaceGroupType::new(605, 583, "67.507", "67.7.583", 67, ConstructType::Type3),
    MagneticSpaceGroupType::new(606, 584, "67.508", "67.8.584", 67, ConstructType::Type4),
    MagneticSpaceGroupType::new(607, 357, "67.509", "47.11.357", 67, ConstructType::Type4),
    MagneticSpaceGroupType::new(608, 612, "67.510", "69.8.612", 67, ConstructType::Type4),
    MagneticSpaceGroupType::new(609, 594, "68.511", "68.1.594", 68, ConstructType::Type1),
    MagneticSpaceGroupType::new(610, 595, "68.512", "68.2.595", 68, ConstructType::Type2),
    MagneticSpaceGroupType::new(611, 596, "68.513", "68.3.596", 68, ConstructType::Type3),
    MagneticSpaceGroupType::new(612, 597, "68.514", "68.4.597", 68, ConstructType::Type3),
    MagneticSpaceGroupType::new(613, 598, "68.515", "68.5.598", 68, ConstructType::Type3),
    MagneticSpaceGroupType::new(614, 599, "68.516", "68.6.599", 68, ConstructType::Type3),
    MagneticSpaceGroupType::new(615, 600, "68.517", "68.7.600", 68, ConstructType::Type3),
    MagneticSpaceGroupType::new(616, 588, "68.518", "67.12.588", 68, ConstructType::Type4),
    MagneticSpaceGroupType::new(617, 376, "68.519", "49.13.376", 68, ConstructType::Type4),
    MagneticSpaceGroupType::new(618, 615, "68.520", "69.11.615", 68, ConstructType::Type4),
    MagneticSpaceGroupType::new(619, 605, "69.521", "69.1.605", 69, ConstructType::Type1),
    MagneticSpaceGroupType::new(620, 606, "69.522", "69.2.606", 69, ConstructType::Type2),
    MagneticSpaceGroupType::new(621, 607, "69.523", "69.3.607", 69, ConstructType::Type3),
    MagneticSpaceGroupType::new(622, 608, "69.524", "69.4.608", 69, ConstructType::Type3),
    MagneticSpaceGroupType::new(623, 609, "69.525", "69.5.609", 69, ConstructType::Type3),
    MagneticSpaceGroupType::new(624, 354, "69.526", "47.8.354", 69, ConstructType::Type4),
    MagneticSpaceGroupType::new(625, 616, "70.527", "70.1.616", 70, ConstructType::Type1),
    MagneticSpaceGroupType::new(626, 617, "70.528", "70.2.617", 70, ConstructType::Type2),
    MagneticSpaceGroupType::new(627, 618, "70.529", "70.3.618", 70, ConstructType::Type3),
    MagneticSpaceGroupType::new(628, 619, "70.530", "70.4.619", 70, ConstructType::Type3),
    MagneticSpaceGroupType::new(629, 620, "70.531", "70.5.620", 70, ConstructType::Type3),
    MagneticSpaceGroupType::new(630, 363, "70.532", "48.6.363", 70, ConstructType::Type4),
    MagneticSpaceGroupType::new(631, 621, "71.533", "71.1.621", 71, ConstructType::Type1),
    MagneticSpaceGroupType::new(632, 622, "71.534", "71.2.622", 71, ConstructType::Type2),
    MagneticSpaceGroupType::new(633, 623, "71.535", "71.3.623", 71, ConstructType::Type3),
    MagneticSpaceGroupType::new(634, 624, "71.536", "71.4.624", 71, ConstructType::Type3),
    MagneticSpaceGroupType::new(635, 625, "71.537", "71.5.625", 71, ConstructType::Type3),
    MagneticSpaceGroupType::new(636, 554, "71.538", "65.10.554", 71, ConstructType::Type4),
    MagneticSpaceGroupType::new(637, 630, "72.539", "72.1.630", 72, ConstructType::Type1),
    MagneticSpaceGroupType::new(638, 631, "72.540", "72.2.631", 72, ConstructType::Type2),
    MagneticSpaceGroupType::new(639, 632, "72.541", "72.3.632", 72, ConstructType::Type3),
    MagneticSpaceGroupType::new(640, 633, "72.542", "72.4.633", 72, ConstructType::Type3),
    MagneticSpaceGroupType::new(641, 634, "72.543", "72.5.634", 72, ConstructType::Type3),
    MagneticSpaceGroupType::new(642, 635, "72.544", "72.6.635", 72, ConstructType::Type3),
    MagneticSpaceGroupType::new(643, 636, "72.545", "72.7.636", 72, ConstructType::Type3),
    MagneticSpaceGroupType::new(644, 563, "72.546", "65.19.563", 72, ConstructType::Type4),
    MagneticSpaceGroupType::new(645, 586, "72.547", "67.10.586", 72, ConstructType::Type4),
    MagneticSpaceGroupType::new(646, 643, "73.548", "73.1.643", 73, ConstructType::Type1),
    MagneticSpaceGroupType::new(647, 644, "73.549", "73.2.644", 73, ConstructType::Type2),
    MagneticSpaceGroupType::new(648, 645, "73.550", "73.3.645", 73, ConstructType::Type3),
    MagneticSpaceGroupType::new(649, 646, "73.551", "73.4.646", 73, ConstructType::Type3),
    MagneticSpaceGroupType::new(650, 647, "73.552", "73.5.647", 73, ConstructType::Type3),
    MagneticSpaceGroupType::new(651, 593, "73.553", "67.17.593", 73, ConstructType::Type4),
    MagneticSpaceGroupType::new(652, 650, "74.554", "74.1.650", 74, ConstructType::Type1),
    MagneticSpaceGroupType::new(653, 651, "74.555", "74.2.651", 74, ConstructType::Type2),
    MagneticSpaceGroupType::new(654, 652, "74.556", "74.3.652", 74, ConstructType::Type3),
    MagneticSpaceGroupType::new(655, 653, "74.557", "74.4.653", 74, ConstructType::Type3),
    MagneticSpaceGroupType::new(656, 654, "74.558", "74.5.654", 74, ConstructType::Type3),
    MagneticSpaceGroupType::new(657, 655, "74.559", "74.6.655", 74, ConstructType::Type3),
    MagneticSpaceGroupType::new(658, 656, "74.560", "74.7.656", 74, ConstructType::Type3),
    MagneticSpaceGroupType::new(659, 592, "74.561", "67.16.592", 74, ConstructType::Type4),
    MagneticSpaceGroupType::new(660, 562, "74.562", "65.18.562", 74, ConstructType::Type4),
    MagneticSpaceGroupType::new(661, 661, "75.1", "75.1.661", 75, ConstructType::Type1),
    MagneticSpaceGroupType::new(662, 662, "75.2", "75.2.662", 75, ConstructType::Type2),
    MagneticSpaceGroupType::new(663, 663, "75.3", "75.3.663", 75, ConstructType::Type3),
    MagneticSpaceGroupType::new(664, 664, "75.4", "75.4.664", 75, ConstructType::Type4),
    MagneticSpaceGroupType::new(665, 665, "75.5", "75.5.665", 75, ConstructType::Type4),
    MagneticSpaceGroupType::new(666, 686, "75.6", "79.4.686", 75, ConstructType::Type4),
    MagneticSpaceGroupType::new(667, 668, "76.7", "76.1.668", 76, ConstructType::Type1),
    MagneticSpaceGroupType::new(668, 669, "76.8", "76.2.669", 76, ConstructType::Type2),
    MagneticSpaceGroupType::new(669, 670, "76.9", "76.3.670", 76, ConstructType::Type3),
    MagneticSpaceGroupType::new(670, 675, "76.10", "77.4.675", 76, ConstructType::Type4),
    MagneticSpaceGroupType::new(671, 671, "76.11", "76.4.671", 76, ConstructType::Type4),
    MagneticSpaceGroupType::new(672, 691, "76.12", "80.4.691", 76, ConstructType::Type4),
    MagneticSpaceGroupType::new(673, 672, "77.13", "77.1.672", 77, ConstructType::Type1),
    MagneticSpaceGroupType::new(674, 673, "77.14", "77.2.673", 77, ConstructType::Type2),
    MagneticSpaceGroupType::new(675, 674, "77.15", "77.3.674", 77, ConstructType::Type3),
    MagneticSpaceGroupType::new(676, 667, "77.16", "75.7.667", 77, ConstructType::Type4),
    MagneticSpaceGroupType::new(677, 676, "77.17", "77.5.676", 77, ConstructType::Type4),
    MagneticSpaceGroupType::new(678, 687, "77.18", "79.5.687", 77, ConstructType::Type4),
    MagneticSpaceGroupType::new(679, 679, "78.19", "78.1.679", 78, ConstructType::Type1),
    MagneticSpaceGroupType::new(680, 680, "78.20", "78.2.680", 78, ConstructType::Type2),
    MagneticSpaceGroupType::new(681, 681, "78.21", "78.3.681", 78, ConstructType::Type3),
    MagneticSpaceGroupType::new(682, 678, "78.22", "77.7.678", 78, ConstructType::Type4),
    MagneticSpaceGroupType::new(683, 682, "78.23", "78.4.682", 78, ConstructType::Type4),
    MagneticSpaceGroupType::new(684, 692, "78.24", "80.5.692", 78, ConstructType::Type4),
    MagneticSpaceGroupType::new(685, 683, "79.25", "79.1.683", 79, ConstructType::Type1),
    MagneticSpaceGroupType::new(686, 684, "79.26", "79.2.684", 79, ConstructType::Type2),
    MagneticSpaceGroupType::new(687, 685, "79.27", "79.3.685", 79, ConstructType::Type3),
    MagneticSpaceGroupType::new(688, 666, "79.28", "75.6.666", 79, ConstructType::Type4),
    MagneticSpaceGroupType::new(689, 688, "80.29", "80.1.688", 80, ConstructType::Type1),
    MagneticSpaceGroupType::new(690, 689, "80.30", "80.2.689", 80, ConstructType::Type2),
    MagneticSpaceGroupType::new(691, 690, "80.31", "80.3.690", 80, ConstructType::Type3),
    MagneticSpaceGroupType::new(692, 677, "80.32", "77.6.677", 80, ConstructType::Type4),
    MagneticSpaceGroupType::new(693, 693, "81.33", "81.1.693", 81, ConstructType::Type1),
    MagneticSpaceGroupType::new(694, 694, "81.34", "81.2.694", 81, ConstructType::Type2),
    MagneticSpaceGroupType::new(695, 695, "81.35", "81.3.695", 81, ConstructType::Type3),
    MagneticSpaceGroupType::new(696, 696, "81.36", "81.4.696", 81, ConstructType::Type4),
    MagneticSpaceGroupType::new(697, 697, "81.37", "81.5.697", 81, ConstructType::Type4),
    MagneticSpaceGroupType::new(698, 702, "81.38", "82.4.702", 81, ConstructType::Type4),
    MagneticSpaceGroupType::new(699, 699, "82.39", "82.1.699", 82, ConstructType::Type1),
    MagneticSpaceGroupType::new(700, 700, "82.40", "82.2.700", 82, ConstructType::Type2),
    MagneticSpaceGroupType::new(701, 701, "82.41", "82.3.701", 82, ConstructType::Type3),
    MagneticSpaceGroupType::new(702, 698, "82.42", "81.6.698", 82, ConstructType::Type4),
    MagneticSpaceGroupType::new(703, 703, "83.43", "83.1.703", 83, ConstructType::Type1),
    MagneticSpaceGroupType::new(704, 704, "83.44", "83.2.704", 83, ConstructType::Type2),
    MagneticSpaceGroupType::new(705, 705, "83.45", "83.3.705", 83, ConstructType::Type3),
    MagneticSpaceGroupType::new(706, 706, "83.46", "83.4.706", 83, ConstructType::Type3),
    MagneticSpaceGroupType::new(707, 707, "83.47", "83.5.707", 83, ConstructType::Type3),
    MagneticSpaceGroupType::new(708, 708, "83.48", "83.6.708", 83, ConstructType::Type4),
    MagneticSpaceGroupType::new(709, 709, "83.49", "83.7.709", 83, ConstructType::Type4),
    MagneticSpaceGroupType::new(710, 738, "83.50", "87.6.738", 83, ConstructType::Type4),
    MagneticSpaceGroupType::new(711, 713, "84.51", "84.1.713", 84, ConstructType::Type1),
    MagneticSpaceGroupType::new(712, 714, "84.52", "84.2.714", 84, ConstructType::Type2),
    MagneticSpaceGroupType::new(713, 715, "84.53", "84.3.715", 84, ConstructType::Type3),
    MagneticSpaceGroupType::new(714, 716, "84.54", "84.4.716", 84, ConstructType::Type3),
    MagneticSpaceGroupType::new(715, 717, "84.55", "84.5.717", 84, ConstructType::Type3),
    MagneticSpaceGroupType::new(716, 711, "84.56", "83.9.711", 84, ConstructType::Type4),
    MagneticSpaceGroupType::new(717, 718, "84.57", "84.6.718", 84, ConstructType::Type4),
    MagneticSpaceGroupType::new(718, 739, "84.58", "87.7.739", 84, ConstructType::Type4),
    MagneticSpaceGroupType::new(719, 720, "85.59", "85.1.720", 85, ConstructType::Type1),
    MagneticSpaceGroupType::new(720, 721, "85.60", "85.2.721", 85, ConstructType::Type2),
    MagneticSpaceGroupType::new(721, 722, "85.61", "85.3.722", 85, ConstructType::Type3),
    MagneticSpaceGroupType::new(722, 723, "85.62", "85.4.723", 85, ConstructType::Type3),
    MagneticSpaceGroupType::new(723, 724, "85.63", "85.5.724", 85, ConstructType::Type3),
    MagneticSpaceGroupType::new(724, 725, "85.64", "85.6.725", 85, ConstructType::Type4),
    MagneticSpaceGroupType::new(725, 712, "85.65", "83.10.712", 85, ConstructType::Type4),
    MagneticSpaceGroupType::new(726, 740, "85.66", "87.8.740", 85, ConstructType::Type4),
    MagneticSpaceGroupType::new(727, 727, "86.67", "86.1.727", 86, ConstructType::Type1),
    MagneticSpaceGroupType::new(728, 728, "86.68", "86.2.728", 86, ConstructType::Type2),
    MagneticSpaceGroupType::new(729, 729, "86.69", "86.3.729", 86, ConstructType::Type3),
    MagneticSpaceGroupType::new(730, 730, "86.70", "86.4.730", 86, ConstructType::Type3),
    MagneticSpaceGroupType::new(731, 731, "86.71", "86.5.731", 86, ConstructType::Type3),
    MagneticSpaceGroupType::new(732, 726, "86.72", "85.7.726", 86, ConstructType::Type4),
    MagneticSpaceGroupType::new(733, 719, "86.73", "84.7.719", 86, ConstructType::Type4),
    MagneticSpaceGroupType::new(734, 741, "86.74", "87.9.741", 86, ConstructType::Type4),
    MagneticSpaceGroupType::new(735, 733, "87.75", "87.1.733", 87, ConstructType::Type1),
    MagneticSpaceGroupType::new(736, 734, "87.76", "87.2.734", 87, ConstructType::Type2),
    MagneticSpaceGroupType::new(737, 735, "87.77", "87.3.735", 87, ConstructType::Type3),
    MagneticSpaceGroupType::new(738, 736, "87.78", "87.4.736", 87, ConstructType::Type3),
    MagneticSpaceGroupType::new(739, 737, "87.79", "87.5.737", 87, ConstructType::Type3),
    MagneticSpaceGroupType::new(740, 710, "87.80", "83.8.710", 87, ConstructType::Type4),
    MagneticSpaceGroupType::new(741, 742, "88.81", "88.1.742", 88, ConstructType::Type1),
    MagneticSpaceGroupType::new(742, 743, "88.82", "88.2.743", 88, ConstructType::Type2),
    MagneticSpaceGroupType::new(743, 744, "88.83", "88.3.744", 88, ConstructType::Type3),
    MagneticSpaceGroupType::new(744, 745, "88.84", "88.4.745", 88, ConstructType::Type3),
    MagneticSpaceGroupType::new(745, 746, "88.85", "88.5.746", 88, ConstructType::Type3),
    MagneticSpaceGroupType::new(746, 732, "88.86", "86.6.732", 88, ConstructType::Type4),
    MagneticSpaceGroupType::new(747, 747, "89.87", "89.1.747", 89, ConstructType::Type1),
    MagneticSpaceGroupType::new(748, 748, "89.88", "89.2.748", 89, ConstructType::Type2),
    MagneticSpaceGroupType::new(749, 749, "89.89", "89.3.749", 89, ConstructType::Type3),
    MagneticSpaceGroupType::new(750, 750, "89.90", "89.4.750", 89, ConstructType::Type3),
    MagneticSpaceGroupType::new(751, 751, "89.91", "89.5.751", 89, ConstructType::Type3),
    MagneticSpaceGroupType::new(752, 752, "89.92", "89.6.752", 89, ConstructType::Type4),
    MagneticSpaceGroupType::new(753, 753, "89.93", "89.7.753", 89, ConstructType::Type4),
    MagneticSpaceGroupType::new(754, 810, "89.94", "97.6.810", 89, ConstructType::Type4),
    MagneticSpaceGroupType::new(755, 757, "90.95", "90.1.757", 90, ConstructType::Type1),
    MagneticSpaceGroupType::new(756, 758, "90.96", "90.2.758", 90, ConstructType::Type2),
    MagneticSpaceGroupType::new(757, 759, "90.97", "90.3.759", 90, ConstructType::Type3),
    MagneticSpaceGroupType::new(758, 760, "90.98", "90.4.760", 90, ConstructType::Type3),
    MagneticSpaceGroupType::new(759, 761, "90.99", "90.5.761", 90, ConstructType::Type3),
    MagneticSpaceGroupType::new(760, 762, "90.100", "90.6.762", 90, ConstructType::Type4),
    MagneticSpaceGroupType::new(761, 756, "90.101", "89.10.756", 90, ConstructType::Type4),
    MagneticSpaceGroupType::new(762, 812, "90.102", "97.8.812", 90, ConstructType::Type4),
    MagneticSpaceGroupType::new(763, 764, "91.103", "91.1.764", 91, ConstructType::Type1),
    MagneticSpaceGroupType::new(764, 765, "91.104", "91.2.765", 91, ConstructType::Type2),
    MagneticSpaceGroupType::new(765, 766, "91.105", "91.3.766", 91, ConstructType::Type3),
    MagneticSpaceGroupType::new(766, 767, "91.106", "91.4.767", 91, ConstructType::Type3),
    MagneticSpaceGroupType::new(767, 768, "91.107", "91.5.768", 91, ConstructType::Type3),
    MagneticSpaceGroupType::new(768, 781, "91.108", "93.6.781", 91, ConstructType::Type4),
    MagneticSpaceGroupType::new(769, 769, "91.109", "91.6.769", 91, ConstructType::Type4),
    MagneticSpaceGroupType::new(770, 819, "91.110", "98.6.819", 91, ConstructType::Type4),
    MagneticSpaceGroupType::new(771, 771, "92.111", "92.1.771", 92, ConstructType::Type1),
    MagneticSpaceGroupType::new(772, 772, "92.112", "92.2.772", 92, ConstructType::Type2),
    MagneticSpaceGroupType::new(773, 773, "92.113", "92.3.773", 92, ConstructType::Type3),
    MagneticSpaceGroupType::new(774, 774, "92.114", "92.4.774", 92, ConstructType::Type3),
    MagneticSpaceGroupType::new(775, 775, "92.115", "92.5.775", 92, ConstructType::Type3),
    MagneticSpaceGroupType::new(776, 791, "92.116", "94.6.791", 92, ConstructType::Type4),
    MagneticSpaceGroupType::new(777, 770, "92.117", "91.7.770", 92, ConstructType::Type4),
    MagneticSpaceGroupType::new(778, 821, "92.118", "98.8.821", 92, ConstructType::Type4),
    MagneticSpaceGroupType::new(779, 776, "93.119", "93.1.776", 93, ConstructType::Type1),
    MagneticSpaceGroupType::new(780, 777, "93.120", "93.2.777", 93, ConstructType::Type2),
    MagneticSpaceGroupType::new(781, 778, "93.121", "93.3.778", 93, ConstructType::Type3),
    MagneticSpaceGroupType::new(782, 779, "93.122", "93.4.779", 93, ConstructType::Type3),
    MagneticSpaceGroupType::new(783, 780, "93.123", "93.5.780", 93, ConstructType::Type3),
    MagneticSpaceGroupType::new(784, 755, "93.124", "89.9.755", 93, ConstructType::Type4),
    MagneticSpaceGroupType::new(785, 782, "93.125", "93.7.782", 93, ConstructType::Type4),
    MagneticSpaceGroupType::new(786, 811, "93.126", "97.7.811", 93, ConstructType::Type4),
    MagneticSpaceGroupType::new(787, 786, "94.127", "94.1.786", 94, ConstructType::Type1),
    MagneticSpaceGroupType::new(788, 787, "94.128", "94.2.787", 94, ConstructType::Type2),
    MagneticSpaceGroupType::new(789, 788, "94.129", "94.3.788", 94, ConstructType::Type3),
    MagneticSpaceGroupType::new(790, 789, "94.130", "94.4.789", 94, ConstructType::Type3),
    MagneticSpaceGroupType::new(791, 790, "94.131", "94.5.790", 94, ConstructType::Type3),
    MagneticSpaceGroupType::new(792, 763, "94.132", "90.7.763", 94, ConstructType::Type4),
    MagneticSpaceGroupType::new(793, 785, "94.133", "93.10.785", 94, ConstructType::Type4),
    MagneticSpaceGroupType::new(794, 813, "94.134", "97.9.813", 94, ConstructType::Type4),
    MagneticSpaceGroupType::new(795, 793, "95.135", "95.1.793", 95, ConstructType::Type1),
    MagneticSpaceGroupType::new(796, 794, "95.136", "95.2.794", 95, ConstructType::Type2),
    MagneticSpaceGroupType::new(797, 795, "95.137", "95.3.795", 95, ConstructType::Type3),
    MagneticSpaceGroupType::new(798, 796, "95.138", "95.4.796", 95, ConstructType::Type3),
    MagneticSpaceGroupType::new(799, 797, "95.139", "95.5.797", 95, ConstructType::Type3),
    MagneticSpaceGroupType::new(800, 784, "95.140", "93.9.784", 95, ConstructType::Type4),
    MagneticSpaceGroupType::new(801, 798, "95.141", "95.6.798", 95, ConstructType::Type4),
    MagneticSpaceGroupType::new(802, 820, "95.142", "98.7.820", 95, ConstructType::Type4),
    MagneticSpaceGroupType::new(803, 800, "96.143", "96.1.800", 96, ConstructType::Type1),
    MagneticSpaceGroupType::new(804, 801, "96.144", "96.2.801", 96, ConstructType::Type2),
    MagneticSpaceGroupType::new(805, 802, "96.145", "96.3.802", 96, ConstructType::Type3),
    MagneticSpaceGroupType::new(806, 803, "96.146", "96.4.803", 96, ConstructType::Type3),
    MagneticSpaceGroupType::new(807, 804, "96.147", "96.5.804", 96, ConstructType::Type3),
    MagneticSpaceGroupType::new(808, 792, "96.148", "94.7.792", 96, ConstructType::Type4),
    MagneticSpaceGroupType::new(809, 799, "96.149", "95.7.799", 96, ConstructType::Type4),
    MagneticSpaceGroupType::new(810, 822, "96.150", "98.9.822", 96, ConstructType::Type4),
    MagneticSpaceGroupType::new(811, 805, "97.151", "97.1.805", 97, ConstructType::Type1),
    MagneticSpaceGroupType::new(812, 806, "97.152", "97.2.806", 97, ConstructType::Type2),
    MagneticSpaceGroupType::new(813, 807, "97.153", "97.3.807", 97, ConstructType::Type3),
    MagneticSpaceGroupType::new(814, 808, "97.154", "97.4.808", 97, ConstructType::Type3),
    MagneticSpaceGroupType::new(815, 809, "97.155", "97.5.809", 97, ConstructType::Type3),
    MagneticSpaceGroupType::new(816, 754, "97.156", "89.8.754", 97, ConstructType::Type4),
    MagneticSpaceGroupType::new(817, 814, "98.157", "98.1.814", 98, ConstructType::Type1),
    MagneticSpaceGroupType::new(818, 815, "98.158", "98.2.815", 98, ConstructType::Type2),
    MagneticSpaceGroupType::new(819, 816, "98.159", "98.3.816", 98, ConstructType::Type3),
    MagneticSpaceGroupType::new(820, 817, "98.160", "98.4.817", 98, ConstructType::Type3),
    MagneticSpaceGroupType::new(821, 818, "98.161", "98.5.818", 98, ConstructType::Type3),
    MagneticSpaceGroupType::new(822, 783, "98.162", "93.8.783", 98, ConstructType::Type4),
    MagneticSpaceGroupType::new(823, 823, "99.163", "99.1.823", 99, ConstructType::Type1),
    MagneticSpaceGroupType::new(824, 824, "99.164", "99.2.824", 99, ConstructType::Type2),
    MagneticSpaceGroupType::new(825, 825, "99.165", "99.3.825", 99, ConstructType::Type3),
    MagneticSpaceGroupType::new(826, 826, "99.166", "99.4.826", 99, ConstructType::Type3),
    MagneticSpaceGroupType::new(827, 827, "99.167", "99.5.827", 99, ConstructType::Type3),
    MagneticSpaceGroupType::new(828, 828, "99.168", "99.6.828", 99, ConstructType::Type4),
    MagneticSpaceGroupType::new(829, 829, "99.169", "99.7.829", 99, ConstructType::Type4),
    MagneticSpaceGroupType::new(830, 888, "99.170", "107.6.888", 99, ConstructType::Type4),
    MagneticSpaceGroupType::new(831, 836, "100.171", "100.1.836", 100, ConstructType::Type1),
    MagneticSpaceGroupType::new(832, 837, "100.172", "100.2.837", 100, ConstructType::Type2),
    MagneticSpaceGroupType::new(833, 838, "100.173", "100.3.838", 100, ConstructType::Type3),
    MagneticSpaceGroupType::new(834, 839, "100.174", "100.4.839", 100, ConstructType::Type3),
    MagneticSpaceGroupType::new(835, 840, "100.175", "100.5.840", 100, ConstructType::Type3),
    MagneticSpaceGroupType::new(836, 841, "100.176", "100.6.841", 100, ConstructType::Type4),
    MagneticSpaceGroupType::new(837, 834, "100.177", "99.12.834", 100, ConstructType::Type4),
    MagneticSpaceGroupType::new(838, 897, "100.178", "108.6.897", 100, ConstructType::Type4),
    MagneticSpaceGroupType::new(839, 845, "101.179", "101.1.845", 101, ConstructType::Type1),
    MagneticSpaceGroupType::new(840, 846, "101.180", "101.2.846", 101, ConstructType::Type2),
    MagneticSpaceGroupType::new(841, 847, "101.181", "101.3.847", 101, ConstructType::Type3),
    MagneticSpaceGroupType::new(842, 848, "101.182", "101.4.848", 101, ConstructType::Type3),
    MagneticSpaceGroupType::new(843, 849, "101.183", "101.5.849", 101, ConstructType::Type3),
    MagneticSpaceGroupType::new(844, 831, "101.184", "99.9.831", 101, ConstructType::Type4),
    MagneticSpaceGroupType::new(845, 876, "101.185", "105.6.876", 101, ConstructType::Type4),
    MagneticSpaceGroupType::new(846, 898, "101.186", "108.7.898", 101, ConstructType::Type4),
    MagneticSpaceGroupType::new(847, 852, "102.187", "102.1.852", 102, ConstructType::Type1),
    MagneticSpaceGroupType::new(848, 853, "102.188", "102.2.853", 102, ConstructType::Type2),
    MagneticSpaceGroupType::new(849, 854, "102.189", "102.3.854", 102, ConstructType::Type3),
    MagneticSpaceGroupType::new(850, 855, "102.190", "102.4.855", 102, ConstructType::Type3),
    MagneticSpaceGroupType::new(851, 856, "102.191", "102.5.856", 102, ConstructType::Type3),
    MagneticSpaceGroupType::new(852, 842, "102.192", "100.7.842", 102, ConstructType::Type4),
    MagneticSpaceGroupType::new(853, 877, "102.193", "105.7.877", 102, ConstructType::Type4),
    MagneticSpaceGroupType::new(854, 889, "102.194", "107.7.889", 102, ConstructType::Type4),
    MagneticSpaceGroupType::new(855, 859, "103.195", "103.1.859", 103, ConstructType::Type1),
    MagneticSpaceGroupType::new(856, 860, "103.196", "103.2.860", 103, ConstructType::Type2),
    MagneticSpaceGroupType::new(857, 861, "103.197", "103.3.861", 103, ConstructType::Type3),
    MagneticSpaceGroupType::new(858, 862, "103.198", "103.4.862", 103, ConstructType::Type3),
    MagneticSpaceGroupType::new(859, 863, "103.199", "103.5.863", 103, ConstructType::Type3),
    MagneticSpaceGroupType::new(860, 833, "103.200", "99.11.833", 103, ConstructType::Type4),
    MagneticSpaceGroupType::new(861, 864, "103.201", "103.6.864", 103, ConstructType::Type4),
    MagneticSpaceGroupType::new(862, 900, "103.202", "108.9.900", 103, ConstructType::Type4),
    MagneticSpaceGroupType::new(863, 866, "104.203", "104.1.866", 104, ConstructType::Type1),
    MagneticSpaceGroupType::new(864, 867, "104.204", "104.2.867", 104, ConstructType::Type2),
    MagneticSpaceGroupType::new(865, 868, "104.205", "104.3.868", 104, ConstructType::Type3),
    MagneticSpaceGroupType::new(866, 869, "104.206", "104.4.869", 104, ConstructType::Type3),
    MagneticSpaceGroupType::new(867, 870, "104.207", "104.5.870", 104, ConstructType::Type3),
    MagneticSpaceGroupType::new(868, 844, "104.208", "100.9.844", 104, ConstructType::Type4),
    MagneticSpaceGroupType::new(869, 865, "104.209", "103.7.865", 104, ConstructType::Type4),
    MagneticSpaceGroupType::new(870, 891, "104.210", "107.9.891", 104, ConstructType::Type4),
    MagneticSpaceGroupType::new(871, 871, "105.211", "105.1.871", 105, ConstructType::Type1),
    MagneticSpaceGroupType::new(872, 872, "105.212", "105.2.872", 105, ConstructType::Type2),
    MagneticSpaceGroupType::new(873, 873, "105.213", "105.3.873", 105, ConstructType::Type3),
    MagneticSpaceGroupType::new(874, 874, "105.214", "105.4.874", 105, ConstructType::Type3),
    MagneticSpaceGroupType::new(875, 875, "105.215", "105.5.875", 105, ConstructType::Type3),
    MagneticSpaceGroupType::new(876, 832, "105.216", "99.10.832", 105, ConstructType::Type4),
    MagneticSpaceGroupType::new(877, 850, "105.217", "101.6.850", 105, ConstructType::Type4),
    MagneticSpaceGroupType::new(878, 890, "105.218", "107.8.890", 105, ConstructType::Type4),
    MagneticSpaceGroupType::new(879, 878, "106.219", "106.1.878", 106, ConstructType::Type1),
    MagneticSpaceGroupType::new(880, 879, "106.220", "106.2.879", 106, ConstructType::Type2),
    MagneticSpaceGroupType::new(881, 880, "106.221", "106.3.880", 106, ConstructType::Type3),
    MagneticSpaceGroupType::new(882, 881, "106.222", "106.4.881", 106, ConstructType::Type3),
    MagneticSpaceGroupType::new(883, 882, "106.223", "106.5.882", 106, ConstructType::Type3),
    MagneticSpaceGroupType::new(884, 843, "106.224", "100.8.843", 106, ConstructType::Type4),
    MagneticSpaceGroupType::new(885, 851, "106.225", "101.7.851", 106, ConstructType::Type4),
    MagneticSpaceGroupType::new(886, 899, "106.226", "108.8.899", 106, ConstructType::Type4),
    MagneticSpaceGroupType::new(887, 883, "107.227", "107.1.883", 107, ConstructType::Type1),
    MagneticSpaceGroupType::new(888, 884, "107.228", "107.2.884", 107, ConstructType::Type2),
    MagneticSpaceGroupType::new(889, 885, "107.229", "107.3.885", 107, ConstructType::Type3),
    MagneticSpaceGroupType::new(890, 886, "107.230", "107.4.886", 107, ConstructType::Type3),
    MagneticSpaceGroupType::new(891, 887, "107.231", "107.5.887", 107, ConstructType::Type3),
    MagneticSpaceGroupType::new(892, 830, "107.232", "99.8.830", 107, ConstructType::Type4),
    MagneticSpaceGroupType::new(893, 892, "108.233", "108.1.892", 108, ConstructType::Type1),
    MagneticSpaceGroupType::new(894, 893, "108.234", "108.2.893", 108, ConstructType::Type2),
    MagneticSpaceGroupType::new(895, 894, "108.235", "108.3.894", 108, ConstructType::Type3),
    MagneticSpaceGroupType::new(896, 895, "108.236", "108.4.895", 108, ConstructType::Type3),
    MagneticSpaceGroupType::new(897, 896, "108.237", "108.5.896", 108, ConstructType::Type3),
    MagneticSpaceGroupType::new(898, 835, "108.238", "99.13.835", 108, ConstructType::Type4),
    MagneticSpaceGroupType::new(899, 901, "109.239", "109.1.901", 109, ConstructType::Type1),
    MagneticSpaceGroupType::new(900, 902, "109.240", "109.2.902", 109, ConstructType::Type2),
    MagneticSpaceGroupType::new(901, 903, "109.241", "109.3.903", 109, ConstructType::Type3),
    MagneticSpaceGroupType::new(902, 904, "109.242", "109.4.904", 109, ConstructType::Type3),
    MagneticSpaceGroupType::new(903, 905, "109.243", "109.5.905", 109, ConstructType::Type3),
    MagneticSpaceGroupType::new(904, 857, "109.244", "102.6.857", 109, ConstructType::Type4),
    MagneticSpaceGroupType::new(905, 906, "110.245", "110.1.906", 110, ConstructType::Type1),
    MagneticSpaceGroupType::new(906, 907, "110.246", "110.2.907", 110, ConstructType::Type2),
    MagneticSpaceGroupType::new(907, 908, "110.247", "110.3.908", 110, ConstructType::Type3),
    MagneticSpaceGroupType::new(908, 909, "110.248", "110.4.909", 110, ConstructType::Type3),
    MagneticSpaceGroupType::new(909, 910, "110.249", "110.5.910", 110, ConstructType::Type3),
    MagneticSpaceGroupType::new(910, 858, "110.250", "102.7.858", 110, ConstructType::Type4),
    MagneticSpaceGroupType::new(911, 911, "111.251", "111.1.911", 111, ConstructType::Type1),
    MagneticSpaceGroupType::new(912, 912, "111.252", "111.2.912", 111, ConstructType::Type2),
    MagneticSpaceGroupType::new(913, 913, "111.253", "111.3.913", 111, ConstructType::Type3),
    MagneticSpaceGroupType::new(914, 914, "111.254", "111.4.914", 111, ConstructType::Type3),
    MagneticSpaceGroupType::new(915, 915, "111.255", "111.5.915", 111, ConstructType::Type3),
    MagneticSpaceGroupType::new(916, 916, "111.256", "111.6.916", 111, ConstructType::Type4),
    MagneticSpaceGroupType::new(917, 947, "111.257", "115.7.947", 111, ConstructType::Type4),
    MagneticSpaceGroupType::new(918, 990, "111.258", "121.6.990", 111, ConstructType::Type4),
    MagneticSpaceGroupType::new(919, 922, "112.259", "112.1.922", 112, ConstructType::Type1),
    MagneticSpaceGroupType::new(920, 923, "112.260", "112.2.923", 112, ConstructType::Type2),
    MagneticSpaceGroupType::new(921, 924, "112.261", "112.3.924", 112, ConstructType::Type3),
    MagneticSpaceGroupType::new(922, 925, "112.262", "112.4.925", 112, ConstructType::Type3),
    MagneticSpaceGroupType::new(923, 926, "112.263", "112.5.926", 112, ConstructType::Type3),
    MagneticSpaceGroupType::new(924, 919, "112.264", "111.9.919", 112, ConstructType::Type4),
    MagneticSpaceGroupType::new(925, 956, "112.265", "116.6.956", 112, ConstructType::Type4),
    MagneticSpaceGroupType::new(926, 992, "112.266", "121.8.992", 112, ConstructType::Type4),
    MagneticSpaceGroupType::new(927, 929, "113.267", "113.1.929", 113, ConstructType::Type1),
    MagneticSpaceGroupType::new(928, 930, "113.268", "113.2.930", 113, ConstructType::Type2),
    MagneticSpaceGroupType::new(929, 931, "113.269", "113.3.931", 113, ConstructType::Type3),
    MagneticSpaceGroupType::new(930, 932, "113.270", "113.4.932", 113, ConstructType::Type3),
    MagneticSpaceGroupType::new(931, 933, "113.271", "113.5.933", 113, ConstructType::Type3),
    MagneticSpaceGroupType::new(932, 934, "113.272", "113.6.934", 113, ConstructType::Type4),
    MagneticSpaceGroupType::new(933, 950, "113.273", "115.10.950", 113, ConstructType::Type4),
    MagneticSpaceGroupType::new(934, 991, "113.274", "121.7.991", 113, ConstructType::Type4),
    MagneticSpaceGroupType::new(935, 936, "114.275", "114.1.936", 114, ConstructType::Type1),
    MagneticSpaceGroupType::new(936, 937, "114.276", "114.2.937", 114, ConstructType::Type2),
    MagneticSpaceGroupType::new(937, 938, "114.277", "114.3.938", 114, ConstructType::Type3),
    MagneticSpaceGroupType::new(938, 939, "114.278", "114.4.939", 114, ConstructType::Type3),
    MagneticSpaceGroupType::new(939, 940, "114.279", "114.5.940", 114, ConstructType::Type3),
    MagneticSpaceGroupType::new(940, 935, "114.280", "113.7.935", 114, ConstructType::Type4),
    MagneticSpaceGroupType::new(941, 957, "114.281", "116.7.957", 114, ConstructType::Type4),
    MagneticSpaceGroupType::new(942, 993, "114.282", "121.9.993", 114, ConstructType::Type4),
    MagneticSpaceGroupType::new(943, 941, "115.283", "115.1.941", 115, ConstructType::Type1),
    MagneticSpaceGroupType::new(944, 942, "115.284", "115.2.942", 115, ConstructType::Type2),
    MagneticSpaceGroupType::new(945, 943, "115.285", "115.3.943", 115, ConstructType::Type3),
    MagneticSpaceGroupType::new(946, 944, "115.286", "115.4.944", 115, ConstructType::Type3),
    MagneticSpaceGroupType::new(947, 945, "115.287", "115.5.945", 115, ConstructType::Type3),
    MagneticSpaceGroupType::new(948, 946, "115.288", "115.6.946", 115, ConstructType::Type4),
    MagneticSpaceGroupType::new(949, 917, "115.289", "111.7.917", 115, ConstructType::Type4),
    MagneticSpaceGroupType::new(950, 976, "115.290", "119.6.976", 115, ConstructType::Type4),
    MagneticSpaceGroupType::new(951, 951, "116.291", "116.1.951", 116, ConstructType::Type1),
    MagneticSpaceGroupType::new(952, 952, "116.292", "116.2.952", 116, ConstructType::Type2),
    MagneticSpaceGroupType::new(953, 953, "116.293", "116.3.953", 116, ConstructType::Type3),
    MagneticSpaceGroupType::new(954, 954, "116.294", "116.4.954", 116, ConstructType::Type3),
    MagneticSpaceGroupType::new(955, 955, "116.295", "116.5.955", 116, ConstructType::Type3),
    MagneticSpaceGroupType::new(956, 949, "116.296", "115.9.949", 116, ConstructType::Type4),
    MagneticSpaceGroupType::new(957, 927, "116.297", "112.6.927", 116, ConstructType::Type4),
    MagneticSpaceGroupType::new(958, 983, "116.298", "120.6.983", 116, ConstructType::Type4),
    MagneticSpaceGroupType::new(959, 958, "117.299", "117.1.958", 117, ConstructType::Type1),
    MagneticSpaceGroupType::new(960, 959, "117.300", "117.2.959", 117, ConstructType::Type2),
    MagneticSpaceGroupType::new(961, 960, "117.301", "117.3.960", 117, ConstructType::Type3),
    MagneticSpaceGroupType::new(962, 961, "117.302", "117.4.961", 117, ConstructType::Type3),
    MagneticSpaceGroupType::new(963, 962, "117.303", "117.5.962", 117, ConstructType::Type3),
    MagneticSpaceGroupType::new(964, 963, "117.304", "117.6.963", 117, ConstructType::Type4),
    MagneticSpaceGroupType::new(965, 920, "117.305", "111.10.920", 117, ConstructType::Type4),
    MagneticSpaceGroupType::new(966, 984, "117.306", "120.7.984", 117, ConstructType::Type4),
    MagneticSpaceGroupType::new(967, 965, "118.307", "118.1.965", 118, ConstructType::Type1),
    MagneticSpaceGroupType::new(968, 966, "118.308", "118.2.966", 118, ConstructType::Type2),
    MagneticSpaceGroupType::new(969, 967, "118.309", "118.3.967", 118, ConstructType::Type3),
    MagneticSpaceGroupType::new(970, 968, "118.310", "118.4.968", 118, ConstructType::Type3),
    MagneticSpaceGroupType::new(971, 969, "118.311", "118.5.969", 118, ConstructType::Type3),
    MagneticSpaceGroupType::new(972, 964, "118.312", "117.7.964", 118, ConstructType::Type4),
    MagneticSpaceGroupType::new(973, 928, "118.313", "112.7.928", 118, ConstructType::Type4),
    MagneticSpaceGroupType::new(974, 977, "118.314", "119.7.977", 118, ConstructType::Type4),
    MagneticSpaceGroupType::new(975, 971, "119.315", "119.1.971", 119, ConstructType::Type1),
    MagneticSpaceGroupType::new(976, 972, "119.316", "119.2.972", 119, ConstructType::Type2),
    MagneticSpaceGroupType::new(977, 973, "119.317", "119.3.973", 119, ConstructType::Type3),
    MagneticSpaceGroupType::new(978, 974, "119.318", "119.4.974", 119, ConstructType::Type3),
    MagneticSpaceGroupType::new(979, 975, "119.319", "119.5.975", 119, ConstructType::Type3),
    MagneticSpaceGroupType::new(980, 918, "119.320", "111.8.918", 119, ConstructType::Type4),
    MagneticSpaceGroupType::new(981, 978, "120.321", "120.1.978", 120, ConstructType::Type1),
    MagneticSpaceGroupType::new(982, 979, "120.322", "120.2.979", 120, ConstructType::Type2),
    MagneticSpaceGroupType::new(983, 980, "120.323", "120.3.980", 120, ConstructType::Type3),
    MagneticSpaceGroupType::new(984, 981, "120.324", "120.4.981", 120, ConstructType::Type3),
    MagneticSpaceGroupType::new(985, 982, "120.325", "120.5.982", 120, ConstructType::Type3),
    MagneticSpaceGroupType::new(986, 921, "120.326", "111.11.921", 120, ConstructType::Type4),
    MagneticSpaceGroupType::new(987, 985, "121.327", "121.1.985", 121, ConstructType::Type1),
    MagneticSpaceGroupType::new(988, 986, "121.328", "121.2.986", 121, ConstructType::Type2),
    MagneticSpaceGroupType::new(989, 987, "121.329", "121.3.987", 121, ConstructType::Type3),
    MagneticSpaceGroupType::new(990, 988, "121.330", "121.4.988", 121, ConstructType::Type3),
    MagneticSpaceGroupType::new(991, 989, "121.331", "121.5.989", 121, ConstructType::Type3),
    MagneticSpaceGroupType::new(992, 948, "121.332", "115.8.948", 121, ConstructType::Type4),
    MagneticSpaceGroupType::new(993, 994, "122.333", "122.1.994", 122, ConstructType::Type1),
    MagneticSpaceGroupType::new(994, 995, "122.334", "122.2.995", 122, ConstructType::Type2),
    MagneticSpaceGroupType::new(995, 996, "122.335", "122.3.996", 122, ConstructType::Type3),
    MagneticSpaceGroupType::new(996, 997, "122.336", "122.4.997", 122, ConstructType::Type3),
    MagneticSpaceGroupType::new(997, 998, "122.337", "122.5.998", 122, ConstructType::Type3),
    MagneticSpaceGroupType::new(998, 970, "122.338", "118.6.970", 122, ConstructType::Type4),
    MagneticSpaceGroupType::new(999, 999, "123.339", "123.1.999", 123, ConstructType::Type1),
    MagneticSpaceGroupType::new(
        1000,
        1000,
        "123.340",
        "123.2.1000",
        123,
        ConstructType::Type2,
    ),
    MagneticSpaceGroupType::new(
        1001,
        1001,
        "123.341",
        "123.3.1001",
        123,
        ConstructType::Type3,
    ),
    MagneticSpaceGroupType::new(
        1002,
        1002,
        "123.342",
        "123.4.1002",
        123,
        ConstructType::Type3,
    ),
    MagneticSpaceGroupType::new(
        1003,
        1003,
        "123.343",
        "123.5.1003",
        123,
        ConstructType::Type3,
    ),
    MagneticSpaceGroupType::new(
        1004,
        1004,
        "123.344",
        "123.6.1004",
        123,
        ConstructType::Type3,
    ),
    MagneticSpaceGroupType::new(
        1005,
        1005,
        "123.345",
        "123.7.1005",
        123,
        ConstructType::Type3,
    ),
    MagneticSpaceGroupType::new(
        1006,
        1006,
        "123.346",
        "123.8.1006",
        123,
        ConstructType::Type3,
    ),
    MagneticSpaceGroupType::new(
        1007,
        1007,
        "123.347",
        "123.9.1007",
        123,
        ConstructType::Type3,
    ),
    MagneticSpaceGroupType::new(
        1008,
        1008,
        "123.348",
        "123.10.1008",
        123,
        ConstructType::Type4,
    ),
    MagneticSpaceGroupType::new(
        1009,
        1009,
        "123.349",
        "123.11.1009",
        123,
        ConstructType::Type4,
    ),
    MagneticSpaceGroupType::new(
        1010,
        1188,
        "123.350",
        "139.10.1188",
        123,
        ConstructType::Type4,
    ),
    MagneticSpaceGroupType::new(
        1011,
        1018,
        "124.351",
        "124.1.1018",
        124,
        ConstructType::Type1,
    ),
    MagneticSpaceGroupType::new(
        1012,
        1019,
        "124.352",
        "124.2.1019",
        124,
        ConstructType::Type2,
    ),
    MagneticSpaceGroupType::new(
        1013,
        1020,
        "124.353",
        "124.3.1020",
        124,
        ConstructType::Type3,
    ),
    MagneticSpaceGroupType::new(
        1014,
        1021,
        "124.354",
        "124.4.1021",
        124,
        ConstructType::Type3,
    ),
    MagneticSpaceGroupType::new(
        1015,
        1022,
        "124.355",
        "124.5.1022",
        124,
        ConstructType::Type3,
    ),
    MagneticSpaceGroupType::new(
        1016,
        1023,
        "124.356",
        "124.6.1023",
        124,
        ConstructType::Type3,
    ),
    MagneticSpaceGroupType::new(
        1017,
        1024,
        "124.357",
        "124.7.1024",
        124,
        ConstructType::Type3,
    ),
    MagneticSpaceGroupType::new(
        1018,
        1025,
        "124.358",
        "124.8.1025",
        124,
        ConstructType::Type3,
    ),
    MagneticSpaceGroupType::new(
        1019,
        1026,
        "124.359",
        "124.9.1026",
        124,
        ConstructType::Type3,
    ),
    MagneticSpaceGroupType::new(
        1020,
        1013,
        "124.360",
        "123.15.1013",
        124,
        ConstructType::Type4,
    ),
    MagneticSpaceGroupType::new(
        1021,
        1027,
        "124.361",
        "124.10.1027",
        124,
        ConstructType::Type4,
    ),
    MagneticSpaceGroupType::new(
        1022,
        1205,
        "124.362",
        "140.10.1205",
        124,
        ConstructType::Type4,
    ),
    MagneticSpaceGroupType::new(
        1023,
        1031,
        "125.363",
        "125.1.1031",
        125,
        ConstructType::Type1,
    ),
    MagneticSpaceGroupType::new(
        1024,
        1032,
        "125.364",
        "125.2.1032",
        125,
        ConstructType::Type2,
    ),
    MagneticSpaceGroupType::new(
        1025,
        1033,
        "125.365",
        "125.3.1033",
        125,
        ConstructType::Type3,
    ),
    MagneticSpaceGroupType::new(
        1026,
        1034,
        "125.366",
        "125.4.1034",
        125,
        ConstructType::Type3,
    ),
    MagneticSpaceGroupType::new(
        1027,
        1035,
        "125.367",
        "125.5.1035",
        125,
        ConstructType::Type3,
    ),
    MagneticSpaceGroupType::new(
        1028,
        1036,
        "125.368",
        "125.6.1036",
        125,
        ConstructType::Type3,
    ),
    MagneticSpaceGroupType::new(
        1029,
        1037,
        "125.369",
        "125.7.1037",
        125,
        ConstructType::Type3,
    ),
    MagneticSpaceGroupType::new(
        1030,
        1038,
        "125.370",
        "125.8.1038",
        125,
        ConstructType::Type3,
    ),
    MagneticSpaceGroupType::new(
        1031,
        1039,
        "125.371",
        "125.9.1039",
        125,
        ConstructType::Type3,
    ),
    MagneticSpaceGroupType::new(
        1032,
        1040,
        "125.372",
        "125.10.1040",
        125,
        ConstructType::Type4,
    ),
    MagneticSpaceGroupType::new(
        1033,
        1016,
        "125.373",
        "123.18.1016",
        125,
        ConstructType::Type4,
    ),
    MagneticSpaceGroupType::new(
        1034,
        1212,
        "125.374",
        "140.17.1212",
        125,
        ConstructType::Type4,
    ),
    MagneticSpaceGroupType::new(
        1035,
        1044,
        "126.375",
        "126.1.1044",
        126,
        ConstructType::Type1,
    ),
    MagneticSpaceGroupType::new(
        1036,
        1045,
        "126.376",
        "126.2.1045",
        126,
        ConstructType::Type2,
    ),
    MagneticSpaceGroupType::new(
        1037,
        1046,
        "126.377",
        "126.3.1046",
        126,
        ConstructType::Type3,
    ),
    MagneticSpaceGroupType::new(
        1038,
        1047,
        "126.378",
        "126.4.1047",
        126,
        ConstructType::Type3,
    ),
    MagneticSpaceGroupType::new(
        1039,
        1048,
        "126.379",
        "126.5.1048",
        126,
        ConstructType::Type3,
    ),
    MagneticSpaceGroupType::new(
        1040,
        1049,
        "126.380",
        "126.6.1049",
        126,
        ConstructType::Type3,
    ),
    MagneticSpaceGroupType::new(
        1041,
        1050,
        "126.381",
        "126.7.1050",
        126,
        ConstructType::Type3,
    ),
    MagneticSpaceGroupType::new(
        1042,
        1051,
        "126.382",
        "126.8.1051",
        126,
        ConstructType::Type3,
    ),
    MagneticSpaceGroupType::new(
        1043,
        1052,
        "126.383",
        "126.9.1052",
        126,
        ConstructType::Type3,
    ),
    MagneticSpaceGroupType::new(
        1044,
        1043,
        "126.384",
        "125.13.1043",
        126,
        ConstructType::Type4,
    ),
    MagneticSpaceGroupType::new(
        1045,
        1030,
        "126.385",
        "124.13.1030",
        126,
        ConstructType::Type4,
    ),
    MagneticSpaceGroupType::new(
        1046,
        1195,
        "126.386",
        "139.17.1195",
        126,
        ConstructType::Type4,
    ),
    MagneticSpaceGroupType::new(
        1047,
        1053,
        "127.387",
        "127.1.1053",
        127,
        ConstructType::Type1,
    ),
    MagneticSpaceGroupType::new(
        1048,
        1054,
        "127.388",
        "127.2.1054",
        127,
        ConstructType::Type2,
    ),
    MagneticSpaceGroupType::new(
        1049,
        1055,
        "127.389",
        "127.3.1055",
        127,
        ConstructType::Type3,
    ),
    MagneticSpaceGroupType::new(
        1050,
        1056,
        "127.390",
        "127.4.1056",
        127,
        ConstructType::Type3,
    ),
    MagneticSpaceGroupType::new(
        1051,
        1057,
        "127.391",
        "127.5.1057",
        127,
        ConstructType::Type3,
    ),
    MagneticSpaceGroupType::new(
        1052,
        1058,
        "127.392",
        "127.6.1058",
        127,
        ConstructType::Type3,
    ),
    MagneticSpaceGroupType::new(
        1053,
        1059,
        "127.393",
        "127.7.1059",
        127,
        ConstructType::Type3,
    ),
    MagneticSpaceGroupType::new(
        1054,
        1060,
        "127.394",
        "127.8.1060",
        127,
        ConstructType::Type3,
    ),
    MagneticSpaceGroupType::new(
        1055,
        1061,
        "127.395",
        "127.9.1061",
        127,
        ConstructType::Type3,
    ),
    MagneticSpaceGroupType::new(
        1056,
        1062,
        "127.396",
        "127.10.1062",
        127,
        ConstructType::Type4,
    ),
    MagneticSpaceGroupType::new(
        1057,
        1015,
        "127.397",
        "123.17.1015",
        127,
        ConstructType::Type4,
    ),
    MagneticSpaceGroupType::new(
        1058,
        1210,
        "127.398",
        "140.15.1210",
        127,
        ConstructType::Type4,
    ),
    MagneticSpaceGroupType::new(
        1059,
        1066,
        "128.399",
        "128.1.1066",
        128,
        ConstructType::Type1,
    ),
    MagneticSpaceGroupType::new(
        1060,
        1067,
        "128.400",
        "128.2.1067",
        128,
        ConstructType::Type2,
    ),
    MagneticSpaceGroupType::new(
        1061,
        1068,
        "128.401",
        "128.3.1068",
        128,
        ConstructType::Type3,
    ),
    MagneticSpaceGroupType::new(
        1062,
        1069,
        "128.402",
        "128.4.1069",
        128,
        ConstructType::Type3,
    ),
    MagneticSpaceGroupType::new(
        1063,
        1070,
        "128.403",
        "128.5.1070",
        128,
        ConstructType::Type3,
    ),
    MagneticSpaceGroupType::new(
        1064,
        1071,
        "128.404",
        "128.6.1071",
        128,
        ConstructType::Type3,
    ),
    MagneticSpaceGroupType::new(
        1065,
        1072,
        "128.405",
        "128.7.1072",
        128,
        ConstructType::Type3,
    ),
    MagneticSpaceGroupType::new(
        1066,
        1073,
        "128.406",
        "128.8.1073",
        128,
        ConstructType::Type3,
    ),
    MagneticSpaceGroupType::new(
        1067,
        1074,
        "128.407",
        "128.9.1074",
        128,
        ConstructType::Type3,
    ),
    MagneticSpaceGroupType::new(
        1068,
        1065,
        "128.408",
        "127.13.1065",
        128,
        ConstructType::Type4,
    ),
    MagneticSpaceGroupType::new(
        1069,
        1029,
        "128.409",
        "124.12.1029",
        128,
        ConstructType::Type4,
    ),
    MagneticSpaceGroupType::new(
        1070,
        1193,
        "128.410",
        "139.15.1193",
        128,
        ConstructType::Type4,
    ),
    MagneticSpaceGroupType::new(
        1071,
        1075,
        "129.411",
        "129.1.1075",
        129,
        ConstructType::Type1,
    ),
    MagneticSpaceGroupType::new(
        1072,
        1076,
        "129.412",
        "129.2.1076",
        129,
        ConstructType::Type2,
    ),
    MagneticSpaceGroupType::new(
        1073,
        1077,
        "129.413",
        "129.3.1077",
        129,
        ConstructType::Type3,
    ),
    MagneticSpaceGroupType::new(
        1074,
        1078,
        "129.414",
        "129.4.1078",
        129,
        ConstructType::Type3,
    ),
    MagneticSpaceGroupType::new(
        1075,
        1079,
        "129.415",
        "129.5.1079",
        129,
        ConstructType::Type3,
    ),
    MagneticSpaceGroupType::new(
        1076,
        1080,
        "129.416",
        "129.6.1080",
        129,
        ConstructType::Type3,
    ),
    MagneticSpaceGroupType::new(
        1077,
        1081,
        "129.417",
        "129.7.1081",
        129,
        ConstructType::Type3,
    ),
    MagneticSpaceGroupType::new(
        1078,
        1082,
        "129.418",
        "129.8.1082",
        129,
        ConstructType::Type3,
    ),
    MagneticSpaceGroupType::new(
        1079,
        1083,
        "129.419",
        "129.9.1083",
        129,
        ConstructType::Type3,
    ),
    MagneticSpaceGroupType::new(
        1080,
        1084,
        "129.420",
        "129.10.1084",
        129,
        ConstructType::Type4,
    ),
    MagneticSpaceGroupType::new(
        1081,
        1014,
        "129.421",
        "123.16.1014",
        129,
        ConstructType::Type4,
    ),
    MagneticSpaceGroupType::new(
        1082,
        1189,
        "129.422",
        "139.11.1189",
        129,
        ConstructType::Type4,
    ),
    MagneticSpaceGroupType::new(
        1083,
        1088,
        "130.423",
        "130.1.1088",
        130,
        ConstructType::Type1,
    ),
    MagneticSpaceGroupType::new(
        1084,
        1089,
        "130.424",
        "130.2.1089",
        130,
        ConstructType::Type2,
    ),
    MagneticSpaceGroupType::new(
        1085,
        1090,
        "130.425",
        "130.3.1090",
        130,
        ConstructType::Type3,
    ),
    MagneticSpaceGroupType::new(
        1086,
        1091,
        "130.426",
        "130.4.1091",
        130,
        ConstructType::Type3,
    ),
    MagneticSpaceGroupType::new(
        1087,
        1092,
        "130.427",
        "130.5.1092",
        130,
        ConstructType::Type3,
    ),
    MagneticSpaceGroupType::new(
        1088,
        1093,
        "130.428",
        "130.6.1093",
        130,
        ConstructType::Type3,
    ),
    MagneticSpaceGroupType::new(
        1089,
        1094,
        "130.429",
        "130.7.1094",
        130,
        ConstructType::Type3,
    ),
    MagneticSpaceGroupType::new(
        1090,
        1095,
        "130.430",
        "130.8.1095",
        130,
        ConstructType::Type3,
    ),
    MagneticSpaceGroupType::new(
        1091,
        1096,
        "130.431",
        "130.9.1096",
        130,
        ConstructType::Type3,
    ),
    MagneticSpaceGroupType::new(
        1092,
        1087,
        "130.432",
        "129.13.1087",
        130,
        ConstructType::Type4,
    ),
    MagneticSpaceGroupType::new(
        1093,
        1028,
        "130.433",
        "124.11.1028",
        130,
        ConstructType::Type4,
    ),
    MagneticSpaceGroupType::new(
        1094,
        1206,
        "130.434",
        "140.11.1206",
        130,
        ConstructType::Type4,
    ),
    MagneticSpaceGroupType::new(
        1095,
        1097,
        "131.435",
        "131.1.1097",
        131,
        ConstructType::Type1,
    ),
    MagneticSpaceGroupType::new(
        1096,
        1098,
        "131.436",
        "131.2.1098",
        131,
        ConstructType::Type2,
    ),
    MagneticSpaceGroupType::new(
        1097,
        1099,
        "131.437",
        "131.3.1099",
        131,
        ConstructType::Type3,
    ),
    MagneticSpaceGroupType::new(
        1098,
        1100,
        "131.438",
        "131.4.1100",
        131,
        ConstructType::Type3,
    ),
    MagneticSpaceGroupType::new(
        1099,
        1101,
        "131.439",
        "131.5.1101",
        131,
        ConstructType::Type3,
    ),
    MagneticSpaceGroupType::new(
        1100,
        1102,
        "131.440",
        "131.6.1102",
        131,
        ConstructType::Type3,
    ),
    MagneticSpaceGroupType::new(
        1101,
        1103,
        "131.441",
        "131.7.1103",
        131,
        ConstructType::Type3,
    ),
    MagneticSpaceGroupType::new(
        1102,
        1104,
        "131.442",
        "131.8.1104",
        131,
        ConstructType::Type3,
    ),
    MagneticSpaceGroupType::new(
        1103,
        1105,
        "131.443",
        "131.9.1105",
        131,
        ConstructType::Type3,
    ),
    MagneticSpaceGroupType::new(
        1104,
        1012,
        "131.444",
        "123.14.1012",
        131,
        ConstructType::Type4,
    ),
    MagneticSpaceGroupType::new(
        1105,
        1119,
        "131.445",
        "132.10.1119",
        131,
        ConstructType::Type4,
    ),
    MagneticSpaceGroupType::new(
        1106,
        1191,
        "131.446",
        "139.13.1191",
        131,
        ConstructType::Type4,
    ),
    MagneticSpaceGroupType::new(
        1107,
        1110,
        "132.447",
        "132.1.1110",
        132,
        ConstructType::Type1,
    ),
    MagneticSpaceGroupType::new(
        1108,
        1111,
        "132.448",
        "132.2.1111",
        132,
        ConstructType::Type2,
    ),
    MagneticSpaceGroupType::new(
        1109,
        1112,
        "132.449",
        "132.3.1112",
        132,
        ConstructType::Type3,
    ),
    MagneticSpaceGroupType::new(
        1110,
        1113,
        "132.450",
        "132.4.1113",
        132,
        ConstructType::Type3,
    ),
    MagneticSpaceGroupType::new(
        1111,
        1114,
        "132.451",
        "132.5.1114",
        132,
        ConstructType::Type3,
    ),
    MagneticSpaceGroupType::new(
        1112,
        1115,
        "132.452",
        "132.6.1115",
        132,
        ConstructType::Type3,
    ),
    MagneticSpaceGroupType::new(
        1113,
        1116,
        "132.453",
        "132.7.1116",
        132,
        ConstructType::Type3,
    ),
    MagneticSpaceGroupType::new(
        1114,
        1117,
        "132.454",
        "132.8.1117",
        132,
        ConstructType::Type3,
    ),
    MagneticSpaceGroupType::new(
        1115,
        1118,
        "132.455",
        "132.9.1118",
        132,
        ConstructType::Type3,
    ),
    MagneticSpaceGroupType::new(
        1116,
        1011,
        "132.456",
        "123.13.1011",
        132,
        ConstructType::Type4,
    ),
    MagneticSpaceGroupType::new(
        1117,
        1106,
        "132.457",
        "131.10.1106",
        132,
        ConstructType::Type4,
    ),
    MagneticSpaceGroupType::new(
        1118,
        1208,
        "132.458",
        "140.13.1208",
        132,
        ConstructType::Type4,
    ),
    MagneticSpaceGroupType::new(
        1119,
        1123,
        "133.459",
        "133.1.1123",
        133,
        ConstructType::Type1,
    ),
    MagneticSpaceGroupType::new(
        1120,
        1124,
        "133.460",
        "133.2.1124",
        133,
        ConstructType::Type2,
    ),
    MagneticSpaceGroupType::new(
        1121,
        1125,
        "133.461",
        "133.3.1125",
        133,
        ConstructType::Type3,
    ),
    MagneticSpaceGroupType::new(
        1122,
        1126,
        "133.462",
        "133.4.1126",
        133,
        ConstructType::Type3,
    ),
    MagneticSpaceGroupType::new(
        1123,
        1127,
        "133.463",
        "133.5.1127",
        133,
        ConstructType::Type3,
    ),
    MagneticSpaceGroupType::new(
        1124,
        1128,
        "133.464",
        "133.6.1128",
        133,
        ConstructType::Type3,
    ),
    MagneticSpaceGroupType::new(
        1125,
        1129,
        "133.465",
        "133.7.1129",
        133,
        ConstructType::Type3,
    ),
    MagneticSpaceGroupType::new(
        1126,
        1130,
        "133.466",
        "133.8.1130",
        133,
        ConstructType::Type3,
    ),
    MagneticSpaceGroupType::new(
        1127,
        1131,
        "133.467",
        "133.9.1131",
        133,
        ConstructType::Type3,
    ),
    MagneticSpaceGroupType::new(
        1128,
        1042,
        "133.468",
        "125.12.1042",
        133,
        ConstructType::Type4,
    ),
    MagneticSpaceGroupType::new(
        1129,
        1122,
        "133.469",
        "132.13.1122",
        133,
        ConstructType::Type4,
    ),
    MagneticSpaceGroupType::new(
        1130,
        1209,
        "133.470",
        "140.14.1209",
        133,
        ConstructType::Type4,
    ),
    MagneticSpaceGroupType::new(
        1131,
        1132,
        "134.471",
        "134.1.1132",
        134,
        ConstructType::Type1,
    ),
    MagneticSpaceGroupType::new(
        1132,
        1133,
        "134.472",
        "134.2.1133",
        134,
        ConstructType::Type2,
    ),
    MagneticSpaceGroupType::new(
        1133,
        1134,
        "134.473",
        "134.3.1134",
        134,
        ConstructType::Type3,
    ),
    MagneticSpaceGroupType::new(
        1134,
        1135,
        "134.474",
        "134.4.1135",
        134,
        ConstructType::Type3,
    ),
    MagneticSpaceGroupType::new(
        1135,
        1136,
        "134.475",
        "134.5.1136",
        134,
        ConstructType::Type3,
    ),
    MagneticSpaceGroupType::new(
        1136,
        1137,
        "134.476",
        "134.6.1137",
        134,
        ConstructType::Type3,
    ),
    MagneticSpaceGroupType::new(
        1137,
        1138,
        "134.477",
        "134.7.1138",
        134,
        ConstructType::Type3,
    ),
    MagneticSpaceGroupType::new(
        1138,
        1139,
        "134.478",
        "134.8.1139",
        134,
        ConstructType::Type3,
    ),
    MagneticSpaceGroupType::new(
        1139,
        1140,
        "134.479",
        "134.9.1140",
        134,
        ConstructType::Type3,
    ),
    MagneticSpaceGroupType::new(
        1140,
        1041,
        "134.480",
        "125.11.1041",
        134,
        ConstructType::Type4,
    ),
    MagneticSpaceGroupType::new(
        1141,
        1109,
        "134.481",
        "131.13.1109",
        134,
        ConstructType::Type4,
    ),
    MagneticSpaceGroupType::new(
        1142,
        1192,
        "134.482",
        "139.14.1192",
        134,
        ConstructType::Type4,
    ),
    MagneticSpaceGroupType::new(
        1143,
        1143,
        "135.483",
        "135.1.1143",
        135,
        ConstructType::Type1,
    ),
    MagneticSpaceGroupType::new(
        1144,
        1144,
        "135.484",
        "135.2.1144",
        135,
        ConstructType::Type2,
    ),
    MagneticSpaceGroupType::new(
        1145,
        1145,
        "135.485",
        "135.3.1145",
        135,
        ConstructType::Type3,
    ),
    MagneticSpaceGroupType::new(
        1146,
        1146,
        "135.486",
        "135.4.1146",
        135,
        ConstructType::Type3,
    ),
    MagneticSpaceGroupType::new(
        1147,
        1147,
        "135.487",
        "135.5.1147",
        135,
        ConstructType::Type3,
    ),
    MagneticSpaceGroupType::new(
        1148,
        1148,
        "135.488",
        "135.6.1148",
        135,
        ConstructType::Type3,
    ),
    MagneticSpaceGroupType::new(
        1149,
        1149,
        "135.489",
        "135.7.1149",
        135,
        ConstructType::Type3,
    ),
    MagneticSpaceGroupType::new(
        1150,
        1150,
        "135.490",
        "135.8.1150",
        135,
        ConstructType::Type3,
    ),
    MagneticSpaceGroupType::new(
        1151,
        1151,
        "135.491",
        "135.9.1151",
        135,
        ConstructType::Type3,
    ),
    MagneticSpaceGroupType::new(
        1152,
        1064,
        "135.492",
        "127.12.1064",
        135,
        ConstructType::Type4,
    ),
    MagneticSpaceGroupType::new(
        1153,
        1121,
        "135.493",
        "132.12.1121",
        135,
        ConstructType::Type4,
    ),
    MagneticSpaceGroupType::new(
        1154,
        1207,
        "135.494",
        "140.12.1207",
        135,
        ConstructType::Type4,
    ),
    MagneticSpaceGroupType::new(
        1155,
        1152,
        "136.495",
        "136.1.1152",
        136,
        ConstructType::Type1,
    ),
    MagneticSpaceGroupType::new(
        1156,
        1153,
        "136.496",
        "136.2.1153",
        136,
        ConstructType::Type2,
    ),
    MagneticSpaceGroupType::new(
        1157,
        1154,
        "136.497",
        "136.3.1154",
        136,
        ConstructType::Type3,
    ),
    MagneticSpaceGroupType::new(
        1158,
        1155,
        "136.498",
        "136.4.1155",
        136,
        ConstructType::Type3,
    ),
    MagneticSpaceGroupType::new(
        1159,
        1156,
        "136.499",
        "136.5.1156",
        136,
        ConstructType::Type3,
    ),
    MagneticSpaceGroupType::new(
        1160,
        1157,
        "136.500",
        "136.6.1157",
        136,
        ConstructType::Type3,
    ),
    MagneticSpaceGroupType::new(
        1161,
        1158,
        "136.501",
        "136.7.1158",
        136,
        ConstructType::Type3,
    ),
    MagneticSpaceGroupType::new(
        1162,
        1159,
        "136.502",
        "136.8.1159",
        136,
        ConstructType::Type3,
    ),
    MagneticSpaceGroupType::new(
        1163,
        1160,
        "136.503",
        "136.9.1160",
        136,
        ConstructType::Type3,
    ),
    MagneticSpaceGroupType::new(
        1164,
        1063,
        "136.504",
        "127.11.1063",
        136,
        ConstructType::Type4,
    ),
    MagneticSpaceGroupType::new(
        1165,
        1108,
        "136.505",
        "131.12.1108",
        136,
        ConstructType::Type4,
    ),
    MagneticSpaceGroupType::new(
        1166,
        1190,
        "136.506",
        "139.12.1190",
        136,
        ConstructType::Type4,
    ),
    MagneticSpaceGroupType::new(
        1167,
        1161,
        "137.507",
        "137.1.1161",
        137,
        ConstructType::Type1,
    ),
    MagneticSpaceGroupType::new(
        1168,
        1162,
        "137.508",
        "137.2.1162",
        137,
        ConstructType::Type2,
    ),
    MagneticSpaceGroupType::new(
        1169,
        1163,
        "137.509",
        "137.3.1163",
        137,
        ConstructType::Type3,
    ),
    MagneticSpaceGroupType::new(
        1170,
        1164,
        "137.510",
        "137.4.1164",
        137,
        ConstructType::Type3,
    ),
    MagneticSpaceGroupType::new(
        1171,
        1165,
        "137.511",
        "137.5.1165",
        137,
        ConstructType::Type3,
    ),
    MagneticSpaceGroupType::new(
        1172,
        1166,
        "137.512",
        "137.6.1166",
        137,
        ConstructType::Type3,
    ),
    MagneticSpaceGroupType::new(
        1173,
        1167,
        "137.513",
        "137.7.1167",
        137,
        ConstructType::Type3,
    ),
    MagneticSpaceGroupType::new(
        1174,
        1168,
        "137.514",
        "137.8.1168",
        137,
        ConstructType::Type3,
    ),
    MagneticSpaceGroupType::new(
        1175,
        1169,
        "137.515",
        "137.9.1169",
        137,
        ConstructType::Type3,
    ),
    MagneticSpaceGroupType::new(
        1176,
        1086,
        "137.516",
        "129.12.1086",
        137,
        ConstructType::Type4,
    ),
    MagneticSpaceGroupType::new(
        1177,
        1120,
        "137.517",
        "132.11.1120",
        137,
        ConstructType::Type4,
    ),
    MagneticSpaceGroupType::new(
        1178,
        1194,
        "137.518",
        "139.16.1194",
        137,
        ConstructType::Type4,
    ),
    MagneticSpaceGroupType::new(
        1179,
        1170,
        "138.519",
        "138.1.1170",
        138,
        ConstructType::Type1,
    ),
    MagneticSpaceGroupType::new(
        1180,
        1171,
        "138.520",
        "138.2.1171",
        138,
        ConstructType::Type2,
    ),
    MagneticSpaceGroupType::new(
        1181,
        1172,
        "138.521",
        "138.3.1172",
        138,
        ConstructType::Type3,
    ),
    MagneticSpaceGroupType::new(
        1182,
        1173,
        "138.522",
        "138.4.1173",
        138,
        ConstructType::Type3,
    ),
    MagneticSpaceGroupType::new(
        1183,
        1174,
        "138.523",
        "138.5.1174",
        138,
        ConstructType::Type3,
    ),
    MagneticSpaceGroupType::new(
        1184,
        1175,
        "138.524",
        "138.6.1175",
        138,
        ConstructType::Type3,
    ),
    MagneticSpaceGroupType::new(
        1185,
        1176,
        "138.525",
        "138.7.1176",
        138,
        ConstructType::Type3,
    ),
    MagneticSpaceGroupType::new(
        1186,
        1177,
        "138.526",
        "138.8.1177",
        138,
        ConstructType::Type3,
    ),
    MagneticSpaceGroupType::new(
        1187,
        1178,
        "138.527",
        "138.9.1178",
        138,
        ConstructType::Type3,
    ),
    MagneticSpaceGroupType::new(
        1188,
        1085,
        "138.528",
        "129.11.1085",
        138,
        ConstructType::Type4,
    ),
    MagneticSpaceGroupType::new(
        1189,
        1107,
        "138.529",
        "131.11.1107",
        138,
        ConstructType::Type4,
    ),
    MagneticSpaceGroupType::new(
        1190,
        1211,
        "138.530",
        "140.16.1211",
        138,
        ConstructType::Type4,
    ),
    MagneticSpaceGroupType::new(
        1191,
        1179,
        "139.531",
        "139.1.1179",
        139,
        ConstructType::Type1,
    ),
    MagneticSpaceGroupType::new(
        1192,
        1180,
        "139.532",
        "139.2.1180",
        139,
        ConstructType::Type2,
    ),
    MagneticSpaceGroupType::new(
        1193,
        1181,
        "139.533",
        "139.3.1181",
        139,
        ConstructType::Type3,
    ),
    MagneticSpaceGroupType::new(
        1194,
        1182,
        "139.534",
        "139.4.1182",
        139,
        ConstructType::Type3,
    ),
    MagneticSpaceGroupType::new(
        1195,
        1183,
        "139.535",
        "139.5.1183",
        139,
        ConstructType::Type3,
    ),
    MagneticSpaceGroupType::new(
        1196,
        1184,
        "139.536",
        "139.6.1184",
        139,
        ConstructType::Type3,
    ),
    MagneticSpaceGroupType::new(
        1197,
        1185,
        "139.537",
        "139.7.1185",
        139,
        ConstructType::Type3,
    ),
    MagneticSpaceGroupType::new(
        1198,
        1186,
        "139.538",
        "139.8.1186",
        139,
        ConstructType::Type3,
    ),
    MagneticSpaceGroupType::new(
        1199,
        1187,
        "139.539",
        "139.9.1187",
        139,
        ConstructType::Type3,
    ),
    MagneticSpaceGroupType::new(
        1200,
        1010,
        "139.540",
        "123.12.1010",
        139,
        ConstructType::Type4,
    ),
    MagneticSpaceGroupType::new(
        1201,
        1196,
        "140.541",
        "140.1.1196",
        140,
        ConstructType::Type1,
    ),
    MagneticSpaceGroupType::new(
        1202,
        1197,
        "140.542",
        "140.2.1197",
        140,
        ConstructType::Type2,
    ),
    MagneticSpaceGroupType::new(
        1203,
        1198,
        "140.543",
        "140.3.1198",
        140,
        ConstructType::Type3,
    ),
    MagneticSpaceGroupType::new(
        1204,
        1199,
        "140.544",
        "140.4.1199",
        140,
        ConstructType::Type3,
    ),
    MagneticSpaceGroupType::new(
        1205,
        1200,
        "140.545",
        "140.5.1200",
        140,
        ConstructType::Type3,
    ),
    MagneticSpaceGroupType::new(
        1206,
        1201,
        "140.546",
        "140.6.1201",
        140,
        ConstructType::Type3,
    ),
    MagneticSpaceGroupType::new(
        1207,
        1202,
        "140.547",
        "140.7.1202",
        140,
        ConstructType::Type3,
    ),
    MagneticSpaceGroupType::new(
        1208,
        1203,
        "140.548",
        "140.8.1203",
        140,
        ConstructType::Type3,
    ),
    MagneticSpaceGroupType::new(
        1209,
        1204,
        "140.549",
        "140.9.1204",
        140,
        ConstructType::Type3,
    ),
    MagneticSpaceGroupType::new(
        1210,
        1017,
        "140.550",
        "123.19.1017",
        140,
        ConstructType::Type4,
    ),
    MagneticSpaceGroupType::new(
        1211,
        1213,
        "141.551",
        "141.1.1213",
        141,
        ConstructType::Type1,
    ),
    MagneticSpaceGroupType::new(
        1212,
        1214,
        "141.552",
        "141.2.1214",
        141,
        ConstructType::Type2,
    ),
    MagneticSpaceGroupType::new(
        1213,
        1215,
        "141.553",
        "141.3.1215",
        141,
        ConstructType::Type3,
    ),
    MagneticSpaceGroupType::new(
        1214,
        1216,
        "141.554",
        "141.4.1216",
        141,
        ConstructType::Type3,
    ),
    MagneticSpaceGroupType::new(
        1215,
        1217,
        "141.555",
        "141.5.1217",
        141,
        ConstructType::Type3,
    ),
    MagneticSpaceGroupType::new(
        1216,
        1218,
        "141.556",
        "141.6.1218",
        141,
        ConstructType::Type3,
    ),
    MagneticSpaceGroupType::new(
        1217,
        1219,
        "141.557",
        "141.7.1219",
        141,
        ConstructType::Type3,
    ),
    MagneticSpaceGroupType::new(
        1218,
        1220,
        "141.558",
        "141.8.1220",
        141,
        ConstructType::Type3,
    ),
    MagneticSpaceGroupType::new(
        1219,
        1221,
        "141.559",
        "141.9.1221",
        141,
        ConstructType::Type3,
    ),
    MagneticSpaceGroupType::new(
        1220,
        1141,
        "141.560",
        "134.10.1141",
        141,
        ConstructType::Type4,
    ),
    MagneticSpaceGroupType::new(
        1221,
        1222,
        "142.561",
        "142.1.1222",
        142,
        ConstructType::Type1,
    ),
    MagneticSpaceGroupType::new(
        1222,
        1223,
        "142.562",
        "142.2.1223",
        142,
        ConstructType::Type2,
    ),
    MagneticSpaceGroupType::new(
        1223,
        1224,
        "142.563",
        "142.3.1224",
        142,
        ConstructType::Type3,
    ),
    MagneticSpaceGroupType::new(
        1224,
        1225,
        "142.564",
        "142.4.1225",
        142,
        ConstructType::Type3,
    ),
    MagneticSpaceGroupType::new(
        1225,
        1226,
        "142.565",
        "142.5.1226",
        142,
        ConstructType::Type3,
    ),
    MagneticSpaceGroupType::new(
        1226,
        1227,
        "142.566",
        "142.6.1227",
        142,
        ConstructType::Type3,
    ),
    MagneticSpaceGroupType::new(
        1227,
        1228,
        "142.567",
        "142.7.1228",
        142,
        ConstructType::Type3,
    ),
    MagneticSpaceGroupType::new(
        1228,
        1229,
        "142.568",
        "142.8.1229",
        142,
        ConstructType::Type3,
    ),
    MagneticSpaceGroupType::new(
        1229,
        1230,
        "142.569",
        "142.9.1230",
        142,
        ConstructType::Type3,
    ),
    MagneticSpaceGroupType::new(
        1230,
        1142,
        "142.570",
        "134.11.1142",
        142,
        ConstructType::Type4,
    ),
    MagneticSpaceGroupType::new(1231, 1231, "143.1", "143.1.1231", 143, ConstructType::Type1),
    MagneticSpaceGroupType::new(1232, 1232, "143.2", "143.2.1232", 143, ConstructType::Type2),
    MagneticSpaceGroupType::new(1233, 1233, "143.3", "143.3.1233", 143, ConstructType::Type4),
    MagneticSpaceGroupType::new(1234, 1234, "144.4", "144.1.1234", 144, ConstructType::Type1),
    MagneticSpaceGroupType::new(1235, 1235, "144.5", "144.2.1235", 144, ConstructType::Type2),
    MagneticSpaceGroupType::new(1236, 1239, "144.6", "145.3.1239", 144, ConstructType::Type4),
    MagneticSpaceGroupType::new(1237, 1237, "145.7", "145.1.1237", 145, ConstructType::Type1),
    MagneticSpaceGroupType::new(1238, 1238, "145.8", "145.2.1238", 145, ConstructType::Type2),
    MagneticSpaceGroupType::new(1239, 1236, "145.9", "144.3.1236", 145, ConstructType::Type4),
    MagneticSpaceGroupType::new(
        1240,
        1240,
        "146.10",
        "146.1.1240",
        146,
        ConstructType::Type1,
    ),
    MagneticSpaceGroupType::new(
        1241,
        1241,
        "146.11",
        "146.2.1241",
        146,
        ConstructType::Type2,
    ),
    MagneticSpaceGroupType::new(
        1242,
        1242,
        "146.12",
        "146.3.1242",
        146,
        ConstructType::Type4,
    ),
    MagneticSpaceGroupType::new(
        1243,
        1243,
        "147.13",
        "147.1.1243",
        147,
        ConstructType::Type1,
    ),
    MagneticSpaceGroupType::new(
        1244,
        1244,
        "147.14",
        "147.2.1244",
        147,
        ConstructType::Type2,
    ),
    MagneticSpaceGroupType::new(
        1245,
        1245,
        "147.15",
        "147.3.1245",
        147,
        ConstructType::Type3,
    ),
    MagneticSpaceGroupType::new(
        1246,
        1246,
        "147.16",
        "147.4.1246",
        147,
        ConstructType::Type4,
    ),
    MagneticSpaceGroupType::new(
        1247,
        1247,
        "148.17",
        "148.1.1247",
        148,
        ConstructType::Type1,
    ),
    MagneticSpaceGroupType::new(
        1248,
        1248,
        "148.18",
        "148.2.1248",
        148,
        ConstructType::Type2,
    ),
    MagneticSpaceGroupType::new(
        1249,
        1249,
        "148.19",
        "148.3.1249",
        148,
        ConstructType::Type3,
    ),
    MagneticSpaceGroupType::new(
        1250,
        1250,
        "148.20",
        "148.4.1250",
        148,
        ConstructType::Type4,
    ),
    MagneticSpaceGroupType::new(
        1251,
        1251,
        "149.21",
        "149.1.1251",
        149,
        ConstructType::Type1,
    ),
    MagneticSpaceGroupType::new(
        1252,
        1252,
        "149.22",
        "149.2.1252",
        149,
        ConstructType::Type2,
    ),
    MagneticSpaceGroupType::new(
        1253,
        1253,
        "149.23",
        "149.3.1253",
        149,
        ConstructType::Type3,
    ),
    MagneticSpaceGroupType::new(
        1254,
        1254,
        "149.24",
        "149.4.1254",
        149,
        ConstructType::Type4,
    ),
    MagneticSpaceGroupType::new(
        1255,
        1255,
        "150.25",
        "150.1.1255",
        150,
        ConstructType::Type1,
    ),
    MagneticSpaceGroupType::new(
        1256,
        1256,
        "150.26",
        "150.2.1256",
        150,
        ConstructType::Type2,
    ),
    MagneticSpaceGroupType::new(
        1257,
        1257,
        "150.27",
        "150.3.1257",
        150,
        ConstructType::Type3,
    ),
    MagneticSpaceGroupType::new(
        1258,
        1258,
        "150.28",
        "150.4.1258",
        150,
        ConstructType::Type4,
    ),
    MagneticSpaceGroupType::new(
        1259,
        1259,
        "151.29",
        "151.1.1259",
        151,
        ConstructType::Type1,
    ),
    MagneticSpaceGroupType::new(
        1260,
        1260,
        "151.30",
        "151.2.1260",
        151,
        ConstructType::Type2,
    ),
    MagneticSpaceGroupType::new(
        1261,
        1261,
        "151.31",
        "151.3.1261",
        151,
        ConstructType::Type3,
    ),
    MagneticSpaceGroupType::new(
        1262,
        1270,
        "151.32",
        "153.4.1270",
        151,
        ConstructType::Type4,
    ),
    MagneticSpaceGroupType::new(
        1263,
        1263,
        "152.33",
        "152.1.1263",
        152,
        ConstructType::Type1,
    ),
    MagneticSpaceGroupType::new(
        1264,
        1264,
        "152.34",
        "152.2.1264",
        152,
        ConstructType::Type2,
    ),
    MagneticSpaceGroupType::new(
        1265,
        1265,
        "152.35",
        "152.3.1265",
        152,
        ConstructType::Type3,
    ),
    MagneticSpaceGroupType::new(
        1266,
        1274,
        "152.36",
        "154.4.1274",
        152,
        ConstructType::Type4,
    ),
    MagneticSpaceGroupType::new(
        1267,
        1267,
        "153.37",
        "153.1.1267",
        153,
        ConstructType::Type1,
    ),
    MagneticSpaceGroupType::new(
        1268,
        1268,
        "153.38",
        "153.2.1268",
        153,
        ConstructType::Type2,
    ),
    MagneticSpaceGroupType::new(
        1269,
        1269,
        "153.39",
        "153.3.1269",
        153,
        ConstructType::Type3,
    ),
    MagneticSpaceGroupType::new(
        1270,
        1262,
        "153.40",
        "151.4.1262",
        153,
        ConstructType::Type4,
    ),
    MagneticSpaceGroupType::new(
        1271,
        1271,
        "154.41",
        "154.1.1271",
        154,
        ConstructType::Type1,
    ),
    MagneticSpaceGroupType::new(
        1272,
        1272,
        "154.42",
        "154.2.1272",
        154,
        ConstructType::Type2,
    ),
    MagneticSpaceGroupType::new(
        1273,
        1273,
        "154.43",
        "154.3.1273",
        154,
        ConstructType::Type3,
    ),
    MagneticSpaceGroupType::new(
        1274,
        1266,
        "154.44",
        "152.4.1266",
        154,
        ConstructType::Type4,
    ),
    MagneticSpaceGroupType::new(
        1275,
        1275,
        "155.45",
        "155.1.1275",
        155,
        ConstructType::Type1,
    ),
    MagneticSpaceGroupType::new(
        1276,
        1276,
        "155.46",
        "155.2.1276",
        155,
        ConstructType::Type2,
    ),
    MagneticSpaceGroupType::new(
        1277,
        1277,
        "155.47",
        "155.3.1277",
        155,
        ConstructType::Type3,
    ),
    MagneticSpaceGroupType::new(
        1278,
        1278,
        "155.48",
        "155.4.1278",
        155,
        ConstructType::Type4,
    ),
    MagneticSpaceGroupType::new(
        1279,
        1279,
        "156.49",
        "156.1.1279",
        156,
        ConstructType::Type1,
    ),
    MagneticSpaceGroupType::new(
        1280,
        1280,
        "156.50",
        "156.2.1280",
        156,
        ConstructType::Type2,
    ),
    MagneticSpaceGroupType::new(
        1281,
        1281,
        "156.51",
        "156.3.1281",
        156,
        ConstructType::Type3,
    ),
    MagneticSpaceGroupType::new(
        1282,
        1282,
        "156.52",
        "156.4.1282",
        156,
        ConstructType::Type4,
    ),
    MagneticSpaceGroupType::new(
        1283,
        1284,
        "157.53",
        "157.1.1284",
        157,
        ConstructType::Type1,
    ),
    MagneticSpaceGroupType::new(
        1284,
        1285,
        "157.54",
        "157.2.1285",
        157,
        ConstructType::Type2,
    ),
    MagneticSpaceGroupType::new(
        1285,
        1286,
        "157.55",
        "157.3.1286",
        157,
        ConstructType::Type3,
    ),
    MagneticSpaceGroupType::new(
        1286,
        1287,
        "157.56",
        "157.4.1287",
        157,
        ConstructType::Type4,
    ),
    MagneticSpaceGroupType::new(
        1287,
        1289,
        "158.57",
        "158.1.1289",
        158,
        ConstructType::Type1,
    ),
    MagneticSpaceGroupType::new(
        1288,
        1290,
        "158.58",
        "158.2.1290",
        158,
        ConstructType::Type2,
    ),
    MagneticSpaceGroupType::new(
        1289,
        1291,
        "158.59",
        "158.3.1291",
        158,
        ConstructType::Type3,
    ),
    MagneticSpaceGroupType::new(
        1290,
        1283,
        "158.60",
        "156.5.1283",
        158,
        ConstructType::Type4,
    ),
    MagneticSpaceGroupType::new(
        1291,
        1292,
        "159.61",
        "159.1.1292",
        159,
        ConstructType::Type1,
    ),
    MagneticSpaceGroupType::new(
        1292,
        1293,
        "159.62",
        "159.2.1293",
        159,
        ConstructType::Type2,
    ),
    MagneticSpaceGroupType::new(
        1293,
        1294,
        "159.63",
        "159.3.1294",
        159,
        ConstructType::Type3,
    ),
    MagneticSpaceGroupType::new(
        1294,
        1288,
        "159.64",
        "157.5.1288",
        159,
        ConstructType::Type4,
    ),
    MagneticSpaceGroupType::new(
        1295,
        1295,
        "160.65",
        "160.1.1295",
        160,
        ConstructType::Type1,
    ),
    MagneticSpaceGroupType::new(
        1296,
        1296,
        "160.66",
        "160.2.1296",
        160,
        ConstructType::Type2,
    ),
    MagneticSpaceGroupType::new(
        1297,
        1297,
        "160.67",
        "160.3.1297",
        160,
        ConstructType::Type3,
    ),
    MagneticSpaceGroupType::new(
        1298,
        1298,
        "160.68",
        "160.4.1298",
        160,
        ConstructType::Type4,
    ),
    MagneticSpaceGroupType::new(
        1299,
        1300,
        "161.69",
        "161.1.1300",
        161,
        ConstructType::Type1,
    ),
    MagneticSpaceGroupType::new(
        1300,
        1301,
        "161.70",
        "161.2.1301",
        161,
        ConstructType::Type2,
    ),
    MagneticSpaceGroupType::new(
        1301,
        1302,
        "161.71",
        "161.3.1302",
        161,
        ConstructType::Type3,
    ),
    MagneticSpaceGroupType::new(
        1302,
        1299,
        "161.72",
        "160.5.1299",
        161,
        ConstructType::Type4,
    ),
    MagneticSpaceGroupType::new(
        1303,
        1303,
        "162.73",
        "162.1.1303",
        162,
        ConstructType::Type1,
    ),
    MagneticSpaceGroupType::new(
        1304,
        1304,
        "162.74",
        "162.2.1304",
        162,
        ConstructType::Type2,
    ),
    MagneticSpaceGroupType::new(
        1305,
        1305,
        "162.75",
        "162.3.1305",
        162,
        ConstructType::Type3,
    ),
    MagneticSpaceGroupType::new(
        1306,
        1306,
        "162.76",
        "162.4.1306",
        162,
        ConstructType::Type3,
    ),
    MagneticSpaceGroupType::new(
        1307,
        1307,
        "162.77",
        "162.5.1307",
        162,
        ConstructType::Type3,
    ),
    MagneticSpaceGroupType::new(
        1308,
        1308,
        "162.78",
        "162.6.1308",
        162,
        ConstructType::Type4,
    ),
    MagneticSpaceGroupType::new(
        1309,
        1310,
        "163.79",
        "163.1.1310",
        163,
        ConstructType::Type1,
    ),
    MagneticSpaceGroupType::new(
        1310,
        1311,
        "163.80",
        "163.2.1311",
        163,
        ConstructType::Type2,
    ),
    MagneticSpaceGroupType::new(
        1311,
        1312,
        "163.81",
        "163.3.1312",
        163,
        ConstructType::Type3,
    ),
    MagneticSpaceGroupType::new(
        1312,
        1313,
        "163.82",
        "163.4.1313",
        163,
        ConstructType::Type3,
    ),
    MagneticSpaceGroupType::new(
        1313,
        1314,
        "163.83",
        "163.5.1314",
        163,
        ConstructType::Type3,
    ),
    MagneticSpaceGroupType::new(
        1314,
        1309,
        "163.84",
        "162.7.1309",
        163,
        ConstructType::Type4,
    ),
    MagneticSpaceGroupType::new(
        1315,
        1315,
        "164.85",
        "164.1.1315",
        164,
        ConstructType::Type1,
    ),
    MagneticSpaceGroupType::new(
        1316,
        1316,
        "164.86",
        "164.2.1316",
        164,
        ConstructType::Type2,
    ),
    MagneticSpaceGroupType::new(
        1317,
        1317,
        "164.87",
        "164.3.1317",
        164,
        ConstructType::Type3,
    ),
    MagneticSpaceGroupType::new(
        1318,
        1318,
        "164.88",
        "164.4.1318",
        164,
        ConstructType::Type3,
    ),
    MagneticSpaceGroupType::new(
        1319,
        1319,
        "164.89",
        "164.5.1319",
        164,
        ConstructType::Type3,
    ),
    MagneticSpaceGroupType::new(
        1320,
        1320,
        "164.90",
        "164.6.1320",
        164,
        ConstructType::Type4,
    ),
    MagneticSpaceGroupType::new(
        1321,
        1322,
        "165.91",
        "165.1.1322",
        165,
        ConstructType::Type1,
    ),
    MagneticSpaceGroupType::new(
        1322,
        1323,
        "165.92",
        "165.2.1323",
        165,
        ConstructType::Type2,
    ),
    MagneticSpaceGroupType::new(
        1323,
        1324,
        "165.93",
        "165.3.1324",
        165,
        ConstructType::Type3,
    ),
    MagneticSpaceGroupType::new(
        1324,
        1325,
        "165.94",
        "165.4.1325",
        165,
        ConstructType::Type3,
    ),
    MagneticSpaceGroupType::new(
        1325,
        1326,
        "165.95",
        "165.5.1326",
        165,
        ConstructType::Type3,
    ),
    MagneticSpaceGroupType::new(
        1326,
        1321,
        "165.96",
        "164.7.1321",
        165,
        ConstructType::Type4,
    ),
    MagneticSpaceGroupType::new(
        1327,
        1327,
        "166.97",
        "166.1.1327",
        166,
        ConstructType::Type1,
    ),
    MagneticSpaceGroupType::new(
        1328,
        1328,
        "166.98",
        "166.2.1328",
        166,
        ConstructType::Type2,
    ),
    MagneticSpaceGroupType::new(
        1329,
        1329,
        "166.99",
        "166.3.1329",
        166,
        ConstructType::Type3,
    ),
    MagneticSpaceGroupType::new(
        1330,
        1330,
        "166.100",
        "166.4.1330",
        166,
        ConstructType::Type3,
    ),
    MagneticSpaceGroupType::new(
        1331,
        1331,
        "166.101",
        "166.5.1331",
        166,
        ConstructType::Type3,
    ),
    MagneticSpaceGroupType::new(
        1332,
        1332,
        "166.102",
        "166.6.1332",
        166,
        ConstructType::Type4,
    ),
    MagneticSpaceGroupType::new(
        1333,
        1334,
        "167.103",
        "167.1.1334",
        167,
        ConstructType::Type1,
    ),
    MagneticSpaceGroupType::new(
        1334,
        1335,
        "167.104",
        "167.2.1335",
        167,
        ConstructType::Type2,
    ),
    MagneticSpaceGroupType::new(
        1335,
        1336,
        "167.105",
        "167.3.1336",
        167,
        ConstructType::Type3,
    ),
    MagneticSpaceGroupType::new(
        1336,
        1337,
        "167.106",
        "167.4.1337",
        167,
        ConstructType::Type3,
    ),
    MagneticSpaceGroupType::new(
        1337,
        1338,
        "167.107",
        "167.5.1338",
        167,
        ConstructType::Type3,
    ),
    MagneticSpaceGroupType::new(
        1338,
        1333,
        "167.108",
        "166.7.1333",
        167,
        ConstructType::Type4,
    ),
    MagneticSpaceGroupType::new(
        1339,
        1339,
        "168.109",
        "168.1.1339",
        168,
        ConstructType::Type1,
    ),
    MagneticSpaceGroupType::new(
        1340,
        1340,
        "168.110",
        "168.2.1340",
        168,
        ConstructType::Type2,
    ),
    MagneticSpaceGroupType::new(
        1341,
        1341,
        "168.111",
        "168.3.1341",
        168,
        ConstructType::Type3,
    ),
    MagneticSpaceGroupType::new(
        1342,
        1342,
        "168.112",
        "168.4.1342",
        168,
        ConstructType::Type4,
    ),
    MagneticSpaceGroupType::new(
        1343,
        1344,
        "169.113",
        "169.1.1344",
        169,
        ConstructType::Type1,
    ),
    MagneticSpaceGroupType::new(
        1344,
        1345,
        "169.114",
        "169.2.1345",
        169,
        ConstructType::Type2,
    ),
    MagneticSpaceGroupType::new(
        1345,
        1346,
        "169.115",
        "169.3.1346",
        169,
        ConstructType::Type3,
    ),
    MagneticSpaceGroupType::new(
        1346,
        1353,
        "169.116",
        "171.4.1353",
        169,
        ConstructType::Type4,
    ),
    MagneticSpaceGroupType::new(
        1347,
        1347,
        "170.117",
        "170.1.1347",
        170,
        ConstructType::Type1,
    ),
    MagneticSpaceGroupType::new(
        1348,
        1348,
        "170.118",
        "170.2.1348",
        170,
        ConstructType::Type2,
    ),
    MagneticSpaceGroupType::new(
        1349,
        1349,
        "170.119",
        "170.3.1349",
        170,
        ConstructType::Type3,
    ),
    MagneticSpaceGroupType::new(
        1350,
        1359,
        "170.120",
        "172.5.1359",
        170,
        ConstructType::Type4,
    ),
    MagneticSpaceGroupType::new(
        1351,
        1350,
        "171.121",
        "171.1.1350",
        171,
        ConstructType::Type1,
    ),
    MagneticSpaceGroupType::new(
        1352,
        1351,
        "171.122",
        "171.2.1351",
        171,
        ConstructType::Type2,
    ),
    MagneticSpaceGroupType::new(
        1353,
        1352,
        "171.123",
        "171.3.1352",
        171,
        ConstructType::Type3,
    ),
    MagneticSpaceGroupType::new(
        1354,
        1358,
        "171.124",
        "172.4.1358",
        171,
        ConstructType::Type4,
    ),
    MagneticSpaceGroupType::new(
        1355,
        1355,
        "172.125",
        "172.1.1355",
        172,
        ConstructType::Type1,
    ),
    MagneticSpaceGroupType::new(
        1356,
        1356,
        "172.126",
        "172.2.1356",
        172,
        ConstructType::Type2,
    ),
    MagneticSpaceGroupType::new(
        1357,
        1357,
        "172.127",
        "172.3.1357",
        172,
        ConstructType::Type3,
    ),
    MagneticSpaceGroupType::new(
        1358,
        1354,
        "172.128",
        "171.5.1354",
        172,
        ConstructType::Type4,
    ),
    MagneticSpaceGroupType::new(
        1359,
        1360,
        "173.129",
        "173.1.1360",
        173,
        ConstructType::Type1,
    ),
    MagneticSpaceGroupType::new(
        1360,
        1361,
        "173.130",
        "173.2.1361",
        173,
        ConstructType::Type2,
    ),
    MagneticSpaceGroupType::new(
        1361,
        1362,
        "173.131",
        "173.3.1362",
        173,
        ConstructType::Type3,
    ),
    MagneticSpaceGroupType::new(
        1362,
        1343,
        "173.132",
        "168.5.1343",
        173,
        ConstructType::Type4,
    ),
    MagneticSpaceGroupType::new(
        1363,
        1363,
        "174.133",
        "174.1.1363",
        174,
        ConstructType::Type1,
    ),
    MagneticSpaceGroupType::new(
        1364,
        1364,
        "174.134",
        "174.2.1364",
        174,
        ConstructType::Type2,
    ),
    MagneticSpaceGroupType::new(
        1365,
        1365,
        "174.135",
        "174.3.1365",
        174,
        ConstructType::Type3,
    ),
    MagneticSpaceGroupType::new(
        1366,
        1366,
        "174.136",
        "174.4.1366",
        174,
        ConstructType::Type4,
    ),
    MagneticSpaceGroupType::new(
        1367,
        1367,
        "175.137",
        "175.1.1367",
        175,
        ConstructType::Type1,
    ),
    MagneticSpaceGroupType::new(
        1368,
        1368,
        "175.138",
        "175.2.1368",
        175,
        ConstructType::Type2,
    ),
    MagneticSpaceGroupType::new(
        1369,
        1369,
        "175.139",
        "175.3.1369",
        175,
        ConstructType::Type3,
    ),
    MagneticSpaceGroupType::new(
        1370,
        1370,
        "175.140",
        "175.4.1370",
        175,
        ConstructType::Type3,
    ),
    MagneticSpaceGroupType::new(
        1371,
        1371,
        "175.141",
        "175.5.1371",
        175,
        ConstructType::Type3,
    ),
    MagneticSpaceGroupType::new(
        1372,
        1372,
        "175.142",
        "175.6.1372",
        175,
        ConstructType::Type4,
    ),
    MagneticSpaceGroupType::new(
        1373,
        1374,
        "176.143",
        "176.1.1374",
        176,
        ConstructType::Type1,
    ),
    MagneticSpaceGroupType::new(
        1374,
        1375,
        "176.144",
        "176.2.1375",
        176,
        ConstructType::Type2,
    ),
    MagneticSpaceGroupType::new(
        1375,
        1376,
        "176.145",
        "176.3.1376",
        176,
        ConstructType::Type3,
    ),
    MagneticSpaceGroupType::new(
        1376,
        1377,
        "176.146",
        "176.4.1377",
        176,
        ConstructType::Type3,
    ),
    MagneticSpaceGroupType::new(
        1377,
        1378,
        "176.147",
        "176.5.1378",
        176,
        ConstructType::Type3,
    ),
    MagneticSpaceGroupType::new(
        1378,
        1373,
        "176.148",
        "175.7.1373",
        176,
        ConstructType::Type4,
    ),
    MagneticSpaceGroupType::new(
        1379,
        1379,
        "177.149",
        "177.1.1379",
        177,
        ConstructType::Type1,
    ),
    MagneticSpaceGroupType::new(
        1380,
        1380,
        "177.150",
        "177.2.1380",
        177,
        ConstructType::Type2,
    ),
    MagneticSpaceGroupType::new(
        1381,
        1381,
        "177.151",
        "177.3.1381",
        177,
        ConstructType::Type3,
    ),
    MagneticSpaceGroupType::new(
        1382,
        1382,
        "177.152",
        "177.4.1382",
        177,
        ConstructType::Type3,
    ),
    MagneticSpaceGroupType::new(
        1383,
        1383,
        "177.153",
        "177.5.1383",
        177,
        ConstructType::Type3,
    ),
    MagneticSpaceGroupType::new(
        1384,
        1384,
        "177.154",
        "177.6.1384",
        177,
        ConstructType::Type4,
    ),
    MagneticSpaceGroupType::new(
        1385,
        1386,
        "178.155",
        "178.1.1386",
        178,
        ConstructType::Type1,
    ),
    MagneticSpaceGroupType::new(
        1386,
        1387,
        "178.156",
        "178.2.1387",
        178,
        ConstructType::Type2,
    ),
    MagneticSpaceGroupType::new(
        1387,
        1388,
        "178.157",
        "178.3.1388",
        178,
        ConstructType::Type3,
    ),
    MagneticSpaceGroupType::new(
        1388,
        1389,
        "178.158",
        "178.4.1389",
        178,
        ConstructType::Type3,
    ),
    MagneticSpaceGroupType::new(
        1389,
        1390,
        "178.159",
        "178.5.1390",
        178,
        ConstructType::Type3,
    ),
    MagneticSpaceGroupType::new(
        1390,
        1401,
        "178.160",
        "180.6.1401",
        178,
        ConstructType::Type4,
    ),
    MagneticSpaceGroupType::new(
        1391,
        1391,
        "179.161",
        "179.1.1391",
        179,
        ConstructType::Type1,
    ),
    MagneticSpaceGroupType::new(
        1392,
        1392,
        "179.162",
        "179.2.1392",
        179,
        ConstructType::Type2,
    ),
    MagneticSpaceGroupType::new(
        1393,
        1393,
        "179.163",
        "179.3.1393",
        179,
        ConstructType::Type3,
    ),
    MagneticSpaceGroupType::new(
        1394,
        1394,
        "179.164",
        "179.4.1394",
        179,
        ConstructType::Type3,
    ),
    MagneticSpaceGroupType::new(
        1395,
        1395,
        "179.165",
        "179.5.1395",
        179,
        ConstructType::Type3,
    ),
    MagneticSpaceGroupType::new(
        1396,
        1409,
        "179.166",
        "181.7.1409",
        179,
        ConstructType::Type4,
    ),
    MagneticSpaceGroupType::new(
        1397,
        1396,
        "180.167",
        "180.1.1396",
        180,
        ConstructType::Type1,
    ),
    MagneticSpaceGroupType::new(
        1398,
        1397,
        "180.168",
        "180.2.1397",
        180,
        ConstructType::Type2,
    ),
    MagneticSpaceGroupType::new(
        1399,
        1398,
        "180.169",
        "180.3.1398",
        180,
        ConstructType::Type3,
    ),
    MagneticSpaceGroupType::new(
        1400,
        1399,
        "180.170",
        "180.4.1399",
        180,
        ConstructType::Type3,
    ),
    MagneticSpaceGroupType::new(
        1401,
        1400,
        "180.171",
        "180.5.1400",
        180,
        ConstructType::Type3,
    ),
    MagneticSpaceGroupType::new(
        1402,
        1408,
        "180.172",
        "181.6.1408",
        180,
        ConstructType::Type4,
    ),
    MagneticSpaceGroupType::new(
        1403,
        1403,
        "181.173",
        "181.1.1403",
        181,
        ConstructType::Type1,
    ),
    MagneticSpaceGroupType::new(
        1404,
        1404,
        "181.174",
        "181.2.1404",
        181,
        ConstructType::Type2,
    ),
    MagneticSpaceGroupType::new(
        1405,
        1405,
        "181.175",
        "181.3.1405",
        181,
        ConstructType::Type3,
    ),
    MagneticSpaceGroupType::new(
        1406,
        1406,
        "181.176",
        "181.4.1406",
        181,
        ConstructType::Type3,
    ),
    MagneticSpaceGroupType::new(
        1407,
        1407,
        "181.177",
        "181.5.1407",
        181,
        ConstructType::Type3,
    ),
    MagneticSpaceGroupType::new(
        1408,
        1402,
        "181.178",
        "180.7.1402",
        181,
        ConstructType::Type4,
    ),
    MagneticSpaceGroupType::new(
        1409,
        1410,
        "182.179",
        "182.1.1410",
        182,
        ConstructType::Type1,
    ),
    MagneticSpaceGroupType::new(
        1410,
        1411,
        "182.180",
        "182.2.1411",
        182,
        ConstructType::Type2,
    ),
    MagneticSpaceGroupType::new(
        1411,
        1412,
        "182.181",
        "182.3.1412",
        182,
        ConstructType::Type3,
    ),
    MagneticSpaceGroupType::new(
        1412,
        1413,
        "182.182",
        "182.4.1413",
        182,
        ConstructType::Type3,
    ),
    MagneticSpaceGroupType::new(
        1413,
        1414,
        "182.183",
        "182.5.1414",
        182,
        ConstructType::Type3,
    ),
    MagneticSpaceGroupType::new(
        1414,
        1385,
        "182.184",
        "177.7.1385",
        182,
        ConstructType::Type4,
    ),
    MagneticSpaceGroupType::new(
        1415,
        1415,
        "183.185",
        "183.1.1415",
        183,
        ConstructType::Type1,
    ),
    MagneticSpaceGroupType::new(
        1416,
        1416,
        "183.186",
        "183.2.1416",
        183,
        ConstructType::Type2,
    ),
    MagneticSpaceGroupType::new(
        1417,
        1417,
        "183.187",
        "183.3.1417",
        183,
        ConstructType::Type3,
    ),
    MagneticSpaceGroupType::new(
        1418,
        1418,
        "183.188",
        "183.4.1418",
        183,
        ConstructType::Type3,
    ),
    MagneticSpaceGroupType::new(
        1419,
        1419,
        "183.189",
        "183.5.1419",
        183,
        ConstructType::Type3,
    ),
    MagneticSpaceGroupType::new(
        1420,
        1420,
        "183.190",
        "183.6.1420",
        183,
        ConstructType::Type4,
    ),
    MagneticSpaceGroupType::new(
        1421,
        1424,
        "184.191",
        "184.1.1424",
        184,
        ConstructType::Type1,
    ),
    MagneticSpaceGroupType::new(
        1422,
        1425,
        "184.192",
        "184.2.1425",
        184,
        ConstructType::Type2,
    ),
    MagneticSpaceGroupType::new(
        1423,
        1426,
        "184.193",
        "184.3.1426",
        184,
        ConstructType::Type3,
    ),
    MagneticSpaceGroupType::new(
        1424,
        1427,
        "184.194",
        "184.4.1427",
        184,
        ConstructType::Type3,
    ),
    MagneticSpaceGroupType::new(
        1425,
        1428,
        "184.195",
        "184.5.1428",
        184,
        ConstructType::Type3,
    ),
    MagneticSpaceGroupType::new(
        1426,
        1423,
        "184.196",
        "183.9.1423",
        184,
        ConstructType::Type4,
    ),
    MagneticSpaceGroupType::new(
        1427,
        1429,
        "185.197",
        "185.1.1429",
        185,
        ConstructType::Type1,
    ),
    MagneticSpaceGroupType::new(
        1428,
        1430,
        "185.198",
        "185.2.1430",
        185,
        ConstructType::Type2,
    ),
    MagneticSpaceGroupType::new(
        1429,
        1431,
        "185.199",
        "185.3.1431",
        185,
        ConstructType::Type3,
    ),
    MagneticSpaceGroupType::new(
        1430,
        1432,
        "185.200",
        "185.4.1432",
        185,
        ConstructType::Type3,
    ),
    MagneticSpaceGroupType::new(
        1431,
        1433,
        "185.201",
        "185.5.1433",
        185,
        ConstructType::Type3,
    ),
    MagneticSpaceGroupType::new(
        1432,
        1421,
        "185.202",
        "183.7.1421",
        185,
        ConstructType::Type4,
    ),
    MagneticSpaceGroupType::new(
        1433,
        1434,
        "186.203",
        "186.1.1434",
        186,
        ConstructType::Type1,
    ),
    MagneticSpaceGroupType::new(
        1434,
        1435,
        "186.204",
        "186.2.1435",
        186,
        ConstructType::Type2,
    ),
    MagneticSpaceGroupType::new(
        1435,
        1436,
        "186.205",
        "186.3.1436",
        186,
        ConstructType::Type3,
    ),
    MagneticSpaceGroupType::new(
        1436,
        1437,
        "186.206",
        "186.4.1437",
        186,
        ConstructType::Type3,
    ),
    MagneticSpaceGroupType::new(
        1437,
        1438,
        "186.207",
        "186.5.1438",
        186,
        ConstructType::Type3,
    ),
    MagneticSpaceGroupType::new(
        1438,
        1422,
        "186.208",
        "183.8.1422",
        186,
        ConstructType::Type4,
    ),
    MagneticSpaceGroupType::new(
        1439,
        1439,
        "187.209",
        "187.1.1439",
        187,
        ConstructType::Type1,
    ),
    MagneticSpaceGroupType::new(
        1440,
        1440,
        "187.210",
        "187.2.1440",
        187,
        ConstructType::Type2,
    ),
    MagneticSpaceGroupType::new(
        1441,
        1441,
        "187.211",
        "187.3.1441",
        187,
        ConstructType::Type3,
    ),
    MagneticSpaceGroupType::new(
        1442,
        1442,
        "187.212",
        "187.4.1442",
        187,
        ConstructType::Type3,
    ),
    MagneticSpaceGroupType::new(
        1443,
        1443,
        "187.213",
        "187.5.1443",
        187,
        ConstructType::Type3,
    ),
    MagneticSpaceGroupType::new(
        1444,
        1444,
        "187.214",
        "187.6.1444",
        187,
        ConstructType::Type4,
    ),
    MagneticSpaceGroupType::new(
        1445,
        1446,
        "188.215",
        "188.1.1446",
        188,
        ConstructType::Type1,
    ),
    MagneticSpaceGroupType::new(
        1446,
        1447,
        "188.216",
        "188.2.1447",
        188,
        ConstructType::Type2,
    ),
    MagneticSpaceGroupType::new(
        1447,
        1448,
        "188.217",
        "188.3.1448",
        188,
        ConstructType::Type3,
    ),
    MagneticSpaceGroupType::new(
        1448,
        1449,
        "188.218",
        "188.4.1449",
        188,
        ConstructType::Type3,
    ),
    MagneticSpaceGroupType::new(
        1449,
        1450,
        "188.219",
        "188.5.1450",
        188,
        ConstructType::Type3,
    ),
    MagneticSpaceGroupType::new(
        1450,
        1445,
        "188.220",
        "187.7.1445",
        188,
        ConstructType::Type4,
    ),
    MagneticSpaceGroupType::new(
        1451,
        1451,
        "189.221",
        "189.1.1451",
        189,
        ConstructType::Type1,
    ),
    MagneticSpaceGroupType::new(
        1452,
        1452,
        "189.222",
        "189.2.1452",
        189,
        ConstructType::Type2,
    ),
    MagneticSpaceGroupType::new(
        1453,
        1453,
        "189.223",
        "189.3.1453",
        189,
        ConstructType::Type3,
    ),
    MagneticSpaceGroupType::new(
        1454,
        1454,
        "189.224",
        "189.4.1454",
        189,
        ConstructType::Type3,
    ),
    MagneticSpaceGroupType::new(
        1455,
        1455,
        "189.225",
        "189.5.1455",
        189,
        ConstructType::Type3,
    ),
    MagneticSpaceGroupType::new(
        1456,
        1456,
        "189.226",
        "189.6.1456",
        189,
        ConstructType::Type4,
    ),
    MagneticSpaceGroupType::new(
        1457,
        1458,
        "190.227",
        "190.1.1458",
        190,
        ConstructType::Type1,
    ),
    MagneticSpaceGroupType::new(
        1458,
        1459,
        "190.228",
        "190.2.1459",
        190,
        ConstructType::Type2,
    ),
    MagneticSpaceGroupType::new(
        1459,
        1460,
        "190.229",
        "190.3.1460",
        190,
        ConstructType::Type3,
    ),
    MagneticSpaceGroupType::new(
        1460,
        1461,
        "190.230",
        "190.4.1461",
        190,
        ConstructType::Type3,
    ),
    MagneticSpaceGroupType::new(
        1461,
        1462,
        "190.231",
        "190.5.1462",
        190,
        ConstructType::Type3,
    ),
    MagneticSpaceGroupType::new(
        1462,
        1457,
        "190.232",
        "189.7.1457",
        190,
        ConstructType::Type4,
    ),
    MagneticSpaceGroupType::new(
        1463,
        1463,
        "191.233",
        "191.1.1463",
        191,
        ConstructType::Type1,
    ),
    MagneticSpaceGroupType::new(
        1464,
        1464,
        "191.234",
        "191.2.1464",
        191,
        ConstructType::Type2,
    ),
    MagneticSpaceGroupType::new(
        1465,
        1465,
        "191.235",
        "191.3.1465",
        191,
        ConstructType::Type3,
    ),
    MagneticSpaceGroupType::new(
        1466,
        1466,
        "191.236",
        "191.4.1466",
        191,
        ConstructType::Type3,
    ),
    MagneticSpaceGroupType::new(
        1467,
        1467,
        "191.237",
        "191.5.1467",
        191,
        ConstructType::Type3,
    ),
    MagneticSpaceGroupType::new(
        1468,
        1468,
        "191.238",
        "191.6.1468",
        191,
        ConstructType::Type3,
    ),
    MagneticSpaceGroupType::new(
        1469,
        1469,
        "191.239",
        "191.7.1469",
        191,
        ConstructType::Type3,
    ),
    MagneticSpaceGroupType::new(
        1470,
        1470,
        "191.240",
        "191.8.1470",
        191,
        ConstructType::Type3,
    ),
    MagneticSpaceGroupType::new(
        1471,
        1471,
        "191.241",
        "191.9.1471",
        191,
        ConstructType::Type3,
    ),
    MagneticSpaceGroupType::new(
        1472,
        1472,
        "191.242",
        "191.10.1472",
        191,
        ConstructType::Type4,
    ),
    MagneticSpaceGroupType::new(
        1473,
        1476,
        "192.243",
        "192.1.1476",
        192,
        ConstructType::Type1,
    ),
    MagneticSpaceGroupType::new(
        1474,
        1477,
        "192.244",
        "192.2.1477",
        192,
        ConstructType::Type2,
    ),
    MagneticSpaceGroupType::new(
        1475,
        1478,
        "192.245",
        "192.3.1478",
        192,
        ConstructType::Type3,
    ),
    MagneticSpaceGroupType::new(
        1476,
        1479,
        "192.246",
        "192.4.1479",
        192,
        ConstructType::Type3,
    ),
    MagneticSpaceGroupType::new(
        1477,
        1480,
        "192.247",
        "192.5.1480",
        192,
        ConstructType::Type3,
    ),
    MagneticSpaceGroupType::new(
        1478,
        1481,
        "192.248",
        "192.6.1481",
        192,
        ConstructType::Type3,
    ),
    MagneticSpaceGroupType::new(
        1479,
        1482,
        "192.249",
        "192.7.1482",
        192,
        ConstructType::Type3,
    ),
    MagneticSpaceGroupType::new(
        1480,
        1483,
        "192.250",
        "192.8.1483",
        192,
        ConstructType::Type3,
    ),
    MagneticSpaceGroupType::new(
        1481,
        1484,
        "192.251",
        "192.9.1484",
        192,
        ConstructType::Type3,
    ),
    MagneticSpaceGroupType::new(
        1482,
        1475,
        "192.252",
        "191.13.1475",
        192,
        ConstructType::Type4,
    ),
    MagneticSpaceGroupType::new(
        1483,
        1485,
        "193.253",
        "193.1.1485",
        193,
        ConstructType::Type1,
    ),
    MagneticSpaceGroupType::new(
        1484,
        1486,
        "193.254",
        "193.2.1486",
        193,
        ConstructType::Type2,
    ),
    MagneticSpaceGroupType::new(
        1485,
        1487,
        "193.255",
        "193.3.1487",
        193,
        ConstructType::Type3,
    ),
    MagneticSpaceGroupType::new(
        1486,
        1488,
        "193.256",
        "193.4.1488",
        193,
        ConstructType::Type3,
    ),
    MagneticSpaceGroupType::new(
        1487,
        1489,
        "193.257",
        "193.5.1489",
        193,
        ConstructType::Type3,
    ),
    MagneticSpaceGroupType::new(
        1488,
        1490,
        "193.258",
        "193.6.1490",
        193,
        ConstructType::Type3,
    ),
    MagneticSpaceGroupType::new(
        1489,
        1491,
        "193.259",
        "193.7.1491",
        193,
        ConstructType::Type3,
    ),
    MagneticSpaceGroupType::new(
        1490,
        1492,
        "193.260",
        "193.8.1492",
        193,
        ConstructType::Type3,
    ),
    MagneticSpaceGroupType::new(
        1491,
        1493,
        "193.261",
        "193.9.1493",
        193,
        ConstructType::Type3,
    ),
    MagneticSpaceGroupType::new(
        1492,
        1473,
        "193.262",
        "191.11.1473",
        193,
        ConstructType::Type4,
    ),
    MagneticSpaceGroupType::new(
        1493,
        1494,
        "194.263",
        "194.1.1494",
        194,
        ConstructType::Type1,
    ),
    MagneticSpaceGroupType::new(
        1494,
        1495,
        "194.264",
        "194.2.1495",
        194,
        ConstructType::Type2,
    ),
    MagneticSpaceGroupType::new(
        1495,
        1496,
        "194.265",
        "194.3.1496",
        194,
        ConstructType::Type3,
    ),
    MagneticSpaceGroupType::new(
        1496,
        1497,
        "194.266",
        "194.4.1497",
        194,
        ConstructType::Type3,
    ),
    MagneticSpaceGroupType::new(
        1497,
        1498,
        "194.267",
        "194.5.1498",
        194,
        ConstructType::Type3,
    ),
    MagneticSpaceGroupType::new(
        1498,
        1499,
        "194.268",
        "194.6.1499",
        194,
        ConstructType::Type3,
    ),
    MagneticSpaceGroupType::new(
        1499,
        1500,
        "194.269",
        "194.7.1500",
        194,
        ConstructType::Type3,
    ),
    MagneticSpaceGroupType::new(
        1500,
        1501,
        "194.270",
        "194.8.1501",
        194,
        ConstructType::Type3,
    ),
    MagneticSpaceGroupType::new(
        1501,
        1502,
        "194.271",
        "194.9.1502",
        194,
        ConstructType::Type3,
    ),
    MagneticSpaceGroupType::new(
        1502,
        1474,
        "194.272",
        "191.12.1474",
        194,
        ConstructType::Type4,
    ),
    MagneticSpaceGroupType::new(1503, 1503, "195.1", "195.1.1503", 195, ConstructType::Type1),
    MagneticSpaceGroupType::new(1504, 1504, "195.2", "195.2.1504", 195, ConstructType::Type2),
    MagneticSpaceGroupType::new(1505, 1510, "195.3", "197.3.1510", 195, ConstructType::Type4),
    MagneticSpaceGroupType::new(1506, 1506, "196.4", "196.1.1506", 196, ConstructType::Type1),
    MagneticSpaceGroupType::new(1507, 1507, "196.5", "196.2.1507", 196, ConstructType::Type2),
    MagneticSpaceGroupType::new(1508, 1505, "196.6", "195.3.1505", 196, ConstructType::Type4),
    MagneticSpaceGroupType::new(1509, 1508, "197.7", "197.1.1508", 197, ConstructType::Type1),
    MagneticSpaceGroupType::new(1510, 1509, "197.8", "197.2.1509", 197, ConstructType::Type2),
    MagneticSpaceGroupType::new(1511, 1511, "198.9", "198.1.1511", 198, ConstructType::Type1),
    MagneticSpaceGroupType::new(
        1512,
        1512,
        "198.10",
        "198.2.1512",
        198,
        ConstructType::Type2,
    ),
    MagneticSpaceGroupType::new(
        1513,
        1515,
        "198.11",
        "199.3.1515",
        198,
        ConstructType::Type4,
    ),
    MagneticSpaceGroupType::new(
        1514,
        1513,
        "199.12",
        "199.1.1513",
        199,
        ConstructType::Type1,
    ),
    MagneticSpaceGroupType::new(
        1515,
        1514,
        "199.13",
        "199.2.1514",
        199,
        ConstructType::Type2,
    ),
    MagneticSpaceGroupType::new(
        1516,
        1516,
        "200.14",
        "200.1.1516",
        200,
        ConstructType::Type1,
    ),
    MagneticSpaceGroupType::new(
        1517,
        1517,
        "200.15",
        "200.2.1517",
        200,
        ConstructType::Type2,
    ),
    MagneticSpaceGroupType::new(
        1518,
        1518,
        "200.16",
        "200.3.1518",
        200,
        ConstructType::Type3,
    ),
    MagneticSpaceGroupType::new(
        1519,
        1533,
        "200.17",
        "204.4.1533",
        200,
        ConstructType::Type4,
    ),
    MagneticSpaceGroupType::new(
        1520,
        1520,
        "201.18",
        "201.1.1520",
        201,
        ConstructType::Type1,
    ),
    MagneticSpaceGroupType::new(
        1521,
        1521,
        "201.19",
        "201.2.1521",
        201,
        ConstructType::Type2,
    ),
    MagneticSpaceGroupType::new(
        1522,
        1522,
        "201.20",
        "201.3.1522",
        201,
        ConstructType::Type3,
    ),
    MagneticSpaceGroupType::new(
        1523,
        1534,
        "201.21",
        "204.5.1534",
        201,
        ConstructType::Type4,
    ),
    MagneticSpaceGroupType::new(
        1524,
        1524,
        "202.22",
        "202.1.1524",
        202,
        ConstructType::Type1,
    ),
    MagneticSpaceGroupType::new(
        1525,
        1525,
        "202.23",
        "202.2.1525",
        202,
        ConstructType::Type2,
    ),
    MagneticSpaceGroupType::new(
        1526,
        1526,
        "202.24",
        "202.3.1526",
        202,
        ConstructType::Type3,
    ),
    MagneticSpaceGroupType::new(
        1527,
        1519,
        "202.25",
        "200.4.1519",
        202,
        ConstructType::Type4,
    ),
    MagneticSpaceGroupType::new(
        1528,
        1527,
        "203.26",
        "203.1.1527",
        203,
        ConstructType::Type1,
    ),
    MagneticSpaceGroupType::new(
        1529,
        1528,
        "203.27",
        "203.2.1528",
        203,
        ConstructType::Type2,
    ),
    MagneticSpaceGroupType::new(
        1530,
        1529,
        "203.28",
        "203.3.1529",
        203,
        ConstructType::Type3,
    ),
    MagneticSpaceGroupType::new(
        1531,
        1523,
        "203.29",
        "201.4.1523",
        203,
        ConstructType::Type4,
    ),
    MagneticSpaceGroupType::new(
        1532,
        1530,
        "204.30",
        "204.1.1530",
        204,
        ConstructType::Type1,
    ),
    MagneticSpaceGroupType::new(
        1533,
        1531,
        "204.31",
        "204.2.1531",
        204,
        ConstructType::Type2,
    ),
    MagneticSpaceGroupType::new(
        1534,
        1532,
        "204.32",
        "204.3.1532",
        204,
        ConstructType::Type3,
    ),
    MagneticSpaceGroupType::new(
        1535,
        1535,
        "205.33",
        "205.1.1535",
        205,
        ConstructType::Type1,
    ),
    MagneticSpaceGroupType::new(
        1536,
        1536,
        "205.34",
        "205.2.1536",
        205,
        ConstructType::Type2,
    ),
    MagneticSpaceGroupType::new(
        1537,
        1537,
        "205.35",
        "205.3.1537",
        205,
        ConstructType::Type3,
    ),
    MagneticSpaceGroupType::new(
        1538,
        1541,
        "205.36",
        "206.4.1541",
        205,
        ConstructType::Type4,
    ),
    MagneticSpaceGroupType::new(
        1539,
        1538,
        "206.37",
        "206.1.1538",
        206,
        ConstructType::Type1,
    ),
    MagneticSpaceGroupType::new(
        1540,
        1539,
        "206.38",
        "206.2.1539",
        206,
        ConstructType::Type2,
    ),
    MagneticSpaceGroupType::new(
        1541,
        1540,
        "206.39",
        "206.3.1540",
        206,
        ConstructType::Type3,
    ),
    MagneticSpaceGroupType::new(
        1542,
        1542,
        "207.40",
        "207.1.1542",
        207,
        ConstructType::Type1,
    ),
    MagneticSpaceGroupType::new(
        1543,
        1543,
        "207.41",
        "207.2.1543",
        207,
        ConstructType::Type2,
    ),
    MagneticSpaceGroupType::new(
        1544,
        1544,
        "207.42",
        "207.3.1544",
        207,
        ConstructType::Type3,
    ),
    MagneticSpaceGroupType::new(
        1545,
        1559,
        "207.43",
        "211.4.1559",
        207,
        ConstructType::Type4,
    ),
    MagneticSpaceGroupType::new(
        1546,
        1546,
        "208.44",
        "208.1.1546",
        208,
        ConstructType::Type1,
    ),
    MagneticSpaceGroupType::new(
        1547,
        1547,
        "208.45",
        "208.2.1547",
        208,
        ConstructType::Type2,
    ),
    MagneticSpaceGroupType::new(
        1548,
        1548,
        "208.46",
        "208.3.1548",
        208,
        ConstructType::Type3,
    ),
    MagneticSpaceGroupType::new(
        1549,
        1560,
        "208.47",
        "211.5.1560",
        208,
        ConstructType::Type4,
    ),
    MagneticSpaceGroupType::new(
        1550,
        1550,
        "209.48",
        "209.1.1550",
        209,
        ConstructType::Type1,
    ),
    MagneticSpaceGroupType::new(
        1551,
        1551,
        "209.49",
        "209.2.1551",
        209,
        ConstructType::Type2,
    ),
    MagneticSpaceGroupType::new(
        1552,
        1552,
        "209.50",
        "209.3.1552",
        209,
        ConstructType::Type3,
    ),
    MagneticSpaceGroupType::new(
        1553,
        1545,
        "209.51",
        "207.4.1545",
        209,
        ConstructType::Type4,
    ),
    MagneticSpaceGroupType::new(
        1554,
        1553,
        "210.52",
        "210.1.1553",
        210,
        ConstructType::Type1,
    ),
    MagneticSpaceGroupType::new(
        1555,
        1554,
        "210.53",
        "210.2.1554",
        210,
        ConstructType::Type2,
    ),
    MagneticSpaceGroupType::new(
        1556,
        1555,
        "210.54",
        "210.3.1555",
        210,
        ConstructType::Type3,
    ),
    MagneticSpaceGroupType::new(
        1557,
        1549,
        "210.55",
        "208.4.1549",
        210,
        ConstructType::Type4,
    ),
    MagneticSpaceGroupType::new(
        1558,
        1556,
        "211.56",
        "211.1.1556",
        211,
        ConstructType::Type1,
    ),
    MagneticSpaceGroupType::new(
        1559,
        1557,
        "211.57",
        "211.2.1557",
        211,
        ConstructType::Type2,
    ),
    MagneticSpaceGroupType::new(
        1560,
        1558,
        "211.58",
        "211.3.1558",
        211,
        ConstructType::Type3,
    ),
    MagneticSpaceGroupType::new(
        1561,
        1561,
        "212.59",
        "212.1.1561",
        212,
        ConstructType::Type1,
    ),
    MagneticSpaceGroupType::new(
        1562,
        1562,
        "212.60",
        "212.2.1562",
        212,
        ConstructType::Type2,
    ),
    MagneticSpaceGroupType::new(
        1563,
        1563,
        "212.61",
        "212.3.1563",
        212,
        ConstructType::Type3,
    ),
    MagneticSpaceGroupType::new(
        1564,
        1570,
        "212.62",
        "214.4.1570",
        212,
        ConstructType::Type4,
    ),
    MagneticSpaceGroupType::new(
        1565,
        1564,
        "213.63",
        "213.1.1564",
        213,
        ConstructType::Type1,
    ),
    MagneticSpaceGroupType::new(
        1566,
        1565,
        "213.64",
        "213.2.1565",
        213,
        ConstructType::Type2,
    ),
    MagneticSpaceGroupType::new(
        1567,
        1566,
        "213.65",
        "213.3.1566",
        213,
        ConstructType::Type3,
    ),
    MagneticSpaceGroupType::new(
        1568,
        1571,
        "213.66",
        "214.5.1571",
        213,
        ConstructType::Type4,
    ),
    MagneticSpaceGroupType::new(
        1569,
        1567,
        "214.67",
        "214.1.1567",
        214,
        ConstructType::Type1,
    ),
    MagneticSpaceGroupType::new(
        1570,
        1568,
        "214.68",
        "214.2.1568",
        214,
        ConstructType::Type2,
    ),
    MagneticSpaceGroupType::new(
        1571,
        1569,
        "214.69",
        "214.3.1569",
        214,
        ConstructType::Type3,
    ),
    MagneticSpaceGroupType::new(
        1572,
        1572,
        "215.70",
        "215.1.1572",
        215,
        ConstructType::Type1,
    ),
    MagneticSpaceGroupType::new(
        1573,
        1573,
        "215.71",
        "215.2.1573",
        215,
        ConstructType::Type2,
    ),
    MagneticSpaceGroupType::new(
        1574,
        1574,
        "215.72",
        "215.3.1574",
        215,
        ConstructType::Type3,
    ),
    MagneticSpaceGroupType::new(
        1575,
        1583,
        "215.73",
        "217.4.1583",
        215,
        ConstructType::Type4,
    ),
    MagneticSpaceGroupType::new(
        1576,
        1577,
        "216.74",
        "216.1.1577",
        216,
        ConstructType::Type1,
    ),
    MagneticSpaceGroupType::new(
        1577,
        1578,
        "216.75",
        "216.2.1578",
        216,
        ConstructType::Type2,
    ),
    MagneticSpaceGroupType::new(
        1578,
        1579,
        "216.76",
        "216.3.1579",
        216,
        ConstructType::Type3,
    ),
    MagneticSpaceGroupType::new(
        1579,
        1575,
        "216.77",
        "215.4.1575",
        216,
        ConstructType::Type4,
    ),
    MagneticSpaceGroupType::new(
        1580,
        1580,
        "217.78",
        "217.1.1580",
        217,
        ConstructType::Type1,
    ),
    MagneticSpaceGroupType::new(
        1581,
        1581,
        "217.79",
        "217.2.1581",
        217,
        ConstructType::Type2,
    ),
    MagneticSpaceGroupType::new(
        1582,
        1582,
        "217.80",
        "217.3.1582",
        217,
        ConstructType::Type3,
    ),
    MagneticSpaceGroupType::new(
        1583,
        1585,
        "218.81",
        "218.1.1585",
        218,
        ConstructType::Type1,
    ),
    MagneticSpaceGroupType::new(
        1584,
        1586,
        "218.82",
        "218.2.1586",
        218,
        ConstructType::Type2,
    ),
    MagneticSpaceGroupType::new(
        1585,
        1587,
        "218.83",
        "218.3.1587",
        218,
        ConstructType::Type3,
    ),
    MagneticSpaceGroupType::new(
        1586,
        1584,
        "218.84",
        "217.5.1584",
        218,
        ConstructType::Type4,
    ),
    MagneticSpaceGroupType::new(
        1587,
        1588,
        "219.85",
        "219.1.1588",
        219,
        ConstructType::Type1,
    ),
    MagneticSpaceGroupType::new(
        1588,
        1589,
        "219.86",
        "219.2.1589",
        219,
        ConstructType::Type2,
    ),
    MagneticSpaceGroupType::new(
        1589,
        1590,
        "219.87",
        "219.3.1590",
        219,
        ConstructType::Type3,
    ),
    MagneticSpaceGroupType::new(
        1590,
        1576,
        "219.88",
        "215.5.1576",
        219,
        ConstructType::Type4,
    ),
    MagneticSpaceGroupType::new(
        1591,
        1591,
        "220.89",
        "220.1.1591",
        220,
        ConstructType::Type1,
    ),
    MagneticSpaceGroupType::new(
        1592,
        1592,
        "220.90",
        "220.2.1592",
        220,
        ConstructType::Type2,
    ),
    MagneticSpaceGroupType::new(
        1593,
        1593,
        "220.91",
        "220.3.1593",
        220,
        ConstructType::Type3,
    ),
    MagneticSpaceGroupType::new(
        1594,
        1594,
        "221.92",
        "221.1.1594",
        221,
        ConstructType::Type1,
    ),
    MagneticSpaceGroupType::new(
        1595,
        1595,
        "221.93",
        "221.2.1595",
        221,
        ConstructType::Type2,
    ),
    MagneticSpaceGroupType::new(
        1596,
        1596,
        "221.94",
        "221.3.1596",
        221,
        ConstructType::Type3,
    ),
    MagneticSpaceGroupType::new(
        1597,
        1597,
        "221.95",
        "221.4.1597",
        221,
        ConstructType::Type3,
    ),
    MagneticSpaceGroupType::new(
        1598,
        1598,
        "221.96",
        "221.5.1598",
        221,
        ConstructType::Type3,
    ),
    MagneticSpaceGroupType::new(
        1599,
        1643,
        "221.97",
        "229.6.1643",
        221,
        ConstructType::Type4,
    ),
    MagneticSpaceGroupType::new(
        1600,
        1601,
        "222.98",
        "222.1.1601",
        222,
        ConstructType::Type1,
    ),
    MagneticSpaceGroupType::new(
        1601,
        1602,
        "222.99",
        "222.2.1602",
        222,
        ConstructType::Type2,
    ),
    MagneticSpaceGroupType::new(
        1602,
        1603,
        "222.100",
        "222.3.1603",
        222,
        ConstructType::Type3,
    ),
    MagneticSpaceGroupType::new(
        1603,
        1604,
        "222.101",
        "222.4.1604",
        222,
        ConstructType::Type3,
    ),
    MagneticSpaceGroupType::new(
        1604,
        1605,
        "222.102",
        "222.5.1605",
        222,
        ConstructType::Type3,
    ),
    MagneticSpaceGroupType::new(
        1605,
        1646,
        "222.103",
        "229.9.1646",
        222,
        ConstructType::Type4,
    ),
    MagneticSpaceGroupType::new(
        1606,
        1606,
        "223.104",
        "223.1.1606",
        223,
        ConstructType::Type1,
    ),
    MagneticSpaceGroupType::new(
        1607,
        1607,
        "223.105",
        "223.2.1607",
        223,
        ConstructType::Type2,
    ),
    MagneticSpaceGroupType::new(
        1608,
        1608,
        "223.106",
        "223.3.1608",
        223,
        ConstructType::Type3,
    ),
    MagneticSpaceGroupType::new(
        1609,
        1609,
        "223.107",
        "223.4.1609",
        223,
        ConstructType::Type3,
    ),
    MagneticSpaceGroupType::new(
        1610,
        1610,
        "223.108",
        "223.5.1610",
        223,
        ConstructType::Type3,
    ),
    MagneticSpaceGroupType::new(
        1611,
        1645,
        "223.109",
        "229.8.1645",
        223,
        ConstructType::Type4,
    ),
    MagneticSpaceGroupType::new(
        1612,
        1611,
        "224.110",
        "224.1.1611",
        224,
        ConstructType::Type1,
    ),
    MagneticSpaceGroupType::new(
        1613,
        1612,
        "224.111",
        "224.2.1612",
        224,
        ConstructType::Type2,
    ),
    MagneticSpaceGroupType::new(
        1614,
        1613,
        "224.112",
        "224.3.1613",
        224,
        ConstructType::Type3,
    ),
    MagneticSpaceGroupType::new(
        1615,
        1614,
        "224.113",
        "224.4.1614",
        224,
        ConstructType::Type3,
    ),
    MagneticSpaceGroupType::new(
        1616,
        1615,
        "224.114",
        "224.5.1615",
        224,
        ConstructType::Type3,
    ),
    MagneticSpaceGroupType::new(
        1617,
        1644,
        "224.115",
        "229.7.1644",
        224,
        ConstructType::Type4,
    ),
    MagneticSpaceGroupType::new(
        1618,
        1618,
        "225.116",
        "225.1.1618",
        225,
        ConstructType::Type1,
    ),
    MagneticSpaceGroupType::new(
        1619,
        1619,
        "225.117",
        "225.2.1619",
        225,
        ConstructType::Type2,
    ),
    MagneticSpaceGroupType::new(
        1620,
        1620,
        "225.118",
        "225.3.1620",
        225,
        ConstructType::Type3,
    ),
    MagneticSpaceGroupType::new(
        1621,
        1621,
        "225.119",
        "225.4.1621",
        225,
        ConstructType::Type3,
    ),
    MagneticSpaceGroupType::new(
        1622,
        1622,
        "225.120",
        "225.5.1622",
        225,
        ConstructType::Type3,
    ),
    MagneticSpaceGroupType::new(
        1623,
        1599,
        "225.121",
        "221.6.1599",
        225,
        ConstructType::Type4,
    ),
    MagneticSpaceGroupType::new(
        1624,
        1623,
        "226.122",
        "226.1.1623",
        226,
        ConstructType::Type1,
    ),
    MagneticSpaceGroupType::new(
        1625,
        1624,
        "226.123",
        "226.2.1624",
        226,
        ConstructType::Type2,
    ),
    MagneticSpaceGroupType::new(
        1626,
        1625,
        "226.124",
        "226.3.1625",
        226,
        ConstructType::Type3,
    ),
    MagneticSpaceGroupType::new(
        1627,
        1626,
        "226.125",
        "226.4.1626",
        226,
        ConstructType::Type3,
    ),
    MagneticSpaceGroupType::new(
        1628,
        1627,
        "226.126",
        "226.5.1627",
        226,
        ConstructType::Type3,
    ),
    MagneticSpaceGroupType::new(
        1629,
        1600,
        "226.127",
        "221.7.1600",
        226,
        ConstructType::Type4,
    ),
    MagneticSpaceGroupType::new(
        1630,
        1628,
        "227.128",
        "227.1.1628",
        227,
        ConstructType::Type1,
    ),
    MagneticSpaceGroupType::new(
        1631,
        1629,
        "227.129",
        "227.2.1629",
        227,
        ConstructType::Type2,
    ),
    MagneticSpaceGroupType::new(
        1632,
        1630,
        "227.130",
        "227.3.1630",
        227,
        ConstructType::Type3,
    ),
    MagneticSpaceGroupType::new(
        1633,
        1631,
        "227.131",
        "227.4.1631",
        227,
        ConstructType::Type3,
    ),
    MagneticSpaceGroupType::new(
        1634,
        1632,
        "227.132",
        "227.5.1632",
        227,
        ConstructType::Type3,
    ),
    MagneticSpaceGroupType::new(
        1635,
        1616,
        "227.133",
        "224.6.1616",
        227,
        ConstructType::Type4,
    ),
    MagneticSpaceGroupType::new(
        1636,
        1633,
        "228.134",
        "228.1.1633",
        228,
        ConstructType::Type1,
    ),
    MagneticSpaceGroupType::new(
        1637,
        1634,
        "228.135",
        "228.2.1634",
        228,
        ConstructType::Type2,
    ),
    MagneticSpaceGroupType::new(
        1638,
        1635,
        "228.136",
        "228.3.1635",
        228,
        ConstructType::Type3,
    ),
    MagneticSpaceGroupType::new(
        1639,
        1636,
        "228.137",
        "228.4.1636",
        228,
        ConstructType::Type3,
    ),
    MagneticSpaceGroupType::new(
        1640,
        1637,
        "228.138",
        "228.5.1637",
        228,
        ConstructType::Type3,
    ),
    MagneticSpaceGroupType::new(
        1641,
        1617,
        "228.139",
        "224.7.1617",
        228,
        ConstructType::Type4,
    ),
    MagneticSpaceGroupType::new(
        1642,
        1638,
        "229.140",
        "229.1.1638",
        229,
        ConstructType::Type1,
    ),
    MagneticSpaceGroupType::new(
        1643,
        1639,
        "229.141",
        "229.2.1639",
        229,
        ConstructType::Type2,
    ),
    MagneticSpaceGroupType::new(
        1644,
        1640,
        "229.142",
        "229.3.1640",
        229,
        ConstructType::Type3,
    ),
    MagneticSpaceGroupType::new(
        1645,
        1641,
        "229.143",
        "229.4.1641",
        229,
        ConstructType::Type3,
    ),
    MagneticSpaceGroupType::new(
        1646,
        1642,
        "229.144",
        "229.5.1642",
        229,
        ConstructType::Type3,
    ),
    MagneticSpaceGroupType::new(
        1647,
        1647,
        "230.145",
        "230.1.1647",
        230,
        ConstructType::Type1,
    ),
    MagneticSpaceGroupType::new(
        1648,
        1648,
        "230.146",
        "230.2.1648",
        230,
        ConstructType::Type2,
    ),
    MagneticSpaceGroupType::new(
        1649,
        1649,
        "230.147",
        "230.3.1649",
        230,
        ConstructType::Type3,
    ),
    MagneticSpaceGroupType::new(
        1650,
        1650,
        "230.148",
        "230.4.1650",
        230,
        ConstructType::Type3,
    ),
    MagneticSpaceGroupType::new(
        1651,
        1651,
        "230.149",
        "230.5.1651",
        230,
        ConstructType::Type3,
    ),
];
